AddContact class final

AddContact (addContact) - TDLib function

Adds a user to the contact list or edits an existing contact by their user identifier.

  • contact: The contact to add or edit; phone number may be empty and needs to be specified only if known, vCard is ignored.
  • sharePhoneNumber: Pass true to share the current user's phone number with the new contact. A corresponding rule to userPrivacySettingShowPhoneNumber will be added if needed.. Use the field userFullInfo.need_phone_number_privacy_exception to check whether the current user needs to be asked to share their phone number.

Ok is returned on completion.

Inheritance

Constructors

AddContact({required Contact contact, required bool sharePhoneNumber})
AddContact (addContact) - TDLib function
const

Properties

contact → Contact
The contact to add or edit; phone number may be empty and needs to be specified only if known, vCard is ignored
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharePhoneNumber → bool
Pass true to share the current user's phone number with the new contact. A corresponding rule to userPrivacySettingShowPhoneNumber will be added if needed.. Use the field userFullInfo.need_phone_number_privacy_exception to check whether the current user needs to be asked to share their phone number
final

Methods

copyWith({Contact? contact, bool? sharePhoneNumber}) → AddContact
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type