AddProxy class final

AddProxy (addProxy) - TDLib function

Adds a proxy server for network requests. Can be called before authorization.

  • server: Proxy server domain or IP address.
  • port: Proxy server port.
  • enable: Pass true to immediately enable the proxy.
  • type: Proxy type.

Proxy is returned on completion.

Inheritance

Constructors

AddProxy({required String server, required int port, required bool enable, required ProxyType type})
AddProxy (addProxy) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
enable → bool
Pass true to immediately enable the proxy
final
hashCode → int
The hash code for this object.
no setterinherited
port → int
Proxy server port
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
server → String
Proxy server domain or IP address
final
type → ProxyType
Proxy type
final

Methods

copyWith({String? server, int? port, bool? enable, ProxyType? type}) → AddProxy
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type