AnswerWebAppQuery class final
AnswerWebAppQuery (answerWebAppQuery) - TDLib function
Sets the result of interaction with a Web App and sends corresponding message on behalf of the user to the chat from which the query originated; for bots only.
- webAppQueryId: Identifier of the Web App query.
- result: The result of the query.
SentWebAppMessage is returned on completion.
- Inheritance
-
- Object
- TdFunction
- AnswerWebAppQuery
Constructors
- AnswerWebAppQuery({required String webAppQueryId, required InputInlineQueryResult result})
-
AnswerWebAppQuery (answerWebAppQuery) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- result → InputInlineQueryResult
-
The result of the query
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- webAppQueryId → String
-
Identifier of the Web App query
final
Methods
-
copyWith(
{String? webAppQueryId, InputInlineQueryResult? result}) → AnswerWebAppQuery - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type