AssignGooglePlayTransaction class final

AssignGooglePlayTransaction (assignGooglePlayTransaction) - TDLib function

Informs server about a purchase through Google Play. For official applications only.

Ok is returned on completion.

Inheritance

Constructors

AssignGooglePlayTransaction({required String packageName, required String storeProductId, required String purchaseToken, required StorePaymentPurpose purpose})
AssignGooglePlayTransaction (assignGooglePlayTransaction) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
packageName → String
Application package name
final
purchaseToken → String
Google Play purchase token
final
purpose → StorePaymentPurpose
Transaction purpose
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storeProductId → String
Identifier of the purchased store product
final

Methods

copyWith({String? packageName, String? storeProductId, String? purchaseToken, StorePaymentPurpose? purpose}) → AssignGooglePlayTransaction
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type