AttachmentMenuBotColor class final

AttachmentMenuBotColor (attachmentMenuBotColor) - basic class

Describes a color to highlight a bot added to attachment menu.

  • lightColor: Color in the RGB24 format for light themes.
  • darkColor: Color in the RGB24 format for dark themes.
Inheritance

Constructors

AttachmentMenuBotColor({required int lightColor, required int darkColor})
AttachmentMenuBotColor (attachmentMenuBotColor) - basic class
const
AttachmentMenuBotColor.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
darkColor → int
Color in the RGB24 format for dark themes
final
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
lightColor → int
Color in the RGB24 format for light themes
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? lightColor, int? darkColor}) → AttachmentMenuBotColor
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type