AuthorizationStateWaitOtherDeviceConfirmation class final
AuthorizationStateWaitOtherDeviceConfirmation (authorizationStateWaitOtherDeviceConfirmation) - child of AuthorizationState
The user needs to confirm authorization on another logged in device by scanning a QR code with the provided link.
- link: A tg:// URL for the QR code. The link will be updated frequently.
- Inheritance
-
- Object
- TdObject
- AuthorizationState
- AuthorizationStateWaitOtherDeviceConfirmation
Constructors
- AuthorizationStateWaitOtherDeviceConfirmation({required String link, dynamic extra, int? clientId})
-
AuthorizationStateWaitOtherDeviceConfirmation (authorizationStateWaitOtherDeviceConfirmation) - child of AuthorizationState
const
-
AuthorizationStateWaitOtherDeviceConfirmation.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
clientId client identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
extra callback sign
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- link → String
-
A tg:// URL for the QR code. The link will be updated frequently
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? link, dynamic extra, int? clientId}) → AuthorizationStateWaitOtherDeviceConfirmation -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type