AvailableReaction class final

AvailableReaction (availableReaction) - basic class

Represents an available reaction.

  • type: Type of the reaction.
  • needsPremium: True, if Telegram Premium is needed to send the reaction.
Inheritance

Constructors

AvailableReaction({required ReactionType type, required bool needsPremium})
AvailableReaction (availableReaction) - basic class
const
AvailableReaction.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
needsPremium → bool
True, if Telegram Premium is needed to send the reaction
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ReactionType
Type of the reaction
final

Methods

copyWith({ReactionType? type, bool? needsPremium}) → AvailableReaction
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type