BackgroundFillFreeformGradient class final

BackgroundFillFreeformGradient (backgroundFillFreeformGradient) - child of BackgroundFill

Describes a freeform gradient fill of a background.

  • colors: A list of 3 or 4 colors of the freeform gradient in the RGB24 format.
Inheritance

Constructors

BackgroundFillFreeformGradient({required List<int> colors})
BackgroundFillFreeformGradient (backgroundFillFreeformGradient) - child of BackgroundFill
const
BackgroundFillFreeformGradient.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
colors → List<int>
A list of 3 or 4 colors of the freeform gradient in the RGB24 format
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<int>? colors}) → BackgroundFillFreeformGradient
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type