BackgroundFillGradient class final

BackgroundFillGradient (backgroundFillGradient) - child of BackgroundFill

Describes a gradient fill of a background.

  • topColor: A top color of the background in the RGB24 format.
  • bottomColor: A bottom color of the background in the RGB24 format.
  • rotationAngle: Clockwise rotation angle of the gradient, in degrees; 0-359. Must always be divisible by 45.
Inheritance

Constructors

BackgroundFillGradient({required int topColor, required int bottomColor, required int rotationAngle})
BackgroundFillGradient (backgroundFillGradient) - child of BackgroundFill
const
BackgroundFillGradient.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

bottomColor → int
A bottom color of the background in the RGB24 format
final
clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
rotationAngle → int
Clockwise rotation angle of the gradient, in degrees; 0-359. Must always be divisible by 45
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topColor → int
A top color of the background in the RGB24 format
final

Methods

copyWith({int? topColor, int? bottomColor, int? rotationAngle}) → BackgroundFillGradient
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type