BotCommands class final

BotCommands (botCommands) - basic class

Contains a list of bot commands.

Inheritance

Constructors

BotCommands({required int botUserId, required List<BotCommand> commands, dynamic extra, int? clientId})
BotCommands (botCommands) - basic class
const
BotCommands.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

botUserId → int
Bot's user identifier
final
clientId → int?
clientId client identifier
final
commands → List<BotCommand>
List of bot commands
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId, List<BotCommand>? commands, dynamic extra, int? clientId}) → BotCommands
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type