BotMediaPreview class final

BotMediaPreview (botMediaPreview) - basic class

Describes media previews of a bot.

  • date: Point in time (Unix timestamp) when the preview was added or changed last time.
  • content: Content of the preview.
Inheritance

Constructors

BotMediaPreview({required int date, required StoryContent content, dynamic extra, int? clientId})
BotMediaPreview (botMediaPreview) - basic class
const
BotMediaPreview.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
content → StoryContent
Content of the preview
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
date → int
Point in time (Unix timestamp) when the preview was added or changed last time
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? date, StoryContent? content, dynamic extra, int? clientId}) → BotMediaPreview
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type