BusinessMessage class final

BusinessMessage (businessMessage) - basic class

Describes a message from a business account as received by a bot.

  • message: The message.
  • replyToMessage: Message that is replied by the message in the same chat; may be null if none (optional).
Inheritance

Constructors

BusinessMessage({required Message message, Message? replyToMessage, dynamic extra, int? clientId})
BusinessMessage (businessMessage) - basic class
const
BusinessMessage.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
message → Message
The message
final
replyToMessage → Message?
Message that is replied by the message in the same chat; may be null if none
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Message? message, Message? replyToMessage, dynamic extra, int? clientId}) → BusinessMessage
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type