Call class final

Call (call) - basic class

Describes a call.

  • id: Call identifier, not persistent.
  • userId: User identifier of the other call participant.
  • isOutgoing: True, if the call is outgoing.
  • isVideo: True, if the call is a video call.
  • state: Call state.
Inheritance

Constructors

Call({required int id, required int userId, required bool isOutgoing, required bool isVideo, required CallState state})
Call (call) - basic class
const
Call.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
Call identifier, not persistent
final
isOutgoing → bool
True, if the call is outgoing
final
isVideo → bool
True, if the call is a video call
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → CallState
Call state
final
userId → int
User identifier of the other call participant
final

Methods

copyWith({int? id, int? userId, bool? isOutgoing, bool? isVideo, CallState? state}) → Call
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type