CallStateDiscarded class final

CallStateDiscarded (callStateDiscarded) - child of CallState

The call has ended successfully.

  • reason: The reason why the call has ended.
  • needRating: True, if the call rating must be sent to the server.
  • needDebugInformation: True, if the call debug information must be sent to the server.
  • needLog: True, if the call log must be sent to the server.
Inheritance

Constructors

CallStateDiscarded({required CallDiscardReason reason, required bool needRating, required bool needDebugInformation, required bool needLog})
CallStateDiscarded (callStateDiscarded) - child of CallState
const
CallStateDiscarded.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
needDebugInformation → bool
True, if the call debug information must be sent to the server
final
needLog → bool
True, if the call log must be sent to the server
final
needRating → bool
True, if the call rating must be sent to the server
final
reason → CallDiscardReason
The reason why the call has ended
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({CallDiscardReason? reason, bool? needRating, bool? needDebugInformation, bool? needLog}) → CallStateDiscarded
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type