CallbackQueryAnswer class final

CallbackQueryAnswer (callbackQueryAnswer) - basic class

Contains a bot's answer to a callback query.

  • text: Text of the answer.
  • showAlert: True, if an alert must be shown to the user instead of a toast notification.
  • url: URL to be opened.
Inheritance

Constructors

CallbackQueryAnswer({required String text, required bool showAlert, required String url, dynamic extra, int? clientId})
CallbackQueryAnswer (callbackQueryAnswer) - basic class
const
CallbackQueryAnswer.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showAlert → bool
True, if an alert must be shown to the user instead of a toast notification
final
text → String
Text of the answer
final
url → String
URL to be opened
final

Methods

copyWith({String? text, bool? showAlert, String? url, dynamic extra, int? clientId}) → CallbackQueryAnswer
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type