CanBotSendMessages class final
CanBotSendMessages (canBotSendMessages) - TDLib function
Checks whether the specified bot can send messages to the user. Returns a 404 error if can't and the access can be granted by call to allowBotToSendMessages.
- botUserId: Identifier of the target bot.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- CanBotSendMessages
Constructors
- CanBotSendMessages({required int botUserId})
-
CanBotSendMessages (canBotSendMessages) - TDLib function
const
Properties
- botUserId → int
-
Identifier of the target bot
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? botUserId}) → CanBotSendMessages - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type