CanBotSendMessages constructor

const CanBotSendMessages({
  1. required int botUserId,
})

CanBotSendMessages (canBotSendMessages) - TDLib function

Checks whether the specified bot can send messages to the user. Returns a 404 error if can't and the access can be granted by call to allowBotToSendMessages.

  • botUserId: Identifier of the target bot.

Ok is returned on completion.

Implementation

const CanBotSendMessages({
  required this.botUserId,
});