CanSendStoryResultActiveStoryLimitExceeded class final

CanSendStoryResultActiveStoryLimitExceeded (canSendStoryResultActiveStoryLimitExceeded) - child of CanSendStoryResult

The limit for the number of active stories exceeded. The user can buy Telegram Premium, delete an active story, or wait for the oldest story to expire.

Inheritance

Constructors

CanSendStoryResultActiveStoryLimitExceeded({dynamic extra, int? clientId})
CanSendStoryResultActiveStoryLimitExceeded (canSendStoryResultActiveStoryLimitExceeded) - child of CanSendStoryResult
const
CanSendStoryResultActiveStoryLimitExceeded.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({dynamic extra, int? clientId}) → CanSendStoryResultActiveStoryLimitExceeded
Copy instance with no modifications.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type