ChatActionWatchingAnimations class final

ChatActionWatchingAnimations (chatActionWatchingAnimations) - child of ChatAction

The user is watching animations sent by the other party by clicking on an animated emoji.

  • emoji: The animated emoji.
Inheritance

Constructors

ChatActionWatchingAnimations({required String emoji})
ChatActionWatchingAnimations (chatActionWatchingAnimations) - child of ChatAction
const
ChatActionWatchingAnimations.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
emoji → String
The animated emoji
final
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? emoji}) → ChatActionWatchingAnimations
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type