ChatAvailableReactionsSome class final
ChatAvailableReactionsSome (chatAvailableReactionsSome) - child of ChatAvailableReactions
Only specific reactions are available in the chat.
- reactions: The list of reactions.
- maxReactionCount: The maximum allowed number of reactions per message; 1-11.
- Inheritance
-
- Object
- TdObject
- ChatAvailableReactions
- ChatAvailableReactionsSome
Constructors
-
ChatAvailableReactionsSome({required List<
ReactionType> reactions, required int maxReactionCount}) -
ChatAvailableReactionsSome (chatAvailableReactionsSome) - child of ChatAvailableReactions
const
-
ChatAvailableReactionsSome.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxReactionCount → int
-
The maximum allowed number of reactions per message; 1-11
final
-
reactions
→ List<
ReactionType> -
The list of reactions
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< ReactionType> ? reactions, int? maxReactionCount}) → ChatAvailableReactionsSome -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type