ChatBoostFeatures class final

ChatBoostFeatures (chatBoostFeatures) - basic class

Contains a list of features available on the first chat boost levels.

Inheritance

Constructors

ChatBoostFeatures({required List<ChatBoostLevelFeatures> features, required int minProfileBackgroundCustomEmojiBoostLevel, required int minBackgroundCustomEmojiBoostLevel, required int minEmojiStatusBoostLevel, required int minChatThemeBackgroundBoostLevel, required int minCustomBackgroundBoostLevel, required int minCustomEmojiStickerSetBoostLevel, required int minSpeechRecognitionBoostLevel, required int minSponsoredMessageDisableBoostLevel, dynamic extra, int? clientId})
ChatBoostFeatures (chatBoostFeatures) - basic class
const
ChatBoostFeatures.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
features → List<ChatBoostLevelFeatures>
The list of features
final
hashCode → int
The hash code for this object.
no setterinherited
minBackgroundCustomEmojiBoostLevel → int
The minimum boost level required to set custom emoji for reply header and link preview background; for channel chats only
final
minChatThemeBackgroundBoostLevel → int
The minimum boost level required to set a chat theme background as chat background
final
minCustomBackgroundBoostLevel → int
The minimum boost level required to set custom chat background
final
minCustomEmojiStickerSetBoostLevel → int
The minimum boost level required to set custom emoji sticker set for the chat; for supergroup chats only
final
minEmojiStatusBoostLevel → int
The minimum boost level required to set emoji status
final
minProfileBackgroundCustomEmojiBoostLevel → int
The minimum boost level required to set custom emoji for profile background
final
minSpeechRecognitionBoostLevel → int
The minimum boost level allowing to recognize speech in video note and voice note messages for non-Premium users; for supergroup chats only
final
minSponsoredMessageDisableBoostLevel → int
The minimum boost level allowing to disable sponsored messages in the chat; for channel chats only
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<ChatBoostLevelFeatures>? features, int? minProfileBackgroundCustomEmojiBoostLevel, int? minBackgroundCustomEmojiBoostLevel, int? minEmojiStatusBoostLevel, int? minChatThemeBackgroundBoostLevel, int? minCustomBackgroundBoostLevel, int? minCustomEmojiStickerSetBoostLevel, int? minSpeechRecognitionBoostLevel, int? minSponsoredMessageDisableBoostLevel, dynamic extra, int? clientId}) → ChatBoostFeatures
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type