ChatEvent class final

ChatEvent (chatEvent) - basic class

Represents a chat event.

  • id: Chat event identifier.
  • date: Point in time (Unix timestamp) when the event happened.
  • memberId: Identifier of the user or chat who performed the action.
  • action: The action.
Inheritance

Constructors

ChatEvent({required int id, required int date, required MessageSender memberId, required ChatEventAction action})
ChatEvent (chatEvent) - basic class
const
ChatEvent.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

action → ChatEventAction
The action
final
clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
date → int
Point in time (Unix timestamp) when the event happened
final
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
Chat event identifier
final
memberId → MessageSender
Identifier of the user or chat who performed the action
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id, int? date, MessageSender? memberId, ChatEventAction? action}) → ChatEvent
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type