ChatEventActiveUsernamesChanged class final

ChatEventActiveUsernamesChanged (chatEventActiveUsernamesChanged) - child of ChatEventAction

The chat active usernames were changed.

Inheritance

Constructors

ChatEventActiveUsernamesChanged({required List<String> oldUsernames, required List<String> newUsernames})
ChatEventActiveUsernamesChanged (chatEventActiveUsernamesChanged) - child of ChatEventAction
const
ChatEventActiveUsernamesChanged.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
newUsernames → List<String>
New list of active usernames
final
oldUsernames → List<String>
Previous list of active usernames
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<String>? oldUsernames, List<String>? newUsernames}) → ChatEventActiveUsernamesChanged
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type