ChatEventAvailableReactionsChanged class final
ChatEventAvailableReactionsChanged (chatEventAvailableReactionsChanged) - child of ChatEventAction
The chat available reactions were changed.
- oldAvailableReactions: Previous chat available reactions.
- newAvailableReactions: New chat available reactions.
- Inheritance
-
- Object
- TdObject
- ChatEventAction
- ChatEventAvailableReactionsChanged
Constructors
- ChatEventAvailableReactionsChanged({required ChatAvailableReactions oldAvailableReactions, required ChatAvailableReactions newAvailableReactions})
-
ChatEventAvailableReactionsChanged (chatEventAvailableReactionsChanged) - child of ChatEventAction
const
-
ChatEventAvailableReactionsChanged.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- newAvailableReactions → ChatAvailableReactions
-
New chat available reactions
final
- oldAvailableReactions → ChatAvailableReactions
-
Previous chat available reactions
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ChatAvailableReactions? oldAvailableReactions, ChatAvailableReactions? newAvailableReactions}) → ChatEventAvailableReactionsChanged -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type