ChatEventForumTopicToggleIsHidden class final

ChatEventForumTopicToggleIsHidden (chatEventForumTopicToggleIsHidden) - child of ChatEventAction

The General forum topic was hidden or unhidden.

  • topicInfo: New information about the topic.
Inheritance

Constructors

ChatEventForumTopicToggleIsHidden({required ForumTopicInfo topicInfo})
ChatEventForumTopicToggleIsHidden (chatEventForumTopicToggleIsHidden) - child of ChatEventAction
const
ChatEventForumTopicToggleIsHidden.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topicInfo → ForumTopicInfo
New information about the topic
final

Methods

copyWith({ForumTopicInfo? topicInfo}) → ChatEventForumTopicToggleIsHidden
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type