ChatEventInviteLinkEdited class final

ChatEventInviteLinkEdited (chatEventInviteLinkEdited) - child of ChatEventAction

A chat invite link was edited.

Inheritance

Constructors

ChatEventInviteLinkEdited({required ChatInviteLink oldInviteLink, required ChatInviteLink newInviteLink})
ChatEventInviteLinkEdited (chatEventInviteLinkEdited) - child of ChatEventAction
const
ChatEventInviteLinkEdited.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
New information about the invite link
final
Previous information about the invite link
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ChatInviteLink? oldInviteLink, ChatInviteLink? newInviteLink}) → ChatEventInviteLinkEdited
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type