ChatEventMemberSubscriptionExtended class final

ChatEventMemberSubscriptionExtended (chatEventMemberSubscriptionExtended) - child of ChatEventAction

A chat member extended their subscription to the chat.

  • userId: Affected chat member user identifier.
  • oldStatus: Previous status of the chat member.
  • newStatus: New status of the chat member.
Inheritance

Constructors

ChatEventMemberSubscriptionExtended({required int userId, required ChatMemberStatus oldStatus, required ChatMemberStatus newStatus})
ChatEventMemberSubscriptionExtended (chatEventMemberSubscriptionExtended) - child of ChatEventAction
const
ChatEventMemberSubscriptionExtended.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
newStatus → ChatMemberStatus
New status of the chat member
final
oldStatus → ChatMemberStatus
Previous status of the chat member
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
Affected chat member user identifier
final

Methods

copyWith({int? userId, ChatMemberStatus? oldStatus, ChatMemberStatus? newStatus}) → ChatEventMemberSubscriptionExtended
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type