ChatInviteLinkCount class final

ChatInviteLinkCount (chatInviteLinkCount) - basic class

Describes a chat administrator with a number of active and revoked chat invite links.

Inheritance

Constructors

ChatInviteLinkCount({required int userId, required int inviteLinkCount, required int revokedInviteLinkCount})
ChatInviteLinkCount (chatInviteLinkCount) - basic class
const
ChatInviteLinkCount.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
inviteLinkCount → int
Number of active invite links
final
revokedInviteLinkCount → int
Number of revoked invite links
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
Administrator's user identifier
final

Methods

copyWith({int? userId, int? inviteLinkCount, int? revokedInviteLinkCount}) → ChatInviteLinkCount
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type