ChatInviteLinks class final

ChatInviteLinks (chatInviteLinks) - basic class

Contains a list of chat invite links.

Inheritance

Constructors

ChatInviteLinks({required int totalCount, required List<ChatInviteLink> inviteLinks, dynamic extra, int? clientId})
ChatInviteLinks (chatInviteLinks) - basic class
const
ChatInviteLinks.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
List of invite links
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCount → int
Approximate total number of chat invite links found
final

Methods

copyWith({int? totalCount, List<ChatInviteLink>? inviteLinks, dynamic extra, int? clientId}) → ChatInviteLinks
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type