ChatJoinRequest class final

ChatJoinRequest (chatJoinRequest) - basic class

Describes a user that sent a join request and waits for administrator approval.

  • userId: User identifier.
  • date: Point in time (Unix timestamp) when the user sent the join request.
  • bio: A short bio of the user.
Inheritance

Constructors

ChatJoinRequest({required int userId, required int date, required String bio})
ChatJoinRequest (chatJoinRequest) - basic class
const
ChatJoinRequest.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

bio → String
A short bio of the user
final
clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
date → int
Point in time (Unix timestamp) when the user sent the join request
final
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
User identifier
final

Methods

copyWith({int? userId, int? date, String? bio}) → ChatJoinRequest
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type