ChatJoinRequestsInfo class final

ChatJoinRequestsInfo (chatJoinRequestsInfo) - basic class

Contains information about pending join requests for a chat.

  • totalCount: Total number of pending join requests.
  • userIds: Identifiers of at most 3 users sent the newest pending join requests.
Inheritance

Constructors

ChatJoinRequestsInfo({required int totalCount, required List<int> userIds})
ChatJoinRequestsInfo (chatJoinRequestsInfo) - basic class
const
ChatJoinRequestsInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCount → int
Total number of pending join requests
final
userIds → List<int>
Identifiers of at most 3 users sent the newest pending join requests
final

Methods

copyWith({int? totalCount, List<int>? userIds}) → ChatJoinRequestsInfo
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type