ChatMemberStatusCreator class final

ChatMemberStatusCreator (chatMemberStatusCreator) - child of ChatMemberStatus

The user is the owner of the chat and has all the administrator privileges.

  • customTitle: A custom title of the owner; 0-16 characters without emoji; applicable to supergroups only.
  • isAnonymous: True, if the creator isn't shown in the chat member list and sends messages anonymously; applicable to supergroups only.
  • isMember: True, if the user is a member of the chat.
Inheritance

Constructors

ChatMemberStatusCreator({required String customTitle, required bool isAnonymous, required bool isMember})
ChatMemberStatusCreator (chatMemberStatusCreator) - child of ChatMemberStatus
const
ChatMemberStatusCreator.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
customTitle → String
A custom title of the owner; 0-16 characters without emoji; applicable to supergroups only
final
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isAnonymous → bool
True, if the creator isn't shown in the chat member list and sends messages anonymously; applicable to supergroups only
final
isMember → bool
True, if the user is a member of the chat
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? customTitle, bool? isAnonymous, bool? isMember}) → ChatMemberStatusCreator
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type