ChatPermissions class final

ChatPermissions (chatPermissions) - basic class

Describes actions that a user is allowed to take in a chat.

Inheritance

Constructors

ChatPermissions({required bool canSendBasicMessages, required bool canSendAudios, required bool canSendDocuments, required bool canSendPhotos, required bool canSendVideos, required bool canSendVideoNotes, required bool canSendVoiceNotes, required bool canSendPolls, required bool canSendOtherMessages, required bool canAddLinkPreviews, required bool canChangeInfo, required bool canInviteUsers, required bool canPinMessages, required bool canCreateTopics})
ChatPermissions (chatPermissions) - basic class
const
ChatPermissions.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

canAddLinkPreviews → bool
True, if the user may add a link preview to their messages
final
canChangeInfo → bool
True, if the user can change the chat title, photo, and other settings
final
canCreateTopics → bool
True, if the user can create topics
final
canInviteUsers → bool
True, if the user can invite new users to the chat
final
canPinMessages → bool
True, if the user can pin messages
final
canSendAudios → bool
True, if the user can send music files
final
canSendBasicMessages → bool
True, if the user can send text messages, contacts, giveaways, giveaway winners, invoices, locations, and venues
final
canSendDocuments → bool
True, if the user can send documents
final
canSendOtherMessages → bool
True, if the user can send animations, games, stickers, and dice and use inline bots
final
canSendPhotos → bool
True, if the user can send photos
final
canSendPolls → bool
True, if the user can send polls
final
canSendVideoNotes → bool
True, if the user can send video notes
final
canSendVideos → bool
True, if the user can send videos
final
canSendVoiceNotes → bool
True, if the user can send voice notes
final
clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? canSendBasicMessages, bool? canSendAudios, bool? canSendDocuments, bool? canSendPhotos, bool? canSendVideos, bool? canSendVideoNotes, bool? canSendVoiceNotes, bool? canSendPolls, bool? canSendOtherMessages, bool? canAddLinkPreviews, bool? canChangeInfo, bool? canInviteUsers, bool? canPinMessages, bool? canCreateTopics}) → ChatPermissions
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type