ChatStatisticsChannel class final

ChatStatisticsChannel (chatStatisticsChannel) - child of ChatStatistics

A detailed statistics about a channel chat.

Inheritance

Constructors

ChatStatisticsChannel({required DateRange period, required StatisticalValue memberCount, required StatisticalValue meanMessageViewCount, required StatisticalValue meanMessageShareCount, required StatisticalValue meanMessageReactionCount, required StatisticalValue meanStoryViewCount, required StatisticalValue meanStoryShareCount, required StatisticalValue meanStoryReactionCount, required double enabledNotificationsPercentage, required StatisticalGraph memberCountGraph, required StatisticalGraph joinGraph, required StatisticalGraph muteGraph, required StatisticalGraph viewCountByHourGraph, required StatisticalGraph viewCountBySourceGraph, required StatisticalGraph joinBySourceGraph, required StatisticalGraph languageGraph, required StatisticalGraph messageInteractionGraph, required StatisticalGraph messageReactionGraph, required StatisticalGraph storyInteractionGraph, required StatisticalGraph storyReactionGraph, required StatisticalGraph instantViewInteractionGraph, required List<ChatStatisticsInteractionInfo> recentInteractions, dynamic extra, int? clientId})
ChatStatisticsChannel (chatStatisticsChannel) - child of ChatStatistics
const
ChatStatisticsChannel.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
enabledNotificationsPercentage → double
A percentage of users with enabled notifications for the chat; 0-100
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
instantViewInteractionGraph → StatisticalGraph
A graph containing number of views of associated with the chat instant views
final
joinBySourceGraph → StatisticalGraph
A graph containing number of new member joins per source
final
joinGraph → StatisticalGraph
A graph containing number of members joined and left the chat
final
languageGraph → StatisticalGraph
A graph containing number of users viewed chat messages per language
final
meanMessageReactionCount → StatisticalValue
Mean number of times reactions were added to the recently sent messages
final
meanMessageShareCount → StatisticalValue
Mean number of times the recently sent messages were shared
final
meanMessageViewCount → StatisticalValue
Mean number of times the recently sent messages were viewed
final
meanStoryReactionCount → StatisticalValue
Mean number of times reactions were added to the recently sent stories
final
meanStoryShareCount → StatisticalValue
Mean number of times the recently sent stories were shared
final
meanStoryViewCount → StatisticalValue
Mean number of times the recently sent stories were viewed
final
memberCount → StatisticalValue
Number of members in the chat
final
memberCountGraph → StatisticalGraph
A graph containing number of members in the chat
final
messageInteractionGraph → StatisticalGraph
A graph containing number of chat message views and shares
final
messageReactionGraph → StatisticalGraph
A graph containing number of reactions on messages
final
muteGraph → StatisticalGraph
A graph containing number of members muted and unmuted the chat
final
period → DateRange
A period to which the statistics applies
final
recentInteractions → List<ChatStatisticsInteractionInfo>
Detailed statistics about number of views and shares of recently sent messages and stories
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storyInteractionGraph → StatisticalGraph
A graph containing number of story views and shares
final
storyReactionGraph → StatisticalGraph
A graph containing number of reactions on stories
final
viewCountByHourGraph → StatisticalGraph
A graph containing number of message views in a given hour in the last two weeks
final
viewCountBySourceGraph → StatisticalGraph
A graph containing number of message views per source
final

Methods

copyWith({DateRange? period, StatisticalValue? memberCount, StatisticalValue? meanMessageViewCount, StatisticalValue? meanMessageShareCount, StatisticalValue? meanMessageReactionCount, StatisticalValue? meanStoryViewCount, StatisticalValue? meanStoryShareCount, StatisticalValue? meanStoryReactionCount, double? enabledNotificationsPercentage, StatisticalGraph? memberCountGraph, StatisticalGraph? joinGraph, StatisticalGraph? muteGraph, StatisticalGraph? viewCountByHourGraph, StatisticalGraph? viewCountBySourceGraph, StatisticalGraph? joinBySourceGraph, StatisticalGraph? languageGraph, StatisticalGraph? messageInteractionGraph, StatisticalGraph? messageReactionGraph, StatisticalGraph? storyInteractionGraph, StatisticalGraph? storyReactionGraph, StatisticalGraph? instantViewInteractionGraph, List<ChatStatisticsInteractionInfo>? recentInteractions, dynamic extra, int? clientId}) → ChatStatisticsChannel
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type