messageInteractionGraph property
A graph containing number of chat message views and shares
Implementation
final StatisticalGraph messageInteractionGraph;
A graph containing number of chat message views and shares
final StatisticalGraph messageInteractionGraph;