ChatStatisticsSupergroup class final

ChatStatisticsSupergroup (chatStatisticsSupergroup) - child of ChatStatistics

A detailed statistics about a supergroup chat.

  • period: A period to which the statistics applies.
  • memberCount: Number of members in the chat.
  • messageCount: Number of messages sent to the chat.
  • viewerCount: Number of users who viewed messages in the chat.
  • senderCount: Number of users who sent messages to the chat.
  • memberCountGraph: A graph containing number of members in the chat.
  • joinGraph: A graph containing number of members joined and left the chat.
  • joinBySourceGraph: A graph containing number of new member joins per source.
  • languageGraph: A graph containing distribution of active users per language.
  • messageContentGraph: A graph containing distribution of sent messages by content type.
  • actionGraph: A graph containing number of different actions in the chat.
  • dayGraph: A graph containing distribution of message views per hour.
  • weekGraph: A graph containing distribution of message views per day of week.
  • topSenders: List of users sent most messages in the last week.
  • topAdministrators: List of most active administrators in the last week.
  • topInviters: List of most active inviters of new members in the last week.
Inheritance

Constructors

ChatStatisticsSupergroup({required DateRange period, required StatisticalValue memberCount, required StatisticalValue messageCount, required StatisticalValue viewerCount, required StatisticalValue senderCount, required StatisticalGraph memberCountGraph, required StatisticalGraph joinGraph, required StatisticalGraph joinBySourceGraph, required StatisticalGraph languageGraph, required StatisticalGraph messageContentGraph, required StatisticalGraph actionGraph, required StatisticalGraph dayGraph, required StatisticalGraph weekGraph, required List<ChatStatisticsMessageSenderInfo> topSenders, required List<ChatStatisticsAdministratorActionsInfo> topAdministrators, required List<ChatStatisticsInviterInfo> topInviters, dynamic extra, int? clientId})
ChatStatisticsSupergroup (chatStatisticsSupergroup) - child of ChatStatistics
const
ChatStatisticsSupergroup.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

actionGraph → StatisticalGraph
A graph containing number of different actions in the chat
final
clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
dayGraph → StatisticalGraph
A graph containing distribution of message views per hour
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
joinBySourceGraph → StatisticalGraph
A graph containing number of new member joins per source
final
joinGraph → StatisticalGraph
A graph containing number of members joined and left the chat
final
languageGraph → StatisticalGraph
A graph containing distribution of active users per language
final
memberCount → StatisticalValue
Number of members in the chat
final
memberCountGraph → StatisticalGraph
A graph containing number of members in the chat
final
messageContentGraph → StatisticalGraph
A graph containing distribution of sent messages by content type
final
messageCount → StatisticalValue
Number of messages sent to the chat
final
period → DateRange
A period to which the statistics applies
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderCount → StatisticalValue
Number of users who sent messages to the chat
final
topAdministrators → List<ChatStatisticsAdministratorActionsInfo>
List of most active administrators in the last week
final
topInviters → List<ChatStatisticsInviterInfo>
List of most active inviters of new members in the last week
final
topSenders → List<ChatStatisticsMessageSenderInfo>
List of users sent most messages in the last week
final
viewerCount → StatisticalValue
Number of users who viewed messages in the chat
final
weekGraph → StatisticalGraph
A graph containing distribution of message views per day of week
final

Methods

copyWith({DateRange? period, StatisticalValue? memberCount, StatisticalValue? messageCount, StatisticalValue? viewerCount, StatisticalValue? senderCount, StatisticalGraph? memberCountGraph, StatisticalGraph? joinGraph, StatisticalGraph? joinBySourceGraph, StatisticalGraph? languageGraph, StatisticalGraph? messageContentGraph, StatisticalGraph? actionGraph, StatisticalGraph? dayGraph, StatisticalGraph? weekGraph, List<ChatStatisticsMessageSenderInfo>? topSenders, List<ChatStatisticsAdministratorActionsInfo>? topAdministrators, List<ChatStatisticsInviterInfo>? topInviters, dynamic extra, int? clientId}) → ChatStatisticsSupergroup
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type