CheckChatInviteLink class final

CheckChatInviteLink (checkChatInviteLink) - TDLib function

Checks the validity of an invite link for a chat and returns information about the corresponding chat.

ChatInviteLinkInfo is returned on completion.

Inheritance

Constructors

CheckChatInviteLink({required String inviteLink})
CheckChatInviteLink (checkChatInviteLink) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
Invite link to be checked
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? inviteLink}) → CheckChatInviteLink
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type