CheckChatInviteLink constructor

const CheckChatInviteLink({
  1. required String inviteLink,
})

CheckChatInviteLink (checkChatInviteLink) - TDLib function

Checks the validity of an invite link for a chat and returns information about the corresponding chat.

  • inviteLink: Invite link to be checked.

ChatInviteLinkInfo is returned on completion.

Implementation

const CheckChatInviteLink({
  required this.inviteLink,
});