CheckPhoneNumberCode class final

CheckPhoneNumberCode (checkPhoneNumberCode) - TDLib function

Check the authentication code and completes the request for which the code was sent if appropriate.

  • code: Authentication code to check.

Ok is returned on completion.

Inheritance

Constructors

CheckPhoneNumberCode({required String code})
CheckPhoneNumberCode (checkPhoneNumberCode) - TDLib function
const

Properties

code → String
Authentication code to check
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? code}) → CheckPhoneNumberCode
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type