ClickChatSponsoredMessage class final
ClickChatSponsoredMessage (clickChatSponsoredMessage) - TDLib function
Informs TDLib that the user opened the sponsored chat via the button, the name, the photo, or a mention in the sponsored message.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- ClickChatSponsoredMessage
Constructors
- ClickChatSponsoredMessage({required int chatId, required int messageId})
-
ClickChatSponsoredMessage (clickChatSponsoredMessage) - TDLib function
const
Properties
- chatId → int
-
Chat identifier of the sponsored message
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageId → int
-
Identifier of the sponsored message
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageId}) → ClickChatSponsoredMessage - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type