CloseSecretChat class final

CloseSecretChat (closeSecretChat) - TDLib function

Closes a secret chat, effectively transferring its state to secretChatStateClosed.

Ok is returned on completion.

Inheritance

Constructors

CloseSecretChat({required int secretChatId})
CloseSecretChat (closeSecretChat) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretChatId → int
Secret chat identifier
final

Methods

copyWith({int? secretChatId}) → CloseSecretChat
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type