ConnectedWebsite class final

ConnectedWebsite (connectedWebsite) - basic class

Contains information about one website the current user is logged in with Telegram.

  • id: Website identifier.
  • domainName: The domain name of the website.
  • botUserId: User identifier of a bot linked with the website.
  • browser: The version of a browser used to log in.
  • platform: Operating system the browser is running on.
  • logInDate: Point in time (Unix timestamp) when the user was logged in.
  • lastActiveDate: Point in time (Unix timestamp) when obtained authorization was last used.
  • ipAddress: IP address from which the user was logged in, in human-readable format.
  • location: Human-readable description of a country and a region from which the user was logged in, based on the IP address.
Inheritance

Constructors

ConnectedWebsite({required int id, required String domainName, required int botUserId, required String browser, required String platform, required int logInDate, required int lastActiveDate, required String ipAddress, required String location})
ConnectedWebsite (connectedWebsite) - basic class
const
ConnectedWebsite.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

botUserId → int
User identifier of a bot linked with the website
final
browser → String
The version of a browser used to log in
final
clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
domainName → String
The domain name of the website
final
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
Website identifier
final
ipAddress → String
IP address from which the user was logged in, in human-readable format
final
lastActiveDate → int
Point in time (Unix timestamp) when obtained authorization was last used
final
location → String
Human-readable description of a country and a region from which the user was logged in, based on the IP address
final
logInDate → int
Point in time (Unix timestamp) when the user was logged in
final
platform → String
Operating system the browser is running on
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id, String? domainName, int? botUserId, String? browser, String? platform, int? logInDate, int? lastActiveDate, String? ipAddress, String? location}) → ConnectedWebsite
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type