ConnectionStateWaitingForNetwork class final

ConnectionStateWaitingForNetwork (connectionStateWaitingForNetwork) - child of ConnectionState

Waiting for the network to become available. Use setNetworkType to change the available network type.

Inheritance

Constructors

ConnectionStateWaitingForNetwork()
ConnectionStateWaitingForNetwork (connectionStateWaitingForNetwork) - child of ConnectionState
const
ConnectionStateWaitingForNetwork.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith() → ConnectionStateWaitingForNetwork
Copy instance with no modifications.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type