CreateInvoiceLink class final

CreateInvoiceLink (createInvoiceLink) - TDLib function

Creates a link for the given invoice; for bots only.

  • invoice: Information about the invoice of the type inputMessageInvoice.

HttpUrl is returned on completion.

Inheritance

Constructors

CreateInvoiceLink({required InputMessageContent invoice})
CreateInvoiceLink (createInvoiceLink) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
invoice → InputMessageContent
Information about the invoice of the type inputMessageInvoice
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({InputMessageContent? invoice}) → CreateInvoiceLink
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type