CreateNewStickerSet class final

CreateNewStickerSet (createNewStickerSet) - TDLib function

Creates a new sticker set. Returns the newly created sticker set.

  • userId: Sticker set owner; ignored for regular users.
  • title: Sticker set title; 1-64 characters.
  • name: Sticker set name. Can contain only English letters, digits and underscores. Must end with *"by. If empty, then the name returned by getSuggestedStickerSetName will be used automatically.
  • stickerType: Type of the stickers in the set.
  • needsRepainting: Pass true if stickers in the sticker set must be repainted; for custom emoji sticker sets only.
  • stickers: List of stickers to be added to the set; 1-200 stickers for custom emoji sticker sets, and 1-120 stickers otherwise. For TGS stickers, uploadStickerFile must be used before the sticker is shown.
  • source: Source of the sticker set; may be empty if unknown.

StickerSet is returned on completion.

Inheritance

Constructors

CreateNewStickerSet({required int userId, required String title, required String name, required StickerType stickerType, required bool needsRepainting, required List<InputSticker> stickers, required String source})
CreateNewStickerSet (createNewStickerSet) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
name → String
Sticker set name. Can contain only English letters, digits and underscores. Must end with *"by. If empty, then the name returned by getSuggestedStickerSetName will be used automatically
final
needsRepainting → bool
Pass true if stickers in the sticker set must be repainted; for custom emoji sticker sets only
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String
Source of the sticker set; may be empty if unknown
final
stickers → List<InputSticker>
List of stickers to be added to the set; 1-200 stickers for custom emoji sticker sets, and 1-120 stickers otherwise. For TGS stickers, uploadStickerFile must be used before the sticker is shown
final
stickerType → StickerType
Type of the stickers in the set
final
title → String
Sticker set title; 1-64 characters
final
userId → int
Sticker set owner; ignored for regular users
final

Methods

copyWith({int? userId, String? title, String? name, StickerType? stickerType, bool? needsRepainting, List<InputSticker>? stickers, String? source}) → CreateNewStickerSet
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type