CreatedBasicGroupChat class final

CreatedBasicGroupChat (createdBasicGroupChat) - basic class

Contains information about a newly created basic group chat.

Inheritance

Constructors

CreatedBasicGroupChat({required int chatId, required FailedToAddMembers failedToAddMembers, dynamic extra, int? clientId})
CreatedBasicGroupChat (createdBasicGroupChat) - basic class
const
CreatedBasicGroupChat.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
Chat identifier
final
clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
failedToAddMembers → FailedToAddMembers
Information about failed to add members
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, FailedToAddMembers? failedToAddMembers, dynamic extra, int? clientId}) → CreatedBasicGroupChat
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type