CustomRequestResult class final

CustomRequestResult (customRequestResult) - basic class

Contains the result of a custom request.

  • result: A JSON-serialized result.
Inheritance

Constructors

CustomRequestResult({required String result, dynamic extra, int? clientId})
CustomRequestResult (customRequestResult) - basic class
const
CustomRequestResult.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
result → String
A JSON-serialized result
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? result, dynamic extra, int? clientId}) → CustomRequestResult
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type