DeepLinkInfo class final

DeepLinkInfo (deepLinkInfo) - basic class

Contains information about a tg: deep link.

Inheritance

Constructors

DeepLinkInfo({required FormattedText text, required bool needUpdateApplication, dynamic extra, int? clientId})
DeepLinkInfo (deepLinkInfo) - basic class
const
DeepLinkInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
needUpdateApplication → bool
True, if the user must be asked to update the application
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → FormattedText
Text to be shown to the user
final

Methods

copyWith({FormattedText? text, bool? needUpdateApplication, dynamic extra, int? clientId}) → DeepLinkInfo
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type