DeleteLanguagePack class final

DeleteLanguagePack (deleteLanguagePack) - TDLib function

Deletes all information about a language pack in the current localization target. The language pack which is currently in use (including base language pack) or is being synchronized can't be deleted.. Can be called before authorization.

Ok is returned on completion.

Inheritance

Constructors

DeleteLanguagePack({required String languagePackId})
DeleteLanguagePack (deleteLanguagePack) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
languagePackId → String
Identifier of the language pack to delete
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? languagePackId}) → DeleteLanguagePack
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type