DeviceTokenApplePush class final

DeviceTokenApplePush (deviceTokenApplePush) - child of DeviceToken

A token for Apple Push Notification service.

Inheritance

Constructors

DeviceTokenApplePush({required String deviceToken, required bool isAppSandbox})
DeviceTokenApplePush (deviceTokenApplePush) - child of DeviceToken
const
DeviceTokenApplePush.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
deviceToken → String
Device token; may be empty to deregister a device
final
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isAppSandbox → bool
True, if App Sandbox is enabled
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? deviceToken, bool? isAppSandbox}) → DeviceTokenApplePush
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type