DeviceTokenApplePushVoIP class final

DeviceTokenApplePushVoIP (deviceTokenApplePushVoIP) - child of DeviceToken

A token for Apple Push Notification service VoIP notifications.

  • deviceToken: Device token; may be empty to deregister a device.
  • isAppSandbox: True, if App Sandbox is enabled.
  • encrypt: True, if push notifications must be additionally encrypted.
Inheritance

Constructors

DeviceTokenApplePushVoIP({required String deviceToken, required bool isAppSandbox, required bool encrypt})
DeviceTokenApplePushVoIP (deviceTokenApplePushVoIP) - child of DeviceToken
const
DeviceTokenApplePushVoIP.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
deviceToken → String
Device token; may be empty to deregister a device
final
encrypt → bool
True, if push notifications must be additionally encrypted
final
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isAppSandbox → bool
True, if App Sandbox is enabled
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? deviceToken, bool? isAppSandbox, bool? encrypt}) → DeviceTokenApplePushVoIP
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type