DeviceTokenFirebaseCloudMessaging class final

DeviceTokenFirebaseCloudMessaging (deviceTokenFirebaseCloudMessaging) - child of DeviceToken

A token for Firebase Cloud Messaging.

  • token: Device registration token; may be empty to deregister a device.
  • encrypt: True, if push notifications must be additionally encrypted.
Inheritance

Constructors

DeviceTokenFirebaseCloudMessaging({required String token, required bool encrypt})
DeviceTokenFirebaseCloudMessaging (deviceTokenFirebaseCloudMessaging) - child of DeviceToken
const
DeviceTokenFirebaseCloudMessaging.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
encrypt → bool
True, if push notifications must be additionally encrypted
final
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
Device registration token; may be empty to deregister a device
final

Methods

copyWith({String? token, bool? encrypt}) → DeviceTokenFirebaseCloudMessaging
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type