DeviceTokenWebPush class final

DeviceTokenWebPush (deviceTokenWebPush) - child of DeviceToken

A token for web Push API.

  • endpoint: Absolute URL exposed by the push service where the application server can send push messages; may be empty to deregister a device.
  • p256dhBase64url: Base64url-encoded P-256 elliptic curve Diffie-Hellman public key.
  • authBase64url: Base64url-encoded authentication secret.
Inheritance

Constructors

DeviceTokenWebPush({required String endpoint, required String p256dhBase64url, required String authBase64url})
DeviceTokenWebPush (deviceTokenWebPush) - child of DeviceToken
const
DeviceTokenWebPush.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

authBase64url → String
Base64url-encoded authentication secret
final
clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
endpoint → String
Absolute URL exposed by the push service where the application server can send push messages; may be empty to deregister a device
final
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
p256dhBase64url → String
Base64url-encoded P-256 elliptic curve Diffie-Hellman public key
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? endpoint, String? p256dhBase64url, String? authBase64url}) → DeviceTokenWebPush
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type