DraftMessage class final

DraftMessage (draftMessage) - basic class

Contains information about a message draft.

  • replyTo: Information about the message to be replied; must be of the type inputMessageReplyToMessage; may be null if none (optional).
  • date: Point in time (Unix timestamp) when the draft was created.
  • inputMessageText: Content of the message draft; must be of the type inputMessageText, inputMessageVideoNote, or inputMessageVoiceNote.
  • effectId: Identifier of the effect to apply to the message when it is sent; 0 if none.
Inheritance

Constructors

DraftMessage({InputMessageReplyTo? replyTo, required int date, required InputMessageContent inputMessageText, required int effectId})
DraftMessage (draftMessage) - basic class
const
DraftMessage.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
date → int
Point in time (Unix timestamp) when the draft was created
final
effectId → int
Identifier of the effect to apply to the message when it is sent; 0 if none
final
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
inputMessageText → InputMessageContent
Content of the message draft; must be of the type inputMessageText, inputMessageVideoNote, or inputMessageVoiceNote
final
replyTo → InputMessageReplyTo?
Information about the message to be replied; must be of the type inputMessageReplyToMessage; may be null if none
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({InputMessageReplyTo? replyTo, int? date, InputMessageContent? inputMessageText, int? effectId}) → DraftMessage
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type