EditBusinessMessageReplyMarkup class final

EditBusinessMessageReplyMarkup (editBusinessMessageReplyMarkup) - TDLib function

Edits the reply markup of a message sent on behalf of a business account; for bots only.

  • businessConnectionId: Unique identifier of business connection on behalf of which the message was sent.
  • chatId: The chat the message belongs to.
  • messageId: Identifier of the message.
  • replyMarkup: The new message reply markup; pass null if none (optional).

BusinessMessage is returned on completion.

Inheritance

Constructors

EditBusinessMessageReplyMarkup({required String businessConnectionId, required int chatId, required int messageId, ReplyMarkup? replyMarkup})
EditBusinessMessageReplyMarkup (editBusinessMessageReplyMarkup) - TDLib function
const

Properties

businessConnectionId → String
Unique identifier of business connection on behalf of which the message was sent
final
chatId → int
The chat the message belongs to
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
Identifier of the message
final
replyMarkup → ReplyMarkup?
The new message reply markup; pass null if none
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? businessConnectionId, int? chatId, int? messageId, ReplyMarkup? replyMarkup}) → EditBusinessMessageReplyMarkup
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type