EditChatFolder class final

EditChatFolder (editChatFolder) - TDLib function

Edits existing chat folder. Returns information about the edited chat folder.

ChatFolderInfo is returned on completion.

Inheritance

Constructors

EditChatFolder({required int chatFolderId, required ChatFolder folder})
EditChatFolder (editChatFolder) - TDLib function
const

Properties

chatFolderId → int
Chat folder identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
folder → ChatFolder
The edited chat folder
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatFolderId, ChatFolder? folder}) → EditChatFolder
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type