EditCustomLanguagePackInfo class final
EditCustomLanguagePackInfo (editCustomLanguagePackInfo) - TDLib function
Edits information about a custom local language pack in the current localization target. Can be called before authorization.
- info: New information about the custom local language pack.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- EditCustomLanguagePackInfo
Constructors
- EditCustomLanguagePackInfo({required LanguagePackInfo info})
-
EditCustomLanguagePackInfo (editCustomLanguagePackInfo) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- info → LanguagePackInfo
-
New information about the custom local language pack
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{LanguagePackInfo? info}) → EditCustomLanguagePackInfo - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type