EditInlineMessageMedia class final

EditInlineMessageMedia (editInlineMessageMedia) - TDLib function

Edits the content of a message with an animation, an audio, a document, a photo or a video in an inline message sent via a bot; for bots only.

  • inlineMessageId: Inline message identifier.
  • replyMarkup: The new message reply markup; pass null if none; for bots only (optional).
  • inputMessageContent: New content of the message. Must be one of the following types: inputMessageAnimation, inputMessageAudio, inputMessageDocument, inputMessagePhoto or inputMessageVideo.

Ok is returned on completion.

Inheritance

Constructors

EditInlineMessageMedia({required String inlineMessageId, ReplyMarkup? replyMarkup, required InputMessageContent inputMessageContent})
EditInlineMessageMedia (editInlineMessageMedia) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
inlineMessageId → String
Inline message identifier
final
inputMessageContent → InputMessageContent
New content of the message. Must be one of the following types: inputMessageAnimation, inputMessageAudio, inputMessageDocument, inputMessagePhoto or inputMessageVideo
final
replyMarkup → ReplyMarkup?
The new message reply markup; pass null if none; for bots only
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? inlineMessageId, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) → EditInlineMessageMedia
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type