EditMessageCaption constructor

const EditMessageCaption({
  1. required int chatId,
  2. required int messageId,
  3. ReplyMarkup? replyMarkup,
  4. FormattedText? caption,
  5. required bool showCaptionAboveMedia,
})

EditMessageCaption (editMessageCaption) - TDLib function

Edits the message content caption. Returns the edited message after the edit is completed on the server side.

  • chatId: The chat the message belongs to.
  • messageId: Identifier of the message. Use messageProperties.can_be_edited to check whether the message can be edited.
  • replyMarkup: The new message reply markup; pass null if none; for bots only (optional).
  • caption: New message content caption; 0-getOption("message_caption_length_max") characters; pass null to remove caption (optional).
  • showCaptionAboveMedia: Pass true to show the caption above the media; otherwise, the caption will be shown below the media. Can be true only for animation, photo, and video messages.

Message is returned on completion.

Implementation

const EditMessageCaption({
  required this.chatId,
  required this.messageId,
  this.replyMarkup,
  this.caption,
  required this.showCaptionAboveMedia,
});