EditMessageSchedulingState class final

EditMessageSchedulingState (editMessageSchedulingState) - TDLib function

Edits the time when a scheduled message will be sent. Scheduling state of all messages in the same album or forwarded together with the message will be also changed.

  • chatId: The chat the message belongs to.
  • messageId: Identifier of the message. Use messageProperties.can_edit_scheduling_state to check whether the message is suitable.
  • schedulingState: The new message scheduling state; pass null to send the message immediately (optional).

Ok is returned on completion.

Inheritance

Constructors

EditMessageSchedulingState({required int chatId, required int messageId, MessageSchedulingState? schedulingState})
EditMessageSchedulingState (editMessageSchedulingState) - TDLib function
const

Properties

chatId → int
The chat the message belongs to
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
Identifier of the message. Use messageProperties.can_edit_scheduling_state to check whether the message is suitable
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedulingState → MessageSchedulingState?
The new message scheduling state; pass null to send the message immediately
final

Methods

copyWith({int? chatId, int? messageId, MessageSchedulingState? schedulingState}) → EditMessageSchedulingState
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type