EditMessageText class final

EditMessageText (editMessageText) - TDLib function

Edits the text of a message (or a text of a game message). Returns the edited message after the edit is completed on the server side.

  • chatId: The chat the message belongs to.
  • messageId: Identifier of the message. Use messageProperties.can_be_edited to check whether the message can be edited.
  • replyMarkup: The new message reply markup; pass null if none; for bots only (optional).
  • inputMessageContent: New text content of the message. Must be of type inputMessageText.

Message is returned on completion.

Inheritance

Constructors

EditMessageText({required int chatId, required int messageId, ReplyMarkup? replyMarkup, required InputMessageContent inputMessageContent})
EditMessageText (editMessageText) - TDLib function
const

Properties

chatId → int
The chat the message belongs to
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
inputMessageContent → InputMessageContent
New text content of the message. Must be of type inputMessageText
final
messageId → int
Identifier of the message. Use messageProperties.can_be_edited to check whether the message can be edited
final
replyMarkup → ReplyMarkup?
The new message reply markup; pass null if none; for bots only
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) → EditMessageText
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type