EditQuickReplyMessage constructor

const EditQuickReplyMessage({
  1. required int shortcutId,
  2. required int messageId,
  3. required InputMessageContent inputMessageContent,
})

EditQuickReplyMessage (editQuickReplyMessage) - TDLib function

Asynchronously edits the text, media or caption of a quick reply message. Use quickReplyMessage.can_be_edited to check whether a message can be edited.. Text message can be edited only to a text message. The type of message content in an album can't be changed with exception of replacing a photo with a video or vice versa.

  • shortcutId: Unique identifier of the quick reply shortcut with the message.
  • messageId: Identifier of the message.
  • inputMessageContent: New content of the message. Must be one of the following types: inputMessageText, inputMessageAnimation, inputMessageAudio, inputMessageDocument, inputMessagePhoto or inputMessageVideo.

Ok is returned on completion.

Implementation

const EditQuickReplyMessage({
  required this.shortcutId,
  required this.messageId,
  required this.inputMessageContent,
});