EmailAddressAuthenticationCodeInfo class final

EmailAddressAuthenticationCodeInfo (emailAddressAuthenticationCodeInfo) - basic class

Information about the email address authentication code that was sent.

  • emailAddressPattern: Pattern of the email address to which an authentication code was sent.
  • length: Length of the code; 0 if unknown.
Inheritance

Constructors

EmailAddressAuthenticationCodeInfo({required String emailAddressPattern, required int length, dynamic extra, int? clientId})
EmailAddressAuthenticationCodeInfo (emailAddressAuthenticationCodeInfo) - basic class
const
EmailAddressAuthenticationCodeInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
emailAddressPattern → String
Pattern of the email address to which an authentication code was sent
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
length → int
Length of the code; 0 if unknown
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? emailAddressPattern, int? length, dynamic extra, int? clientId}) → EmailAddressAuthenticationCodeInfo
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type