EncryptedPassportElement class final

EncryptedPassportElement (encryptedPassportElement) - basic class

Contains information about an encrypted Telegram Passport element; for bots only.

  • type: Type of Telegram Passport element.
  • data: Encrypted JSON-encoded data about the user.
  • frontSide: The front side of an identity document.
  • reverseSide: The reverse side of an identity document; may be null (optional).
  • selfie: Selfie with the document; may be null (optional).
  • translation: List of files containing a certified English translation of the document.
  • files: List of attached files.
  • value: Unencrypted data, phone number or email address.
  • hash: Hash of the entire element.
Inheritance

Constructors

EncryptedPassportElement({required PassportElementType type, required String data, required DatedFile frontSide, DatedFile? reverseSide, DatedFile? selfie, required List<DatedFile> translation, required List<DatedFile> files, required String value, required String hash})
EncryptedPassportElement (encryptedPassportElement) - basic class
const
EncryptedPassportElement.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
data → String
Encrypted JSON-encoded data about the user
final
extra → dynamic
A sign from TDLib update
no setterinherited
files → List<DatedFile>
List of attached files
final
frontSide → DatedFile
The front side of an identity document
final
hash → String
Hash of the entire element
final
hashCode → int
The hash code for this object.
no setterinherited
reverseSide → DatedFile?
The reverse side of an identity document; may be null
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selfie → DatedFile?
Selfie with the document; may be null
final
translation → List<DatedFile>
List of files containing a certified English translation of the document
final
type → PassportElementType
Type of Telegram Passport element
final
value → String
Unencrypted data, phone number or email address
final

Methods

copyWith({PassportElementType? type, String? data, DatedFile? frontSide, DatedFile? reverseSide, DatedFile? selfie, List<DatedFile>? translation, List<DatedFile>? files, String? value, String? hash}) → EncryptedPassportElement
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type