FailedToAddMember class final

FailedToAddMember (failedToAddMember) - basic class

Contains information about a user that has failed to be added to a chat.

Inheritance

Constructors

FailedToAddMember({required int userId, required bool premiumWouldAllowInvite, required bool premiumRequiredToSendMessages})
FailedToAddMember (failedToAddMember) - basic class
const
FailedToAddMember.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
premiumRequiredToSendMessages → bool
True, if subscription to Telegram Premium is required to send the user chat invite link
final
premiumWouldAllowInvite → bool
True, if subscription to Telegram Premium would have allowed to add the user to the chat
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
User identifier
final

Methods

copyWith({int? userId, bool? premiumWouldAllowInvite, bool? premiumRequiredToSendMessages}) → FailedToAddMember
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type