FirebaseAuthenticationSettingsIos class final
FirebaseAuthenticationSettingsIos (firebaseAuthenticationSettingsIos) - child of FirebaseAuthenticationSettings
Settings for Firebase Authentication in the official iOS application.
- deviceToken: Device token from Apple Push Notification service.
- isAppSandbox: True, if App Sandbox is enabled.
- Inheritance
-
- Object
- TdObject
- FirebaseAuthenticationSettings
- FirebaseAuthenticationSettingsIos
Constructors
- FirebaseAuthenticationSettingsIos({required String deviceToken, required bool isAppSandbox})
-
FirebaseAuthenticationSettingsIos (firebaseAuthenticationSettingsIos) - child of FirebaseAuthenticationSettings
const
-
FirebaseAuthenticationSettingsIos.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- deviceToken → String
-
Device token from Apple Push Notification service
final
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAppSandbox → bool
-
True, if App Sandbox is enabled
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? deviceToken, bool? isAppSandbox}) → FirebaseAuthenticationSettingsIos -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type