ForumTopics class final

ForumTopics (forumTopics) - basic class

Describes a list of forum topics.

Inheritance

Constructors

ForumTopics({required int totalCount, required List<ForumTopic> topics, required int nextOffsetDate, required int nextOffsetMessageId, required int nextOffsetMessageThreadId, dynamic extra, int? clientId})
ForumTopics (forumTopics) - basic class
const
ForumTopics.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
nextOffsetDate → int
Offset date for the next getForumTopics request
final
nextOffsetMessageId → int
Offset message identifier for the next getForumTopics request
final
nextOffsetMessageThreadId → int
Offset message thread identifier for the next getForumTopics request
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topics → List<ForumTopic>
List of forum topics
final
totalCount → int
Approximate total number of forum topics found
final

Methods

copyWith({int? totalCount, List<ForumTopic>? topics, int? nextOffsetDate, int? nextOffsetMessageId, int? nextOffsetMessageThreadId, dynamic extra, int? clientId}) → ForumTopics
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type