FoundPosition class final

FoundPosition (foundPosition) - basic class

Contains 0-based match position.

Inheritance

Constructors

FoundPosition({required int position, dynamic extra, int? clientId})
FoundPosition (foundPosition) - basic class
const
FoundPosition.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
position → int
The position of the match
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? position, dynamic extra, int? clientId}) → FoundPosition
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type