GetBasicGroup class final

GetBasicGroup (getBasicGroup) - TDLib function

Returns information about a basic group by its identifier. This is an offline request if the current user is not a bot.

BasicGroup is returned on completion.

Inheritance

Constructors

GetBasicGroup({required int basicGroupId})
GetBasicGroup (getBasicGroup) - TDLib function
const

Properties

basicGroupId → int
Basic group identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? basicGroupId}) → GetBasicGroup
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type