GetBotMediaPreviews class final
GetBotMediaPreviews (getBotMediaPreviews) - TDLib function
Returns the list of media previews of a bot.
- botUserId: Identifier of the target bot. The bot must have the main Web App.
BotMediaPreviews is returned on completion.
- Inheritance
-
- Object
- TdFunction
- GetBotMediaPreviews
Constructors
- GetBotMediaPreviews({required int botUserId})
-
GetBotMediaPreviews (getBotMediaPreviews) - TDLib function
const
Properties
- botUserId → int
-
Identifier of the target bot. The bot must have the main Web App
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? botUserId}) → GetBotMediaPreviews - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type