GetBusinessConnectedBot class final

GetBusinessConnectedBot (getBusinessConnectedBot) - TDLib function

Returns the business bot that is connected to the current user account. Returns a 404 error if there is no connected bot.

BusinessConnectedBot is returned on completion.

Inheritance

Constructors

GetBusinessConnectedBot()
GetBusinessConnectedBot (getBusinessConnectedBot) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith() → GetBusinessConnectedBot
Copy instance with no modifications.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type