GetChatBoostFeatures class final

GetChatBoostFeatures (getChatBoostFeatures) - TDLib function

Returns the list of features available for different chat boost levels; this is an offline request.

  • isChannel: Pass true to get the list of features for channels; pass false to get the list of features for supergroups.

ChatBoostFeatures is returned on completion.

Inheritance

Constructors

GetChatBoostFeatures({required bool isChannel})
GetChatBoostFeatures (getChatBoostFeatures) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
isChannel → bool
Pass true to get the list of features for channels; pass false to get the list of features for supergroups
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isChannel}) → GetChatBoostFeatures
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type