GetChatFolderDefaultIconName class final
GetChatFolderDefaultIconName (getChatFolderDefaultIconName) - TDLib function
Returns default icon name for a folder. Can be called synchronously.
- folder: Chat folder.
ChatFolderIcon is returned on completion.
- Inheritance
-
- Object
- TdFunction
- GetChatFolderDefaultIconName
Constructors
- GetChatFolderDefaultIconName({required ChatFolder folder})
-
GetChatFolderDefaultIconName (getChatFolderDefaultIconName) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- folder → ChatFolder
-
Chat folder
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ChatFolder? folder}) → GetChatFolderDefaultIconName - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type