GetChatJoinRequests class final

GetChatJoinRequests (getChatJoinRequests) - TDLib function

Returns pending join requests in a chat.

  • chatId: Chat identifier.
  • inviteLink: Invite link for which to return join requests. If empty, all join requests will be returned. Requires administrator privileges and can_invite_users right in the chat for own links and owner privileges for other links.
  • query: A query to search for in the first names, last names and usernames of the users to return.
  • offsetRequest: A chat join request from which to return next requests; pass null to get results from the beginning (optional).
  • limit: The maximum number of requests to join the chat to return.

ChatJoinRequests is returned on completion.

Inheritance

Constructors

GetChatJoinRequests({required int chatId, required String inviteLink, required String query, ChatJoinRequest? offsetRequest, required int limit})
GetChatJoinRequests (getChatJoinRequests) - TDLib function
const

Properties

chatId → int
Chat identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
Invite link for which to return join requests. If empty, all join requests will be returned. Requires administrator privileges and can_invite_users right in the chat for own links and owner privileges for other links
final
limit → int
The maximum number of requests to join the chat to return
final
offsetRequest → ChatJoinRequest?
A chat join request from which to return next requests; pass null to get results from the beginning
final
query → String
A query to search for in the first names, last names and usernames of the users to return
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, String? inviteLink, String? query, ChatJoinRequest? offsetRequest, int? limit}) → GetChatJoinRequests
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type