GetChatMessagePosition constructor
const
GetChatMessagePosition({
- required int chatId,
- required int messageId,
- required SearchMessagesFilter filter,
- required int messageThreadId,
- required int savedMessagesTopicId,
GetChatMessagePosition (getChatMessagePosition) - TDLib function
Returns approximate 1-based position of a message among messages, which can be found by the specified filter in the chat. Cannot be used in secret chats.
chatId: Identifier of the chat in which to find message position.messageId: Message identifier.filter: Filter for message content; searchMessagesFilterEmpty, searchMessagesFilterUnreadMention, searchMessagesFilterUnreadReaction, and searchMessagesFilterFailedToSend are unsupported in this function.messageThreadId: If not 0, only messages in the specified thread will be considered; supergroups only.savedMessagesTopicId: If not 0, only messages in the specified Saved Messages topic will be considered; pass 0 to consider all relevant messages, or for chats other than Saved Messages.
Count is returned on completion.
Implementation
const GetChatMessagePosition({
required this.chatId,
required this.messageId,
required this.filter,
required this.messageThreadId,
required this.savedMessagesTopicId,
});