GetChatRevenueStatistics class final

GetChatRevenueStatistics (getChatRevenueStatistics) - TDLib function

Returns detailed revenue statistics about a chat. Currently, this method can be used only for channels if supergroupFullInfo.can_get_revenue_statistics == true.

  • chatId: Chat identifier.
  • isDark: Pass true if a dark theme is used by the application.

ChatRevenueStatistics is returned on completion.

Inheritance

Constructors

GetChatRevenueStatistics({required int chatId, required bool isDark})
GetChatRevenueStatistics (getChatRevenueStatistics) - TDLib function
const

Properties

chatId → int
Chat identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
isDark → bool
Pass true if a dark theme is used by the application
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, bool? isDark}) → GetChatRevenueStatistics
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type