GetChatRevenueStatistics constructor
GetChatRevenueStatistics (getChatRevenueStatistics) - TDLib function
Returns detailed revenue statistics about a chat. Currently, this method can be used only for channels if supergroupFullInfo.can_get_revenue_statistics == true.
chatId: Chat identifier.isDark: Pass true if a dark theme is used by the application.
ChatRevenueStatistics is returned on completion.
Implementation
const GetChatRevenueStatistics({
required this.chatId,
required this.isDark,
});