GetChatSimilarChatCount class final

GetChatSimilarChatCount (getChatSimilarChatCount) - TDLib function

Returns approximate number of chats similar to the given chat.

  • chatId: Identifier of the target chat; must be an identifier of a channel chat.
  • returnLocal: Pass true to get the number of chats without sending network requests, or -1 if the number of chats is unknown locally.

Count is returned on completion.

Inheritance

Constructors

GetChatSimilarChatCount({required int chatId, required bool returnLocal})
GetChatSimilarChatCount (getChatSimilarChatCount) - TDLib function
const

Properties

chatId → int
Identifier of the target chat; must be an identifier of a channel chat
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
returnLocal → bool
Pass true to get the number of chats without sending network requests, or -1 if the number of chats is unknown locally
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, bool? returnLocal}) → GetChatSimilarChatCount
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type