GetChatsForChatFolderInviteLink class final

GetChatsForChatFolderInviteLink (getChatsForChatFolderInviteLink) - TDLib function

Returns identifiers of chats from a chat folder, suitable for adding to a chat folder invite link.

Chats is returned on completion.

Inheritance

Constructors

GetChatsForChatFolderInviteLink({required int chatFolderId})
GetChatsForChatFolderInviteLink (getChatsForChatFolderInviteLink) - TDLib function
const

Properties

chatFolderId → int
Chat folder identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatFolderId}) → GetChatsForChatFolderInviteLink
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type