GetDefaultChatPhotoCustomEmojiStickers class final

GetDefaultChatPhotoCustomEmojiStickers (getDefaultChatPhotoCustomEmojiStickers) - TDLib function

Returns default list of custom emoji stickers for placing on a chat photo.

Stickers is returned on completion.

Inheritance

Constructors

GetDefaultChatPhotoCustomEmojiStickers()
GetDefaultChatPhotoCustomEmojiStickers (getDefaultChatPhotoCustomEmojiStickers) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith() → GetDefaultChatPhotoCustomEmojiStickers
Copy instance with no modifications.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type