GetFile class final

GetFile (getFile) - TDLib function

Returns information about a file; this is an offline request.

  • fileId: Identifier of the file to get.

File is returned on completion.

Inheritance

Constructors

GetFile({required int fileId})
GetFile (getFile) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
fileId → int
Identifier of the file to get
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? fileId}) → GetFile
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type