offsetMessageThreadId property
The message thread identifier of the last found topic, or 0 for the first request
Implementation
final int offsetMessageThreadId;
The message thread identifier of the last found topic, or 0 for the first request
final int offsetMessageThreadId;