GetGroupCallStreamSegment class final

GetGroupCallStreamSegment (getGroupCallStreamSegment) - TDLib function

Returns a file with a segment of a group call stream in a modified OGG format for audio or MPEG-4 format for video.

  • groupCallId: Group call identifier.
  • timeOffset: Point in time when the stream segment begins; Unix timestamp in milliseconds.
  • scale: Segment duration scale; 0-1. Segment's duration is 1000/(2**scale) milliseconds.
  • channelId: Identifier of an audio/video channel to get as received from tgcalls.
  • videoQuality: Video quality as received from tgcalls; pass null to get the worst available quality (optional).

FilePart is returned on completion.

Inheritance

Constructors

GetGroupCallStreamSegment({required int groupCallId, required int timeOffset, required int scale, required int channelId, GroupCallVideoQuality? videoQuality})
GetGroupCallStreamSegment (getGroupCallStreamSegment) - TDLib function
const

Properties

channelId → int
Identifier of an audio/video channel to get as received from tgcalls
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
groupCallId → int
Group call identifier
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → int
Segment duration scale; 0-1. Segment's duration is 1000/(2**scale) milliseconds
final
timeOffset → int
Point in time when the stream segment begins; Unix timestamp in milliseconds
final
videoQuality → GroupCallVideoQuality?
Video quality as received from tgcalls; pass null to get the worst available quality
final

Methods

copyWith({int? groupCallId, int? timeOffset, int? scale, int? channelId, GroupCallVideoQuality? videoQuality}) → GetGroupCallStreamSegment
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type