GetGroupCallStreams class final

GetGroupCallStreams (getGroupCallStreams) - TDLib function

Returns information about available group call streams.

GroupCallStreams is returned on completion.

Inheritance

Constructors

GetGroupCallStreams({required int groupCallId})
GetGroupCallStreams (getGroupCallStreams) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
groupCallId → int
Group call identifier
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId}) → GetGroupCallStreams
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type