GetInlineQueryResults class final

GetInlineQueryResults (getInlineQueryResults) - TDLib function

Sends an inline query to a bot and returns its results. Returns an error with code 502 if the bot fails to answer the query before the query timeout expires.

  • botUserId: Identifier of the target bot.
  • chatId: Identifier of the chat where the query was sent.
  • userLocation: Location of the user; pass null if unknown or the bot doesn't need user's location (optional).
  • query: Text of the query.
  • offset: Offset of the first entry to return; use empty string to get the first chunk of results.

InlineQueryResults is returned on completion.

Inheritance

Constructors

GetInlineQueryResults({required int botUserId, required int chatId, Location? userLocation, required String query, required String offset})
GetInlineQueryResults (getInlineQueryResults) - TDLib function
const

Properties

botUserId → int
Identifier of the target bot
final
chatId → int
Identifier of the chat where the query was sent
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
offset → String
Offset of the first entry to return; use empty string to get the first chunk of results
final
query → String
Text of the query
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userLocation → Location?
Location of the user; pass null if unknown or the bot doesn't need user's location
final

Methods

copyWith({int? botUserId, int? chatId, Location? userLocation, String? query, String? offset}) → GetInlineQueryResults
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type