GetMarkdownText class final
GetMarkdownText (getMarkdownText) - TDLib function
Replaces text entities with Markdown formatting in a human-friendly format. Entities that can't be represented in Markdown unambiguously are kept as is. Can be called synchronously.
- text: The text.
FormattedText is returned on completion.
- Inheritance
-
- Object
- TdFunction
- GetMarkdownText
Constructors
- GetMarkdownText({required FormattedText text})
-
GetMarkdownText (getMarkdownText) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → FormattedText
-
The text
final
Methods
-
copyWith(
{FormattedText? text}) → GetMarkdownText - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type