GetMe (getMe) - TDLib function
Returns the current user.
User is returned on completion.
Constructors
-
GetMe()
-
GetMe (getMe) - TDLib function
const
Properties
-
currentObjectId
→ String
-
TDLib object type for current class instance
no setteroverride
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith()
→ GetMe
-
Copy instance with no modifications.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson([])
→ Map<String, dynamic>
-
Convert model to TDLib JSON format
override
-
toString()
→ String
-
Convert model to TDLib JSON format, encoded into String.
override