GetMessageImportConfirmationText class final

GetMessageImportConfirmationText (getMessageImportConfirmationText) - TDLib function

Returns a confirmation text to be shown to the user before starting message import.

  • chatId: Identifier of a chat to which the messages will be imported. It must be an identifier of a private chat with a mutual contact or an identifier of a supergroup chat with can_change_info member right.

Text is returned on completion.

Inheritance

Constructors

GetMessageImportConfirmationText({required int chatId})
GetMessageImportConfirmationText (getMessageImportConfirmationText) - TDLib function
const

Properties

chatId → int
Identifier of a chat to which the messages will be imported. It must be an identifier of a private chat with a mutual contact or an identifier of a supergroup chat with can_change_info member right
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId}) → GetMessageImportConfirmationText
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type