GetMessageLink class final

GetMessageLink (getMessageLink) - TDLib function

Returns an HTTPS link to a message in a chat. Available only if messageProperties.can_get_link, or if messageProperties.can_get_media_timestamp_links and a media timestamp link is generated. This is an offline request.

  • chatId: Identifier of the chat to which the message belongs.
  • messageId: Identifier of the message.
  • mediaTimestamp: If not 0, timestamp from which the video/audio/video note/voice note/story playing must start, in seconds. The media can be in the message content or in its link preview.
  • forAlbum: Pass true to create a link for the whole media album.
  • inMessageThread: Pass true to create a link to the message as a channel post comment, in a message thread, or a forum topic.

MessageLink is returned on completion.

Inheritance

Constructors

GetMessageLink({required int chatId, required int messageId, required int mediaTimestamp, required bool forAlbum, required bool inMessageThread})
GetMessageLink (getMessageLink) - TDLib function
const

Properties

chatId → int
Identifier of the chat to which the message belongs
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
forAlbum → bool
Pass true to create a link for the whole media album
final
hashCode → int
The hash code for this object.
no setterinherited
inMessageThread → bool
Pass true to create a link to the message as a channel post comment, in a message thread, or a forum topic
final
mediaTimestamp → int
If not 0, timestamp from which the video/audio/video note/voice note/story playing must start, in seconds. The media can be in the message content or in its link preview
final
messageId → int
Identifier of the message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, int? mediaTimestamp, bool? forAlbum, bool? inMessageThread}) → GetMessageLink
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type