GetMessageLink constructor

const GetMessageLink({
  1. required int chatId,
  2. required int messageId,
  3. required int mediaTimestamp,
  4. required bool forAlbum,
  5. required bool inMessageThread,
})

GetMessageLink (getMessageLink) - TDLib function

Returns an HTTPS link to a message in a chat. Available only if messageProperties.can_get_link, or if messageProperties.can_get_media_timestamp_links and a media timestamp link is generated. This is an offline request.

  • chatId: Identifier of the chat to which the message belongs.
  • messageId: Identifier of the message.
  • mediaTimestamp: If not 0, timestamp from which the video/audio/video note/voice note/story playing must start, in seconds. The media can be in the message content or in its link preview.
  • forAlbum: Pass true to create a link for the whole media album.
  • inMessageThread: Pass true to create a link to the message as a channel post comment, in a message thread, or a forum topic.

MessageLink is returned on completion.

Implementation

const GetMessageLink({
  required this.chatId,
  required this.messageId,
  required this.mediaTimestamp,
  required this.forAlbum,
  required this.inMessageThread,
});