GetPremiumFeatures class final

GetPremiumFeatures (getPremiumFeatures) - TDLib function

Returns information about features, available to Premium users.

  • source: Source of the request; pass null if the method is called from some non-standard source (optional).

PremiumFeatures is returned on completion.

Inheritance

Constructors

GetPremiumFeatures({PremiumSource? source})
GetPremiumFeatures (getPremiumFeatures) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → PremiumSource?
Source of the request; pass null if the method is called from some non-standard source
final

Methods

copyWith({PremiumSource? source}) → GetPremiumFeatures
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type