GetPremiumGiftCodePaymentOptions class final

GetPremiumGiftCodePaymentOptions (getPremiumGiftCodePaymentOptions) - TDLib function

Returns available options for Telegram Premium gift code or Telegram Premium giveaway creation.

  • boostedChatId: Identifier of the supergroup or channel chat, which will be automatically boosted by receivers of the gift codes and which is administered by the user; 0 if none.

PremiumGiftCodePaymentOptions is returned on completion.

Inheritance

Constructors

GetPremiumGiftCodePaymentOptions({required int boostedChatId})
GetPremiumGiftCodePaymentOptions (getPremiumGiftCodePaymentOptions) - TDLib function
const

Properties

boostedChatId → int
Identifier of the supergroup or channel chat, which will be automatically boosted by receivers of the gift codes and which is administered by the user; 0 if none
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? boostedChatId}) → GetPremiumGiftCodePaymentOptions
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type