boostedChatId property

int boostedChatId
final

Identifier of the supergroup or channel chat, which will be automatically boosted by receivers of the gift codes and which is administered by the user; 0 if none

Implementation

final int boostedChatId;