GetPremiumState class final

GetPremiumState (getPremiumState) - TDLib function

Returns state of Telegram Premium subscription and promotion videos for Premium features.

PremiumState is returned on completion.

Inheritance

Constructors

GetPremiumState()
GetPremiumState (getPremiumState) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith() → GetPremiumState
Copy instance with no modifications.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type