GetRecentStickers class final

GetRecentStickers (getRecentStickers) - TDLib function

Returns a list of recently used stickers.

  • isAttached: Pass true to return stickers and masks that were recently attached to photos or video files; pass false to return recently sent stickers.

Stickers is returned on completion.

Inheritance

Constructors

GetRecentStickers({required bool isAttached})
GetRecentStickers (getRecentStickers) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
isAttached → bool
Pass true to return stickers and masks that were recently attached to photos or video files; pass false to return recently sent stickers
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isAttached}) → GetRecentStickers
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type