GetSavedNotificationSound class final

GetSavedNotificationSound (getSavedNotificationSound) - TDLib function

Returns saved notification sound by its identifier. Returns a 404 error if there is no saved notification sound with the specified identifier.

NotificationSounds is returned on completion.

Inheritance

Constructors

GetSavedNotificationSound({required int notificationSoundId})
GetSavedNotificationSound (getSavedNotificationSound) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
notificationSoundId → int
Identifier of the notification sound
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? notificationSoundId}) → GetSavedNotificationSound
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type