GetStarSubscriptions class final

GetStarSubscriptions (getStarSubscriptions) - TDLib function

Returns the list of Telegram Star subscriptions for the current user.

  • onlyExpiring: Pass true to receive only expiring subscriptions for which there are no enough Telegram Stars to extend.
  • offset: Offset of the first subscription to return as received from the previous request; use empty string to get the first chunk of results.

StarSubscriptions is returned on completion.

Inheritance

Constructors

GetStarSubscriptions({required bool onlyExpiring, required String offset})
GetStarSubscriptions (getStarSubscriptions) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
offset → String
Offset of the first subscription to return as received from the previous request; use empty string to get the first chunk of results
final
onlyExpiring → bool
Pass true to receive only expiring subscriptions for which there are no enough Telegram Stars to extend
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? onlyExpiring, String? offset}) → GetStarSubscriptions
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type