GetStickerSet class final

GetStickerSet (getStickerSet) - TDLib function

Returns information about a sticker set by its identifier.

  • setId: Identifier of the sticker set.

StickerSet is returned on completion.

Inheritance

Constructors

GetStickerSet({required int setId})
GetStickerSet (getStickerSet) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setId → int
Identifier of the sticker set
final

Methods

copyWith({int? setId}) → GetStickerSet
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type