GetSuggestedFileName class final
GetSuggestedFileName (getSuggestedFileName) - TDLib function
Returns suggested name for saving a file in a given directory.
Text is returned on completion.
- Inheritance
-
- Object
- TdFunction
- GetSuggestedFileName
Constructors
- GetSuggestedFileName({required int fileId, required String directory})
-
GetSuggestedFileName (getSuggestedFileName) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- directory → String
-
Directory in which the file is supposed to be saved
final
- fileId → int
-
Identifier of the file
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? fileId, String? directory}) → GetSuggestedFileName - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type