GroupCallVideoSourceGroup class final

GroupCallVideoSourceGroup (groupCallVideoSourceGroup) - basic class

Describes a group of video synchronization source identifiers.

  • semantics: The semantics of sources, one of "SIM" or "FgroupCallVideoSourceGroup".
  • sourceIds: The list of synchronization source identifiers.
Inheritance

Constructors

GroupCallVideoSourceGroup({required String semantics, required List<int> sourceIds})
GroupCallVideoSourceGroup (groupCallVideoSourceGroup) - basic class
const
GroupCallVideoSourceGroup.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semantics → String
The semantics of sources, one of "SIM" or "FgroupCallVideoSourceGroup"
final
sourceIds → List<int>
The list of synchronization source identifiers
final

Methods

copyWith({String? semantics, List<int>? sourceIds}) → GroupCallVideoSourceGroup
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type