InputInlineQueryResultAudio class final

InputInlineQueryResultAudio (inputInlineQueryResultAudio) - child of InputInlineQueryResult

Represents a link to an MP3 audio file.

  • id: Unique identifier of the query result.
  • title: Title of the audio file.
  • performer: Performer of the audio file.
  • audioUrl: The URL of the audio file.
  • audioDuration: Audio file duration, in seconds.
  • replyMarkup: The message reply markup; pass null if none. Must be of type replyMarkupInlineKeyboard or null (optional).
  • inputMessageContent: The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageAudio, inputMessageInvoice, inputMessageLocation, inputMessageVenue or inputMessageContact.
Inheritance

Constructors

InputInlineQueryResultAudio({required String id, required String title, required String performer, required String audioUrl, required int audioDuration, ReplyMarkup? replyMarkup, required InputMessageContent inputMessageContent})
InputInlineQueryResultAudio (inputInlineQueryResultAudio) - child of InputInlineQueryResult
const
InputInlineQueryResultAudio.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

audioDuration → int
Audio file duration, in seconds
final
audioUrl → String
The URL of the audio file
final
clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
Unique identifier of the query result
final
inputMessageContent → InputMessageContent
The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageAudio, inputMessageInvoice, inputMessageLocation, inputMessageVenue or inputMessageContact
final
performer → String
Performer of the audio file
final
replyMarkup → ReplyMarkup?
The message reply markup; pass null if none. Must be of type replyMarkupInlineKeyboard or null
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
Title of the audio file
final

Methods

copyWith({String? id, String? title, String? performer, String? audioUrl, int? audioDuration, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) → InputInlineQueryResultAudio
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type