InputInlineQueryResultDocument class final

InputInlineQueryResultDocument (inputInlineQueryResultDocument) - child of InputInlineQueryResult

Represents a link to a file.

  • id: Unique identifier of the query result.
  • title: Title of the resulting file.
  • description: Short description of the result, if known.
  • documentUrl: URL of the file.
  • mimeType: MIME type of the file content; only "application/pdf" and "application/zip" are currently allowed.
  • thumbnailUrl: The URL of the file thumbnail, if it exists.
  • thumbnailWidth: Width of the thumbnail.
  • thumbnailHeight: Height of the thumbnail.
  • replyMarkup: The message reply markup; pass null if none. Must be of type replyMarkupInlineKeyboard or null (optional).
  • inputMessageContent: The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageDocument, inputMessageInvoice, inputMessageLocation, inputMessageVenue or inputMessageContact.
Inheritance

Constructors

InputInlineQueryResultDocument({required String id, required String title, required String description, required String documentUrl, required String mimeType, required String thumbnailUrl, required int thumbnailWidth, required int thumbnailHeight, ReplyMarkup? replyMarkup, required InputMessageContent inputMessageContent})
InputInlineQueryResultDocument (inputInlineQueryResultDocument) - child of InputInlineQueryResult
const
InputInlineQueryResultDocument.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
description → String
Short description of the result, if known
final
documentUrl → String
URL of the file
final
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
Unique identifier of the query result
final
inputMessageContent → InputMessageContent
The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageDocument, inputMessageInvoice, inputMessageLocation, inputMessageVenue or inputMessageContact
final
mimeType → String
MIME type of the file content; only "application/pdf" and "application/zip" are currently allowed
final
replyMarkup → ReplyMarkup?
The message reply markup; pass null if none. Must be of type replyMarkupInlineKeyboard or null
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnailHeight → int
Height of the thumbnail
final
thumbnailUrl → String
The URL of the file thumbnail, if it exists
final
thumbnailWidth → int
Width of the thumbnail
final
title → String
Title of the resulting file
final

Methods

copyWith({String? id, String? title, String? description, String? documentUrl, String? mimeType, String? thumbnailUrl, int? thumbnailWidth, int? thumbnailHeight, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) → InputInlineQueryResultDocument
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type