showCaptionAboveMedia property

bool showCaptionAboveMedia
final

True, if the caption must be shown above the animation; otherwise, the caption must be shown below the animation; not supported in secret chats

Implementation

final bool showCaptionAboveMedia;