InputMessageLocation class final

InputMessageLocation (inputMessageLocation) - child of InputMessageContent

A message with a location.

  • location: Location to be sent.
  • livePeriod: Period for which the location can be updated, in seconds; must be between 60 and 86400 for a temporary live location, 0x7FFFFFFF for permanent live location, and 0 otherwise.
  • heading: For live locations, a direction in which the location moves, in degrees; 1-360. Pass 0 if unknown.
  • proximityAlertRadius: For live locations, a maximum distance to another chat member for proximity alerts, in meters (0-100000). Pass 0 if the notification is disabled. Can't be enabled in channels and Saved Messages.
Inheritance

Constructors

InputMessageLocation({required Location location, required int livePeriod, required int heading, required int proximityAlertRadius})
InputMessageLocation (inputMessageLocation) - child of InputMessageContent
const
InputMessageLocation.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
heading → int
For live locations, a direction in which the location moves, in degrees; 1-360. Pass 0 if unknown
final
livePeriod → int
Period for which the location can be updated, in seconds; must be between 60 and 86400 for a temporary live location, 0x7FFFFFFF for permanent live location, and 0 otherwise
final
location → Location
Location to be sent
final
proximityAlertRadius → int
For live locations, a maximum distance to another chat member for proximity alerts, in meters (0-100000). Pass 0 if the notification is disabled. Can't be enabled in channels and Saved Messages
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Location? location, int? livePeriod, int? heading, int? proximityAlertRadius}) → InputMessageLocation
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type