hasSpoiler property
True, if the photo preview must be covered by a spoiler animation; not supported in secret chats
Implementation
final bool hasSpoiler;
True, if the photo preview must be covered by a spoiler animation; not supported in secret chats
final bool hasSpoiler;