InputMessageReplyToMessage constructor

const InputMessageReplyToMessage({
  1. required int messageId,
  2. InputTextQuote? quote,
})

InputMessageReplyToMessage (inputMessageReplyToMessage) - child of InputMessageReplyTo

Describes a message to be replied in the same chat and forum topic.

  • messageId: The identifier of the message to be replied in the same chat and forum topic. A message can be replied in the same chat and forum topic only if messageProperties.can_be_replied.
  • quote: Quote from the message to be replied; pass null if none. Must always be null for replies in secret chats (optional).

Implementation

const InputMessageReplyToMessage({
  required this.messageId,
  this.quote,
});