InputMessageStory class final

InputMessageStory (inputMessageStory) - child of InputMessageContent

A message with a forwarded story. Stories can't be sent to secret chats. A story can be forwarded only if story.can_be_forwarded.

Inheritance

Constructors

InputMessageStory({required int storySenderChatId, required int storyId})
InputMessageStory (inputMessageStory) - child of InputMessageContent
const
InputMessageStory.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storyId → int
Story identifier
final
storySenderChatId → int
Identifier of the chat that posted the story
final

Methods

copyWith({int? storySenderChatId, int? storyId}) → InputMessageStory
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type