InputMessageVenue class final

InputMessageVenue (inputMessageVenue) - child of InputMessageContent

A message with information about a venue.

Inheritance

Constructors

InputMessageVenue({required Venue venue})
InputMessageVenue (inputMessageVenue) - child of InputMessageContent
const
InputMessageVenue.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
venue → Venue
Venue to send
final

Methods

copyWith({Venue? venue}) → InputMessageVenue
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type