InputPassportElementEmailAddress class final

InputPassportElementEmailAddress (inputPassportElementEmailAddress) - child of InputPassportElement

A Telegram Passport element to be saved containing the user's email address.

Inheritance

Constructors

InputPassportElementEmailAddress({required String emailAddress})
InputPassportElementEmailAddress (inputPassportElementEmailAddress) - child of InputPassportElement
const
InputPassportElementEmailAddress.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
emailAddress → String
The email address to be saved
final
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? emailAddress}) → InputPassportElementEmailAddress
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type