InputPassportElementError class final

InputPassportElementError (inputPassportElementError) - basic class

Contains the description of an error in a Telegram Passport element; for bots only.

  • type: Type of Telegram Passport element that has the error.
  • message: Error message.
  • source: Error source.
Inheritance

Constructors

InputPassportElementError({required PassportElementType type, required String message, required InputPassportElementErrorSource source})
InputPassportElementError (inputPassportElementError) - basic class
const
InputPassportElementError.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
Error message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → InputPassportElementErrorSource
Error source
final
type → PassportElementType
Type of Telegram Passport element that has the error
final

Methods

copyWith({PassportElementType? type, String? message, InputPassportElementErrorSource? source}) → InputPassportElementError
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type