InputPassportElementErrorSourceFiles class final

InputPassportElementErrorSourceFiles (inputPassportElementErrorSourceFiles) - child of InputPassportElementErrorSource

The list of attached files contains an error. The error is considered resolved when the file list changes.

  • fileHashes: Current hashes of all attached files.
Inheritance

Constructors

InputPassportElementErrorSourceFiles({required List<String> fileHashes})
InputPassportElementErrorSourceFiles (inputPassportElementErrorSourceFiles) - child of InputPassportElementErrorSource
const
InputPassportElementErrorSourceFiles.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
fileHashes → List<String>
Current hashes of all attached files
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<String>? fileHashes}) → InputPassportElementErrorSourceFiles
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type