InputStoryContentVideo class final

InputStoryContentVideo (inputStoryContentVideo) - child of InputStoryContent

A video story.

  • video: Video to be sent. The video size must be 720x1280. The video must be streamable and stored in MPEG4 format, after encoding with x265 codec and key frames added each second.
  • addedStickerFileIds: File identifiers of the stickers added to the video, if applicable.
  • duration: Precise duration of the video, in seconds; 0-60.
  • coverFrameTimestamp: Timestamp of the frame, which will be used as video thumbnail.
  • isAnimation: True, if the video has no sound.
Inheritance

Constructors

InputStoryContentVideo({required InputFile video, required List<int> addedStickerFileIds, required double duration, required double coverFrameTimestamp, required bool isAnimation})
InputStoryContentVideo (inputStoryContentVideo) - child of InputStoryContent
const
InputStoryContentVideo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

addedStickerFileIds → List<int>
File identifiers of the stickers added to the video, if applicable
final
clientId → int?
Client ID, from which this object was received
no setterinherited
coverFrameTimestamp → double
Timestamp of the frame, which will be used as video thumbnail
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
duration → double
Precise duration of the video, in seconds; 0-60
final
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isAnimation → bool
True, if the video has no sound
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
video → InputFile
Video to be sent. The video size must be 720x1280. The video must be streamable and stored in MPEG4 format, after encoding with x265 codec and key frames added each second
final

Methods

copyWith({InputFile? video, List<int>? addedStickerFileIds, double? duration, double? coverFrameTimestamp, bool? isAnimation}) → InputStoryContentVideo
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type