InputThumbnail class final

InputThumbnail (inputThumbnail) - basic class

A thumbnail to be sent along with a file; must be in JPEG or WEBP format for stickers, and less than 200 KB in size.

  • thumbnail: Thumbnail file to send. Sending thumbnails by file_id is currently not supported.
  • width: Thumbnail width, usually shouldn't exceed 320. Use 0 if unknown.
  • height: Thumbnail height, usually shouldn't exceed 320. Use 0 if unknown.
Inheritance

Constructors

InputThumbnail({required InputFile thumbnail, required int width, required int height})
InputThumbnail (inputThumbnail) - basic class
const
InputThumbnail.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
height → int
Thumbnail height, usually shouldn't exceed 320. Use 0 if unknown
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail → InputFile
Thumbnail file to send. Sending thumbnails by file_id is currently not supported
final
width → int
Thumbnail width, usually shouldn't exceed 320. Use 0 if unknown
final

Methods

copyWith({InputFile? thumbnail, int? width, int? height}) → InputThumbnail
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type