LogStreamEmpty class final

LogStreamEmpty (logStreamEmpty) - child of LogStream

The log is written nowhere.

Inheritance

Constructors

LogStreamEmpty({dynamic extra, int? clientId})
LogStreamEmpty (logStreamEmpty) - child of LogStream
const
LogStreamEmpty.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({dynamic extra, int? clientId}) → LogStreamEmpty
Copy instance with no modifications.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type