LogStreamFile class final

LogStreamFile (logStreamFile) - child of LogStream

The log is written to a file.

  • path: Path to the file to where the internal TDLib log will be written.
  • maxFileSize: The maximum size of the file to where the internal TDLib log is written before the file will automatically be rotated, in bytes.
  • redirectStderr: Pass true to additionally redirect stderr to the log file. Ignored on Windows.
Inheritance

Constructors

LogStreamFile({required String path, required int maxFileSize, required bool redirectStderr, dynamic extra, int? clientId})
LogStreamFile (logStreamFile) - child of LogStream
const
LogStreamFile.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
maxFileSize → int
The maximum size of the file to where the internal TDLib log is written before the file will automatically be rotated, in bytes
final
path → String
Path to the file to where the internal TDLib log will be written
final
redirectStderr → bool
Pass true to additionally redirect stderr to the log file. Ignored on Windows
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? path, int? maxFileSize, bool? redirectStderr, dynamic extra, int? clientId}) → LogStreamFile
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type