MessageBasicGroupChatCreate class final

MessageBasicGroupChatCreate (messageBasicGroupChatCreate) - child of MessageContent

A newly created basic group.

  • title: Title of the basic group.
  • memberUserIds: User identifiers of members in the basic group.
Inheritance

Constructors

MessageBasicGroupChatCreate({required String title, required List<int> memberUserIds})
MessageBasicGroupChatCreate (messageBasicGroupChatCreate) - child of MessageContent
const
MessageBasicGroupChatCreate.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
memberUserIds → List<int>
User identifiers of members in the basic group
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
Title of the basic group
final

Methods

copyWith({String? title, List<int>? memberUserIds}) → MessageBasicGroupChatCreate
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type