MessageChatSetMessageAutoDeleteTime class final

MessageChatSetMessageAutoDeleteTime (messageChatSetMessageAutoDeleteTime) - child of MessageContent

The auto-delete or self-destruct timer for messages in the chat has been changed.

  • messageAutoDeleteTime: New value auto-delete or self-destruct time, in seconds; 0 if disabled.
  • fromUserId: If not 0, a user identifier, which default setting was automatically applied.
Inheritance

Constructors

MessageChatSetMessageAutoDeleteTime({required int messageAutoDeleteTime, required int fromUserId})
MessageChatSetMessageAutoDeleteTime (messageChatSetMessageAutoDeleteTime) - child of MessageContent
const
MessageChatSetMessageAutoDeleteTime.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
fromUserId → int
If not 0, a user identifier, which default setting was automatically applied
final
hashCode → int
The hash code for this object.
no setterinherited
messageAutoDeleteTime → int
New value auto-delete or self-destruct time, in seconds; 0 if disabled
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? messageAutoDeleteTime, int? fromUserId}) → MessageChatSetMessageAutoDeleteTime
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type