MessageCopyOptions class final

MessageCopyOptions (messageCopyOptions) - basic class

Options to be used when a message content is copied without reference to the original sender. Service messages, messages with messageInvoice, messagePaidMedia, messageGiveaway, or messageGiveawayWinners content can't be copied.

  • sendCopy: True, if content of the message needs to be copied without reference to the original sender. Always true if the message is forwarded to a secret chat or is local.
  • replaceCaption: True, if media caption of the message copy needs to be replaced. Ignored if send_copy is false.
  • newCaption: New message caption; pass null to copy message without caption. Ignored if replace_caption is false (optional).
  • newShowCaptionAboveMedia: True, if new caption must be shown above the animation; otherwise, new caption must be shown below the animation; not supported in secret chats. Ignored if replace_caption is false.
Inheritance

Constructors

MessageCopyOptions({required bool sendCopy, required bool replaceCaption, FormattedText? newCaption, required bool newShowCaptionAboveMedia})
MessageCopyOptions (messageCopyOptions) - basic class
const
MessageCopyOptions.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
newCaption → FormattedText?
New message caption; pass null to copy message without caption. Ignored if replace_caption is false
final
newShowCaptionAboveMedia → bool
True, if new caption must be shown above the animation; otherwise, new caption must be shown below the animation; not supported in secret chats. Ignored if replace_caption is false
final
replaceCaption → bool
True, if media caption of the message copy needs to be replaced. Ignored if send_copy is false
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendCopy → bool
True, if content of the message needs to be copied without reference to the original sender. Always true if the message is forwarded to a secret chat or is local
final

Methods

copyWith({bool? sendCopy, bool? replaceCaption, FormattedText? newCaption, bool? newShowCaptionAboveMedia}) → MessageCopyOptions
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type