MessageEffect class final

MessageEffect (messageEffect) - basic class

Contains information about an effect added to a message.

  • id: Unique identifier of the effect.
  • staticIcon: Static icon for the effect in WEBP format; may be null if none (optional).
  • emoji: Emoji corresponding to the effect that can be used if static icon isn't available.
  • isPremium: True, if Telegram Premium subscription is required to use the effect.
  • type: Type of the effect.
Inheritance

Constructors

MessageEffect({required int id, Sticker? staticIcon, required String emoji, required bool isPremium, required MessageEffectType type, dynamic extra, int? clientId})
MessageEffect (messageEffect) - basic class
const
MessageEffect.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
emoji → String
Emoji corresponding to the effect that can be used if static icon isn't available
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
Unique identifier of the effect
final
isPremium → bool
True, if Telegram Premium subscription is required to use the effect
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
staticIcon → Sticker?
Static icon for the effect in WEBP format; may be null if none
final
type → MessageEffectType
Type of the effect
final

Methods

copyWith({int? id, Sticker? staticIcon, String? emoji, bool? isPremium, MessageEffectType? type, dynamic extra, int? clientId}) → MessageEffect
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type