MessageForumTopicIsClosedToggled class final

MessageForumTopicIsClosedToggled (messageForumTopicIsClosedToggled) - child of MessageContent

A forum topic has been closed or opened.

  • isClosed: True, if the topic was closed; otherwise, the topic was reopened.
Inheritance

Constructors

MessageForumTopicIsClosedToggled({required bool isClosed})
MessageForumTopicIsClosedToggled (messageForumTopicIsClosedToggled) - child of MessageContent
const
MessageForumTopicIsClosedToggled.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isClosed → bool
True, if the topic was closed; otherwise, the topic was reopened
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isClosed}) → MessageForumTopicIsClosedToggled
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type