MessageGameScore class final
MessageGameScore (messageGameScore) - child of MessageContent
A new high score was achieved in a game.
- gameMessageId: Identifier of the message with the game, can be an identifier of a deleted message.
- gameId: Identifier of the game; may be different from the games presented in the message with the game.
- score: New score.
- Inheritance
-
- Object
- TdObject
- MessageContent
- MessageGameScore
Constructors
- MessageGameScore({required int gameMessageId, required int gameId, required int score})
-
MessageGameScore (messageGameScore) - child of MessageContent
const
-
MessageGameScore.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- gameId → int
-
Identifier of the game; may be different from the games presented in the message with the game
final
- gameMessageId → int
-
Identifier of the message with the game, can be an identifier of a deleted message
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- score → int
-
New score
final
Methods
-
copyWith(
{int? gameMessageId, int? gameId, int? score}) → MessageGameScore -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type