gameMessageId property
Identifier of the message with the game, can be an identifier of a deleted message
Implementation
final int gameMessageId;
Identifier of the message with the game, can be an identifier of a deleted message
final int gameMessageId;