MessageOriginHiddenUser class final

MessageOriginHiddenUser (messageOriginHiddenUser) - child of MessageOrigin

The message was originally sent by a user, which is hidden by their privacy settings.

Inheritance

Constructors

MessageOriginHiddenUser({required String senderName})
MessageOriginHiddenUser (messageOriginHiddenUser) - child of MessageOrigin
const
MessageOriginHiddenUser.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderName → String
Name of the sender
final

Methods

copyWith({String? senderName}) → MessageOriginHiddenUser
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type