MessagePassportDataSent class final
MessagePassportDataSent (messagePassportDataSent) - child of MessageContent
Telegram Passport data has been sent to a bot.
- types: List of Telegram Passport element types sent.
- Inheritance
-
- Object
- TdObject
- MessageContent
- MessagePassportDataSent
Constructors
-
MessagePassportDataSent({required List<
PassportElementType> types}) -
MessagePassportDataSent (messagePassportDataSent) - child of MessageContent
const
-
MessagePassportDataSent.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
types
→ List<
PassportElementType> -
List of Telegram Passport element types sent
final
Methods
-
copyWith(
{List< PassportElementType> ? types}) → MessagePassportDataSent -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type