MessagePaymentSuccessful class final

MessagePaymentSuccessful (messagePaymentSuccessful) - child of MessageContent

A payment has been completed.

  • invoiceChatId: Identifier of the chat, containing the corresponding invoice message.
  • invoiceMessageId: Identifier of the message with the corresponding invoice; can be 0 or an identifier of a deleted message.
  • currency: Currency for the price of the product.
  • totalAmount: Total price for the product, in the smallest units of the currency.
  • isRecurring: True, if this is a recurring payment.
  • isFirstRecurring: True, if this is the first recurring payment.
  • invoiceName: Name of the invoice; may be empty if unknown.
Inheritance

Constructors

MessagePaymentSuccessful({required int invoiceChatId, required int invoiceMessageId, required String currency, required int totalAmount, required bool isRecurring, required bool isFirstRecurring, required String invoiceName})
MessagePaymentSuccessful (messagePaymentSuccessful) - child of MessageContent
const
MessagePaymentSuccessful.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currency → String
Currency for the price of the product
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
invoiceChatId → int
Identifier of the chat, containing the corresponding invoice message
final
invoiceMessageId → int
Identifier of the message with the corresponding invoice; can be 0 or an identifier of a deleted message
final
invoiceName → String
Name of the invoice; may be empty if unknown
final
isFirstRecurring → bool
True, if this is the first recurring payment
final
isRecurring → bool
True, if this is a recurring payment
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalAmount → int
Total price for the product, in the smallest units of the currency
final

Methods

copyWith({int? invoiceChatId, int? invoiceMessageId, String? currency, int? totalAmount, bool? isRecurring, bool? isFirstRecurring, String? invoiceName}) → MessagePaymentSuccessful
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type