MessagePaymentSuccessfulBot class final

MessagePaymentSuccessfulBot (messagePaymentSuccessfulBot) - child of MessageContent

A payment has been completed; for bots only.

Inheritance

Constructors

MessagePaymentSuccessfulBot({required String currency, required int totalAmount, required bool isRecurring, required bool isFirstRecurring, required String invoicePayload, required String shippingOptionId, OrderInfo? orderInfo, required String telegramPaymentChargeId, required String providerPaymentChargeId})
MessagePaymentSuccessfulBot (messagePaymentSuccessfulBot) - child of MessageContent
const
MessagePaymentSuccessfulBot.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currency → String
Currency for price of the product
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
invoicePayload → String
Invoice payload
final
isFirstRecurring → bool
True, if this is the first recurring payment
final
isRecurring → bool
True, if this is a recurring payment
final
orderInfo → OrderInfo?
Information about the order; may be null
final
providerPaymentChargeId → String
Provider payment identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingOptionId → String
Identifier of the shipping option chosen by the user; may be empty if not applicable
final
telegramPaymentChargeId → String
Telegram payment identifier
final
totalAmount → int
Total price for the product, in the smallest units of the currency
final

Methods

copyWith({String? currency, int? totalAmount, bool? isRecurring, bool? isFirstRecurring, String? invoicePayload, String? shippingOptionId, OrderInfo? orderInfo, String? telegramPaymentChargeId, String? providerPaymentChargeId}) → MessagePaymentSuccessfulBot
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type