MessagePhoto class final

MessagePhoto (messagePhoto) - child of MessageContent

A photo message.

  • photo: The photo.
  • caption: Photo caption.
  • showCaptionAboveMedia: True, if the caption must be shown above the photo; otherwise, the caption must be shown below the photo.
  • hasSpoiler: True, if the photo preview must be covered by a spoiler animation.
  • isSecret: True, if the photo must be blurred and must be shown only while tapped.
Inheritance

Constructors

MessagePhoto({required Photo photo, required FormattedText caption, required bool showCaptionAboveMedia, required bool hasSpoiler, required bool isSecret})
MessagePhoto (messagePhoto) - child of MessageContent
const
MessagePhoto.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

caption → FormattedText
Photo caption
final
clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasSpoiler → bool
True, if the photo preview must be covered by a spoiler animation
final
isSecret → bool
True, if the photo must be blurred and must be shown only while tapped
final
photo → Photo
The photo
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showCaptionAboveMedia → bool
True, if the caption must be shown above the photo; otherwise, the caption must be shown below the photo
final

Methods

copyWith({Photo? photo, FormattedText? caption, bool? showCaptionAboveMedia, bool? hasSpoiler, bool? isSecret}) → MessagePhoto
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type