MessageProperties class final

MessageProperties (messageProperties) - basic class

Contains properties of a message and describes actions that can be done with the message right now.

  • canBeCopiedToSecretChat: True, if content of the message can be copied to a secret chat using inputMessageForwarded or forwardMessages with copy options.
  • canBeDeletedOnlyForSelf: True, if the message can be deleted only for the current user while other users will continue to see it using the method deleteMessages with revoke == false.
  • canBeDeletedForAllUsers: True, if the message can be deleted for all users using the method deleteMessages with revoke == true.
  • canBeEdited: True, if the message can be edited using the methods editMessageText, editMessageMedia, editMessageCaption, or editMessageReplyMarkup.. For live location and poll messages this fields shows whether editMessageLiveLocation or stopPoll can be used with this message.
  • canBeForwarded: True, if the message can be forwarded using inputMessageForwarded or forwardMessages.
  • canBePaid: True, if the message can be paid using inputInvoiceMessage.
  • canBePinned: True, if the message can be pinned or unpinned in the chat using pinChatMessage or unpinChatMessage.
  • canBeReplied: True, if the message can be replied in the same chat and forum topic using inputMessageReplyToMessage.
  • canBeRepliedInAnotherChat: True, if the message can be replied in another chat or forum topic using inputMessageReplyToExternalMessage.
  • canBeSaved: True, if content of the message can be saved locally or copied using inputMessageForwarded or forwardMessages with copy options.
  • canBeSharedInStory: True, if the message can be shared in a story using inputStoryAreaTypeMessage.
  • canEditSchedulingState: True, if scheduling state of the message can be edited.
  • canGetEmbeddingCode: True, if code for message embedding can be received using getMessageEmbeddingCode.
  • canGetLink: True, if a link can be generated for the message using getMessageLink.
  • canGetMediaTimestampLinks: True, if media timestamp links can be generated for media timestamp entities in the message text, caption or link preview description using getMessageLink.
  • canGetMessageThread: True, if information about the message thread is available through getMessageThread and getMessageThreadHistory.
  • canGetReadDate: True, if read date of the message can be received through getMessageReadDate.
  • canGetStatistics: True, if message statistics are available through getMessageStatistics and message forwards can be received using getMessagePublicForwards.
  • canGetViewers: True, if chat members already viewed the message can be received through getMessageViewers.
  • canRecognizeSpeech: True, if speech can be recognized for the message through recognizeSpeech.
  • canReportChat: True, if the message can be reported using reportChat.
  • canReportReactions: True, if reactions on the message can be reported through reportMessageReactions.
  • canReportSupergroupSpam: True, if the message can be reported using reportSupergroupSpam.
  • canSetFactCheck: True, if fact check for the message can be changed through setMessageFactCheck.
  • needShowStatistics: True, if message statistics must be available from context menu of the message.
Inheritance

Constructors

MessageProperties({required bool canBeCopiedToSecretChat, required bool canBeDeletedOnlyForSelf, required bool canBeDeletedForAllUsers, required bool canBeEdited, required bool canBeForwarded, required bool canBePaid, required bool canBePinned, required bool canBeReplied, required bool canBeRepliedInAnotherChat, required bool canBeSaved, required bool canBeSharedInStory, required bool canEditSchedulingState, required bool canGetEmbeddingCode, required bool canGetLink, required bool canGetMediaTimestampLinks, required bool canGetMessageThread, required bool canGetReadDate, required bool canGetStatistics, required bool canGetViewers, required bool canRecognizeSpeech, required bool canReportChat, required bool canReportReactions, required bool canReportSupergroupSpam, required bool canSetFactCheck, required bool needShowStatistics, dynamic extra, int? clientId})
MessageProperties (messageProperties) - basic class
const
MessageProperties.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

canBeCopiedToSecretChat → bool
True, if content of the message can be copied to a secret chat using inputMessageForwarded or forwardMessages with copy options
final
canBeDeletedForAllUsers → bool
True, if the message can be deleted for all users using the method deleteMessages with revoke == true
final
canBeDeletedOnlyForSelf → bool
True, if the message can be deleted only for the current user while other users will continue to see it using the method deleteMessages with revoke == false
final
canBeEdited → bool
True, if the message can be edited using the methods editMessageText, editMessageMedia, editMessageCaption, or editMessageReplyMarkup.. For live location and poll messages this fields shows whether editMessageLiveLocation or stopPoll can be used with this message
final
canBeForwarded → bool
True, if the message can be forwarded using inputMessageForwarded or forwardMessages
final
canBePaid → bool
True, if the message can be paid using inputInvoiceMessage
final
canBePinned → bool
True, if the message can be pinned or unpinned in the chat using pinChatMessage or unpinChatMessage
final
canBeReplied → bool
True, if the message can be replied in the same chat and forum topic using inputMessageReplyToMessage
final
canBeRepliedInAnotherChat → bool
True, if the message can be replied in another chat or forum topic using inputMessageReplyToExternalMessage
final
canBeSaved → bool
True, if content of the message can be saved locally or copied using inputMessageForwarded or forwardMessages with copy options
final
canBeSharedInStory → bool
True, if the message can be shared in a story using inputStoryAreaTypeMessage
final
canEditSchedulingState → bool
True, if scheduling state of the message can be edited
final
canGetEmbeddingCode → bool
True, if code for message embedding can be received using getMessageEmbeddingCode
final
True, if a link can be generated for the message using getMessageLink
final
True, if media timestamp links can be generated for media timestamp entities in the message text, caption or link preview description using getMessageLink
final
canGetMessageThread → bool
True, if information about the message thread is available through getMessageThread and getMessageThreadHistory
final
canGetReadDate → bool
True, if read date of the message can be received through getMessageReadDate
final
canGetStatistics → bool
True, if message statistics are available through getMessageStatistics and message forwards can be received using getMessagePublicForwards
final
canGetViewers → bool
True, if chat members already viewed the message can be received through getMessageViewers
final
canRecognizeSpeech → bool
True, if speech can be recognized for the message through recognizeSpeech
final
canReportChat → bool
True, if the message can be reported using reportChat
final
canReportReactions → bool
True, if reactions on the message can be reported through reportMessageReactions
final
canReportSupergroupSpam → bool
True, if the message can be reported using reportSupergroupSpam
final
canSetFactCheck → bool
True, if fact check for the message can be changed through setMessageFactCheck
final
clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
needShowStatistics → bool
True, if message statistics must be available from context menu of the message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? canBeCopiedToSecretChat, bool? canBeDeletedOnlyForSelf, bool? canBeDeletedForAllUsers, bool? canBeEdited, bool? canBeForwarded, bool? canBePaid, bool? canBePinned, bool? canBeReplied, bool? canBeRepliedInAnotherChat, bool? canBeSaved, bool? canBeSharedInStory, bool? canEditSchedulingState, bool? canGetEmbeddingCode, bool? canGetLink, bool? canGetMediaTimestampLinks, bool? canGetMessageThread, bool? canGetReadDate, bool? canGetStatistics, bool? canGetViewers, bool? canRecognizeSpeech, bool? canReportChat, bool? canReportReactions, bool? canReportSupergroupSpam, bool? canSetFactCheck, bool? needShowStatistics, dynamic extra, int? clientId}) → MessageProperties
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type