MessageProximityAlertTriggered class final

MessageProximityAlertTriggered (messageProximityAlertTriggered) - child of MessageContent

A user in the chat came within proximity alert range.

  • travelerId: The identifier of a user or chat that triggered the proximity alert.
  • watcherId: The identifier of a user or chat that subscribed for the proximity alert.
  • distance: The distance between the users.
Inheritance

Constructors

MessageProximityAlertTriggered({required MessageSender travelerId, required MessageSender watcherId, required int distance})
MessageProximityAlertTriggered (messageProximityAlertTriggered) - child of MessageContent
const
MessageProximityAlertTriggered.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
distance → int
The distance between the users
final
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
travelerId → MessageSender
The identifier of a user or chat that triggered the proximity alert
final
watcherId → MessageSender
The identifier of a user or chat that subscribed for the proximity alert
final

Methods

copyWith({MessageSender? travelerId, MessageSender? watcherId, int? distance}) → MessageProximityAlertTriggered
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type