MessageReadDateRead class final

MessageReadDateRead (messageReadDateRead) - child of MessageReadDate

Contains read date of the message.

  • readDate: Point in time (Unix timestamp) when the message was read by the other user.
Inheritance

Constructors

MessageReadDateRead({required int readDate, dynamic extra, int? clientId})
MessageReadDateRead (messageReadDateRead) - child of MessageReadDate
const
MessageReadDateRead.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
readDate → int
Point in time (Unix timestamp) when the message was read by the other user
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? readDate, dynamic extra, int? clientId}) → MessageReadDateRead
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type