MessageReadDateUnread class final

MessageReadDateUnread (messageReadDateUnread) - child of MessageReadDate

The message is unread yet.

Inheritance

Constructors

MessageReadDateUnread({dynamic extra, int? clientId})
MessageReadDateUnread (messageReadDateUnread) - child of MessageReadDate
const
MessageReadDateUnread.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({dynamic extra, int? clientId}) → MessageReadDateUnread
Copy instance with no modifications.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type