MessageSchedulingStateSendAtDate class final

MessageSchedulingStateSendAtDate (messageSchedulingStateSendAtDate) - child of MessageSchedulingState

The message will be sent at the specified date.

  • sendDate: Point in time (Unix timestamp) when the message will be sent. The date must be within 367 days in the future.
Inheritance

Constructors

MessageSchedulingStateSendAtDate({required int sendDate})
MessageSchedulingStateSendAtDate (messageSchedulingStateSendAtDate) - child of MessageSchedulingState
const
MessageSchedulingStateSendAtDate.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendDate → int
Point in time (Unix timestamp) when the message will be sent. The date must be within 367 days in the future
final

Methods

copyWith({int? sendDate}) → MessageSchedulingStateSendAtDate
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type