MessageSticker class final

MessageSticker (messageSticker) - child of MessageContent

A sticker message.

  • sticker: The sticker description.
  • isPremium: True, if premium animation of the sticker must be played.
Inheritance

Constructors

MessageSticker({required Sticker sticker, required bool isPremium})
MessageSticker (messageSticker) - child of MessageContent
const
MessageSticker.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isPremium → bool
True, if premium animation of the sticker must be played
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sticker → Sticker
The sticker description
final

Methods

copyWith({Sticker? sticker, bool? isPremium}) → MessageSticker
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type