MessageStory class final

MessageStory (messageStory) - child of MessageContent

A message with a forwarded story.

  • storySenderChatId: Identifier of the chat that posted the story.
  • storyId: Story identifier.
  • viaMention: True, if the story was automatically forwarded because of a mention of the user.
Inheritance

Constructors

MessageStory({required int storySenderChatId, required int storyId, required bool viaMention})
MessageStory (messageStory) - child of MessageContent
const
MessageStory.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storyId → int
Story identifier
final
storySenderChatId → int
Identifier of the chat that posted the story
final
viaMention → bool
True, if the story was automatically forwarded because of a mention of the user
final

Methods

copyWith({int? storySenderChatId, int? storyId, bool? viaMention}) → MessageStory
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type