MessageVideoNote class final

MessageVideoNote (messageVideoNote) - child of MessageContent

A video note message.

  • videoNote: The video note description.
  • isViewed: True, if at least one of the recipients has viewed the video note.
  • isSecret: True, if the video note thumbnail must be blurred and the video note must be shown only while tapped.
Inheritance

Constructors

MessageVideoNote({required VideoNote videoNote, required bool isViewed, required bool isSecret})
MessageVideoNote (messageVideoNote) - child of MessageContent
const
MessageVideoNote.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isSecret → bool
True, if the video note thumbnail must be blurred and the video note must be shown only while tapped
final
isViewed → bool
True, if at least one of the recipients has viewed the video note
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
videoNote → VideoNote
The video note description
final

Methods

copyWith({VideoNote? videoNote, bool? isViewed, bool? isSecret}) → MessageVideoNote
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type