MessageWebAppDataReceived class final

MessageWebAppDataReceived (messageWebAppDataReceived) - child of MessageContent

Data from a Web App has been received; for bots only.

  • buttonText: Text of the keyboardButtonTypeWebApp button, which opened the Web App.
  • data: The data.
Inheritance

Constructors

MessageWebAppDataReceived({required String buttonText, required String data})
MessageWebAppDataReceived (messageWebAppDataReceived) - child of MessageContent
const
MessageWebAppDataReceived.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

buttonText → String
Text of the keyboardButtonTypeWebApp button, which opened the Web App
final
clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
data → String
The data
final
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? buttonText, String? data}) → MessageWebAppDataReceived
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type