NetworkStatistics class final

NetworkStatistics (networkStatistics) - basic class

A full list of available network statistic entries.

  • sinceDate: Point in time (Unix timestamp) from which the statistics are collected.
  • entries: Network statistics entries.
Inheritance

Constructors

NetworkStatistics({required int sinceDate, required List<NetworkStatisticsEntry> entries, dynamic extra, int? clientId})
NetworkStatistics (networkStatistics) - basic class
const
NetworkStatistics.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
entries → List<NetworkStatisticsEntry>
Network statistics entries
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sinceDate → int
Point in time (Unix timestamp) from which the statistics are collected
final

Methods

copyWith({int? sinceDate, List<NetworkStatisticsEntry>? entries, dynamic extra, int? clientId}) → NetworkStatistics
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type