OpenMessageContent class final

OpenMessageContent (openMessageContent) - TDLib function

Informs TDLib that the message content has been opened (e.g., the user has opened a photo, video, document, location or venue, or has listened to an audio file or voice note message).. An updateMessageContentOpened update will be generated if something has changed.

  • chatId: Chat identifier of the message.
  • messageId: Identifier of the message with the opened content.

Ok is returned on completion.

Inheritance

Constructors

OpenMessageContent({required int chatId, required int messageId})
OpenMessageContent (openMessageContent) - TDLib function
const

Properties

chatId → int
Chat identifier of the message
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
Identifier of the message with the opened content
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId}) → OpenMessageContent
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type