PageBlockDetails class final

PageBlockDetails (pageBlockDetails) - child of PageBlock

A collapsible block.

  • header: Always visible heading for the block.
  • pageBlocks: Block contents.
  • isOpen: True, if the block is open by default.
Inheritance

Constructors

PageBlockDetails({required RichText header, required List<PageBlock> pageBlocks, required bool isOpen})
PageBlockDetails (pageBlockDetails) - child of PageBlock
const
PageBlockDetails.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
Always visible heading for the block
final
isOpen → bool
True, if the block is open by default
final
pageBlocks → List<PageBlock>
Block contents
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({RichText? header, List<PageBlock>? pageBlocks, bool? isOpen}) → PageBlockDetails
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type