PageBlockVoiceNote class final

PageBlockVoiceNote (pageBlockVoiceNote) - child of PageBlock

A voice note.

Inheritance

Constructors

PageBlockVoiceNote({VoiceNote? voiceNote, required PageBlockCaption caption})
PageBlockVoiceNote (pageBlockVoiceNote) - child of PageBlock
const
PageBlockVoiceNote.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

caption → PageBlockCaption
Voice note caption
final
clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
voiceNote → VoiceNote?
Voice note; may be null
final

Methods

copyWith({VoiceNote? voiceNote, PageBlockCaption? caption}) → PageBlockVoiceNote
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type