PassportElementErrorSourceReverseSide class final

PassportElementErrorSourceReverseSide (passportElementErrorSourceReverseSide) - child of PassportElementErrorSource

The reverse side of the document contains an error. The error will be considered resolved when the file with the reverse side changes.

Inheritance

Constructors

PassportElementErrorSourceReverseSide()
PassportElementErrorSourceReverseSide (passportElementErrorSourceReverseSide) - child of PassportElementErrorSource
const
PassportElementErrorSourceReverseSide.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith() → PassportElementErrorSourceReverseSide
Copy instance with no modifications.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type