PaymentForm class final

PaymentForm (paymentForm) - basic class

Contains information about an invoice payment form.

  • id: The payment form identifier.
  • type: Type of the payment form.
  • sellerBotUserId: User identifier of the seller bot.
  • productInfo: Information about the product.
Inheritance

Constructors

PaymentForm({required int id, required PaymentFormType type, required int sellerBotUserId, required ProductInfo productInfo, dynamic extra, int? clientId})
PaymentForm (paymentForm) - basic class
const
PaymentForm.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
The payment form identifier
final
productInfo → ProductInfo
Information about the product
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sellerBotUserId → int
User identifier of the seller bot
final
type → PaymentFormType
Type of the payment form
final

Methods

copyWith({int? id, PaymentFormType? type, int? sellerBotUserId, ProductInfo? productInfo, dynamic extra, int? clientId}) → PaymentForm
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type