PinChatMessage class final

PinChatMessage (pinChatMessage) - TDLib function

Pins a message in a chat. A message can be pinned only if messageProperties.can_be_pinned.

  • chatId: Identifier of the chat.
  • messageId: Identifier of the new pinned message.
  • disableNotification: Pass true to disable notification about the pinned message. Notifications are always disabled in channels and private chats.
  • onlyForSelf: Pass true to pin the message only for self; private chats only.

Ok is returned on completion.

Inheritance

Constructors

PinChatMessage({required int chatId, required int messageId, required bool disableNotification, required bool onlyForSelf})
PinChatMessage (pinChatMessage) - TDLib function
const

Properties

chatId → int
Identifier of the chat
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
disableNotification → bool
Pass true to disable notification about the pinned message. Notifications are always disabled in channels and private chats
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
Identifier of the new pinned message
final
onlyForSelf → bool
Pass true to pin the message only for self; private chats only
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, bool? disableNotification, bool? onlyForSelf}) → PinChatMessage
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type