PremiumFeature class sealed
PremiumFeature (premiumFeature) - parent
Describes a feature available to Premium users.
- Inheritance
- Implementers
- PremiumFeatureAccentColor
- PremiumFeatureAdvancedChatManagement
- PremiumFeatureAnimatedProfilePhoto
- PremiumFeatureAppIcons
- PremiumFeatureBackgroundForBoth
- PremiumFeatureBusiness
- PremiumFeatureChatBoost
- PremiumFeatureCustomEmoji
- PremiumFeatureDisabledAds
- PremiumFeatureEmojiStatus
- PremiumFeatureForumTopicIcon
- PremiumFeatureImprovedDownloadSpeed
- PremiumFeatureIncreasedLimits
- PremiumFeatureIncreasedUploadFileSize
- PremiumFeatureLastSeenTimes
- PremiumFeatureMessageEffects
- PremiumFeatureMessagePrivacy
- PremiumFeatureProfileBadge
- PremiumFeatureRealTimeChatTranslation
- PremiumFeatureSavedMessagesTags
- PremiumFeatureUniqueReactions
- PremiumFeatureUniqueStickers
- PremiumFeatureUpgradedStories
- PremiumFeatureVoiceRecognition
Constructors
-
PremiumFeature.fromJson(Map<
String, dynamic> json) -
a PremiumFeature return type can be :
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
) → PremiumFeature - Copy instance with no modifications.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type