PremiumFeatureLastSeenTimes class final

PremiumFeatureLastSeenTimes (premiumFeatureLastSeenTimes) - child of PremiumFeature

The ability to view last seen and read times of other users even they can't view last seen or read time for the current user.

Inheritance

Constructors

PremiumFeatureLastSeenTimes()
PremiumFeatureLastSeenTimes (premiumFeatureLastSeenTimes) - child of PremiumFeature
const
PremiumFeatureLastSeenTimes.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith() → PremiumFeatureLastSeenTimes
Copy instance with no modifications.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type