PremiumFeatures class final

PremiumFeatures (premiumFeatures) - basic class

Contains information about features, available to Premium users.

  • features: The list of available features.
  • limits: The list of limits, increased for Premium users.
  • paymentLink: An internal link to be opened to pay for Telegram Premium if store payment isn't possible; may be null if direct payment isn't available (optional).
Inheritance

Constructors

PremiumFeatures({required List<PremiumFeature> features, required List<PremiumLimit> limits, InternalLinkType? paymentLink, dynamic extra, int? clientId})
PremiumFeatures (premiumFeatures) - basic class
const
PremiumFeatures.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
features → List<PremiumFeature>
The list of available features
final
hashCode → int
The hash code for this object.
no setterinherited
limits → List<PremiumLimit>
The list of limits, increased for Premium users
final
An internal link to be opened to pay for Telegram Premium if store payment isn't possible; may be null if direct payment isn't available
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<PremiumFeature>? features, List<PremiumLimit>? limits, InternalLinkType? paymentLink, dynamic extra, int? clientId}) → PremiumFeatures
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type