PremiumLimit class final
PremiumLimit (premiumLimit) - basic class
Contains information about a limit, increased for Premium users.
- type: The type of the limit.
- defaultValue: Default value of the limit.
- premiumValue: Value of the limit for Premium users.
Constructors
- PremiumLimit({required PremiumLimitType type, required int defaultValue, dynamic extra, int? clientId})
-
PremiumLimit (premiumLimit) - basic class
const
-
PremiumLimit.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
clientId client identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- defaultValue → int
-
Default value of the limit
final
- extra → dynamic
-
extra callback sign
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Value of the limit for Premium users
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → PremiumLimitType
-
The type of the limit
final
Methods
-
copyWith(
{PremiumLimitType? type, int? defaultValue, dynamic extra, int? clientId}) → PremiumLimit - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type