PushMessageContentAnimation class final

PushMessageContentAnimation (pushMessageContentAnimation) - child of PushMessageContent

An animation message (GIF-style).

  • animation: Message content; may be null (optional).
  • caption: Animation caption.
  • isPinned: True, if the message is a pinned message with the specified content.
Inheritance

Constructors

PushMessageContentAnimation({Animation? animation, required String caption, required bool isPinned})
PushMessageContentAnimation (pushMessageContentAnimation) - child of PushMessageContent
const
PushMessageContentAnimation.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

animation → Animation?
Message content; may be null
final
caption → String
Animation caption
final
clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isPinned → bool
True, if the message is a pinned message with the specified content
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Animation? animation, String? caption, bool? isPinned}) → PushMessageContentAnimation
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type