PushMessageContentInvoice class final

PushMessageContentInvoice (pushMessageContentInvoice) - child of PushMessageContent

A message with an invoice from a bot.

  • price: Product price.
  • isPinned: True, if the message is a pinned message with the specified content.
Inheritance

Constructors

PushMessageContentInvoice({required String price, required bool isPinned})
PushMessageContentInvoice (pushMessageContentInvoice) - child of PushMessageContent
const
PushMessageContentInvoice.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isPinned → bool
True, if the message is a pinned message with the specified content
final
price → String
Product price
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? price, bool? isPinned}) → PushMessageContentInvoice
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type