PushMessageContentLocation class final

PushMessageContentLocation (pushMessageContentLocation) - child of PushMessageContent

A message with a location.

  • isLive: True, if the location is live.
  • isPinned: True, if the message is a pinned message with the specified content.
Inheritance

Constructors

PushMessageContentLocation({required bool isLive, required bool isPinned})
PushMessageContentLocation (pushMessageContentLocation) - child of PushMessageContent
const
PushMessageContentLocation.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isLive → bool
True, if the location is live
final
isPinned → bool
True, if the message is a pinned message with the specified content
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isLive, bool? isPinned}) → PushMessageContentLocation
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type