PushMessageContentPoll class final

PushMessageContentPoll (pushMessageContentPoll) - child of PushMessageContent

A message with a poll.

  • question: Poll question.
  • isRegular: True, if the poll is regular and not in quiz mode.
  • isPinned: True, if the message is a pinned message with the specified content.
Inheritance

Constructors

PushMessageContentPoll({required String question, required bool isRegular, required bool isPinned})
PushMessageContentPoll (pushMessageContentPoll) - child of PushMessageContent
const
PushMessageContentPoll.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isPinned → bool
True, if the message is a pinned message with the specified content
final
isRegular → bool
True, if the poll is regular and not in quiz mode
final
question → String
Poll question
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? question, bool? isRegular, bool? isPinned}) → PushMessageContentPoll
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type