QuickReplyMessage class final

QuickReplyMessage (quickReplyMessage) - basic class

Describes a message that can be used for quick reply.

  • id: Unique message identifier among all quick replies.
  • sendingState: The sending state of the message; may be null if the message isn't being sent and didn't fail to be sent (optional).
  • canBeEdited: True, if the message can be edited.
  • replyToMessageId: The identifier of the quick reply message to which the message replies; 0 if none.
  • viaBotUserId: If non-zero, the user identifier of the bot through which this message was sent.
  • mediaAlbumId: Unique identifier of an album this message belongs to; 0 if none. Only audios, documents, photos and videos can be grouped together in albums.
  • content: Content of the message.
  • replyMarkup: Inline keyboard reply markup for the message; may be null if none (optional).
Inheritance

Constructors

QuickReplyMessage({required int id, MessageSendingState? sendingState, required bool canBeEdited, required int replyToMessageId, required int viaBotUserId, required int mediaAlbumId, required MessageContent content, ReplyMarkup? replyMarkup, dynamic extra, int? clientId})
QuickReplyMessage (quickReplyMessage) - basic class
const
QuickReplyMessage.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

canBeEdited → bool
True, if the message can be edited
final
clientId → int?
clientId client identifier
final
content → MessageContent
Content of the message
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
Unique message identifier among all quick replies
final
mediaAlbumId → int
Unique identifier of an album this message belongs to; 0 if none. Only audios, documents, photos and videos can be grouped together in albums
final
replyMarkup → ReplyMarkup?
Inline keyboard reply markup for the message; may be null if none
final
replyToMessageId → int
The identifier of the quick reply message to which the message replies; 0 if none
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendingState → MessageSendingState?
The sending state of the message; may be null if the message isn't being sent and didn't fail to be sent
final
viaBotUserId → int
If non-zero, the user identifier of the bot through which this message was sent
final

Methods

copyWith({int? id, MessageSendingState? sendingState, bool? canBeEdited, int? replyToMessageId, int? viaBotUserId, int? mediaAlbumId, MessageContent? content, ReplyMarkup? replyMarkup, dynamic extra, int? clientId}) → QuickReplyMessage
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type