ReactionNotificationSettings class final

ReactionNotificationSettings (reactionNotificationSettings) - basic class

Contains information about notification settings for reactions.

  • messageReactionSource: Source of message reactions for which notifications are shown.
  • storyReactionSource: Source of story reactions for which notifications are shown.
  • soundId: Identifier of the notification sound to be played; 0 if sound is disabled.
  • showPreview: True, if reaction sender and emoji must be displayed in notifications.
Inheritance

Constructors

ReactionNotificationSettings({required ReactionNotificationSource messageReactionSource, required ReactionNotificationSource storyReactionSource, required int soundId, required bool showPreview})
ReactionNotificationSettings (reactionNotificationSettings) - basic class
const
ReactionNotificationSettings.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
messageReactionSource → ReactionNotificationSource
Source of message reactions for which notifications are shown
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showPreview → bool
True, if reaction sender and emoji must be displayed in notifications
final
soundId → int
Identifier of the notification sound to be played; 0 if sound is disabled
final
storyReactionSource → ReactionNotificationSource
Source of story reactions for which notifications are shown
final

Methods

copyWith({ReactionNotificationSource? messageReactionSource, ReactionNotificationSource? storyReactionSource, int? soundId, bool? showPreview}) → ReactionNotificationSettings
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type