ReadChatList class final

ReadChatList (readChatList) - TDLib function

Traverse all chats in a chat list and marks all messages in the chats as read.

  • chatList: Chat list in which to mark all chats as read.

Ok is returned on completion.

Inheritance

Constructors

ReadChatList({required ChatList chatList})
ReadChatList (readChatList) - TDLib function
const

Properties

chatList → ChatList
Chat list in which to mark all chats as read
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ChatList? chatList}) → ReadChatList
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type