RemoveAllFilesFromDownloads class final

RemoveAllFilesFromDownloads (removeAllFilesFromDownloads) - TDLib function

Removes all files from the file download list.

  • onlyActive: Pass true to remove only active downloads, including paused.
  • onlyCompleted: Pass true to remove only completed downloads.
  • deleteFromCache: Pass true to delete the file from the TDLib file cache.

Ok is returned on completion.

Inheritance

Constructors

RemoveAllFilesFromDownloads({required bool onlyActive, required bool onlyCompleted, required bool deleteFromCache})
RemoveAllFilesFromDownloads (removeAllFilesFromDownloads) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
deleteFromCache → bool
Pass true to delete the file from the TDLib file cache
final
hashCode → int
The hash code for this object.
no setterinherited
onlyActive → bool
Pass true to remove only active downloads, including paused
final
onlyCompleted → bool
Pass true to remove only completed downloads
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? onlyActive, bool? onlyCompleted, bool? deleteFromCache}) → RemoveAllFilesFromDownloads
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type