RemoveContacts class final

RemoveContacts (removeContacts) - TDLib function

Removes users from the contact list.

  • userIds: Identifiers of users to be deleted.

Ok is returned on completion.

Inheritance

Constructors

RemoveContacts({required List<int> userIds})
RemoveContacts (removeContacts) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userIds → List<int>
Identifiers of users to be deleted
final

Methods

copyWith({List<int>? userIds}) → RemoveContacts
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type