RemoveFavoriteSticker class final

RemoveFavoriteSticker (removeFavoriteSticker) - TDLib function

Removes a sticker from the list of favorite stickers.

  • sticker: Sticker file to delete from the list.

Ok is returned on completion.

Inheritance

Constructors

RemoveFavoriteSticker({required InputFile sticker})
RemoveFavoriteSticker (removeFavoriteSticker) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sticker → InputFile
Sticker file to delete from the list
final

Methods

copyWith({InputFile? sticker}) → RemoveFavoriteSticker
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type