RemoveProxy class final

RemoveProxy (removeProxy) - TDLib function

Removes a proxy server. Can be called before authorization.

Ok is returned on completion.

Inheritance

Constructors

RemoveProxy({required int proxyId})
RemoveProxy (removeProxy) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
proxyId → int
Proxy identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? proxyId}) → RemoveProxy
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type