RemoveRecentlyFoundChat class final

RemoveRecentlyFoundChat (removeRecentlyFoundChat) - TDLib function

Removes a chat from the list of recently found chats.

  • chatId: Identifier of the chat to be removed.

Ok is returned on completion.

Inheritance

Constructors

RemoveRecentlyFoundChat({required int chatId})
RemoveRecentlyFoundChat (removeRecentlyFoundChat) - TDLib function
const

Properties

chatId → int
Identifier of the chat to be removed
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId}) → RemoveRecentlyFoundChat
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type