RemoveStickerFromSet class final

RemoveStickerFromSet (removeStickerFromSet) - TDLib function

Removes a sticker from the set to which it belongs. The sticker set must be owned by the current user.

  • sticker: Sticker to remove from the set.

Ok is returned on completion.

Inheritance

Constructors

RemoveStickerFromSet({required InputFile sticker})
RemoveStickerFromSet (removeStickerFromSet) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sticker → InputFile
Sticker to remove from the set
final

Methods

copyWith({InputFile? sticker}) → RemoveStickerFromSet
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type