ReplyMarkupForceReply class final

ReplyMarkupForceReply (replyMarkupForceReply) - child of ReplyMarkup

Instructs application to force a reply to this message.

  • isPersonal: True, if a forced reply must automatically be shown to the current user. For outgoing messages, specify true to show the forced reply only for the mentioned users and for the target user of a reply.
  • inputFieldPlaceholder: If non-empty, the placeholder to be shown in the input field when the reply is active; 0-64 characters.
Inheritance

Constructors

ReplyMarkupForceReply({required bool isPersonal, required String inputFieldPlaceholder})
ReplyMarkupForceReply (replyMarkupForceReply) - child of ReplyMarkup
const
ReplyMarkupForceReply.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
inputFieldPlaceholder → String
If non-empty, the placeholder to be shown in the input field when the reply is active; 0-64 characters
final
isPersonal → bool
True, if a forced reply must automatically be shown to the current user. For outgoing messages, specify true to show the forced reply only for the mentioned users and for the target user of a reply
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isPersonal, String? inputFieldPlaceholder}) → ReplyMarkupForceReply
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type