copyWith method
Copy model with modified properties.
Properties:
is_personal: True, if a forced reply must automatically be shown to the current user. For outgoing messages, specify true to show the forced reply only for the mentioned users and for the target user of a replyinput_field_placeholder: If non-empty, the placeholder to be shown in the input field when the reply is active; 0-64 characters
Implementation
@override
ReplyMarkupForceReply copyWith({
bool? isPersonal,
String? inputFieldPlaceholder,
}) =>
ReplyMarkupForceReply(
isPersonal: isPersonal ?? this.isPersonal,
inputFieldPlaceholder:
inputFieldPlaceholder ?? this.inputFieldPlaceholder,
);