ReportChatPhoto class final

ReportChatPhoto (reportChatPhoto) - TDLib function

Reports a chat photo to the Telegram moderators. A chat photo can be reported only if chat.can_be_reported.

  • chatId: Chat identifier.
  • fileId: Identifier of the photo to report. Only full photos from chatPhoto can be reported.
  • reason: The reason for reporting the chat photo.
  • text: Additional report details; 0-1024 characters.

Ok is returned on completion.

Inheritance

Constructors

ReportChatPhoto({required int chatId, required int fileId, required ReportReason reason, required String text})
ReportChatPhoto (reportChatPhoto) - TDLib function
const

Properties

chatId → int
Chat identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
fileId → int
Identifier of the photo to report. Only full photos from chatPhoto can be reported
final
hashCode → int
The hash code for this object.
no setterinherited
reason → ReportReason
The reason for reporting the chat photo
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
Additional report details; 0-1024 characters
final

Methods

copyWith({int? chatId, int? fileId, ReportReason? reason, String? text}) → ReportChatPhoto
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type