ReportPhoneNumberCodeMissing class final

ReportPhoneNumberCodeMissing (reportPhoneNumberCodeMissing) - TDLib function

Reports that authentication code wasn't delivered via SMS to the specified phone number; for official mobile applications only.

Ok is returned on completion.

Inheritance

Constructors

ReportPhoneNumberCodeMissing({required String mobileNetworkCode})
ReportPhoneNumberCodeMissing (reportPhoneNumberCodeMissing) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
mobileNetworkCode → String
Current mobile network code
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? mobileNetworkCode}) → ReportPhoneNumberCodeMissing
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type