ResendPhoneNumberCode class final

ResendPhoneNumberCode (resendPhoneNumberCode) - TDLib function

Resends the authentication code sent to a phone number. Works only if the previously received authenticationCodeInfo next_code_type was not null and the server-specified timeout has passed.

  • reason: Reason of code resending; pass null if unknown (optional).

AuthenticationCodeInfo is returned on completion.

Inheritance

Constructors

ResendPhoneNumberCode({ResendCodeReason? reason})
ResendPhoneNumberCode (resendPhoneNumberCode) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
reason → ResendCodeReason?
Reason of code resending; pass null if unknown
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ResendCodeReason? reason}) → ResendPhoneNumberCode
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type