SearchChatMessages class final

SearchChatMessages (searchChatMessages) - TDLib function

Searches for messages with given words in the chat. Returns the results in reverse chronological order, i.e. in order of decreasing message_id. Cannot be used in secret chats with a non-empty query. (searchSecretMessages must be used instead), or without an enabled message database. For optimal performance, the number of returned messages is chosen by TDLib and can be smaller than the specified limit.. A combination of query, sender_id, filter and message_thread_id search criteria is expected to be supported, only if it is required for Telegram official application implementation.

  • chatId: Identifier of the chat in which to search messages.
  • query: Query to search for.
  • senderId: Identifier of the sender of messages to search for; pass null to search for messages from any sender. Not supported in secret chats (optional).
  • fromMessageId: Identifier of the message starting from which history must be fetched; use 0 to get results from the last message.
  • offset: Specify 0 to get results from exactly the message from_message_id or a negative offset to get the specified message and some newer messages.
  • limit: The maximum number of messages to be returned; must be positive and can't be greater than 100. If the offset is negative, the limit must be greater than -offset.. For optimal performance, the number of returned messages is chosen by TDLib and can be smaller than the specified limit.
  • filter: Additional filter for messages to search; pass null to search for all messages (optional).
  • messageThreadId: If not 0, only messages in the specified thread will be returned; supergroups only.
  • savedMessagesTopicId: If not 0, only messages in the specified Saved Messages topic will be returned; pass 0 to return all messages, or for chats other than Saved Messages.

FoundChatMessages is returned on completion.

Inheritance

Constructors

SearchChatMessages({required int chatId, required String query, MessageSender? senderId, required int fromMessageId, required int offset, required int limit, SearchMessagesFilter? filter, required int messageThreadId, required int savedMessagesTopicId})
SearchChatMessages (searchChatMessages) - TDLib function
const

Properties

chatId → int
Identifier of the chat in which to search messages
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
filter → SearchMessagesFilter?
Additional filter for messages to search; pass null to search for all messages
final
fromMessageId → int
Identifier of the message starting from which history must be fetched; use 0 to get results from the last message
final
hashCode → int
The hash code for this object.
no setterinherited
limit → int
The maximum number of messages to be returned; must be positive and can't be greater than 100. If the offset is negative, the limit must be greater than -offset.. For optimal performance, the number of returned messages is chosen by TDLib and can be smaller than the specified limit
final
messageThreadId → int
If not 0, only messages in the specified thread will be returned; supergroups only
final
offset → int
Specify 0 to get results from exactly the message from_message_id or a negative offset to get the specified message and some newer messages
final
query → String
Query to search for
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
savedMessagesTopicId → int
If not 0, only messages in the specified Saved Messages topic will be returned; pass 0 to return all messages, or for chats other than Saved Messages
final
senderId → MessageSender?
Identifier of the sender of messages to search for; pass null to search for messages from any sender. Not supported in secret chats
final

Methods

copyWith({int? chatId, String? query, MessageSender? senderId, int? fromMessageId, int? offset, int? limit, SearchMessagesFilter? filter, int? messageThreadId, int? savedMessagesTopicId}) → SearchChatMessages
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type