SearchChatRecentLocationMessages class final

SearchChatRecentLocationMessages (searchChatRecentLocationMessages) - TDLib function

Returns information about the recent locations of chat members that were sent to the chat. Returns up to 1 location message per user.

  • chatId: Chat identifier.
  • limit: The maximum number of messages to be returned.

Messages is returned on completion.

Inheritance

Constructors

SearchChatRecentLocationMessages({required int chatId, required int limit})
SearchChatRecentLocationMessages (searchChatRecentLocationMessages) - TDLib function
const

Properties

chatId → int
Chat identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
limit → int
The maximum number of messages to be returned
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? limit}) → SearchChatRecentLocationMessages
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type