SendBotStartMessage class final

SendBotStartMessage (sendBotStartMessage) - TDLib function

Invites a bot to a chat (if it is not yet a member) and sends it the /start command; requires can_invite_users member right. Bots can't be invited to a private chat other than the chat with the bot.. Bots can't be invited to channels (although they can be added as admins) and secret chats. Returns the sent message.

Message is returned on completion.

Inheritance

Constructors

SendBotStartMessage({required int botUserId, required int chatId, required String parameter})
SendBotStartMessage (sendBotStartMessage) - TDLib function
const

Properties

botUserId → int
Identifier of the bot
final
chatId → int
Identifier of the target chat
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
parameter → String
A hidden parameter sent to the bot for deep linking purposes (https://core.telegram.org/bots#deep-linking)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId, int? chatId, String? parameter}) → SendBotStartMessage
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type