SendCallLog class final

SendCallLog (sendCallLog) - TDLib function

Sends log file for a call to Telegram servers.

  • callId: Call identifier.
  • logFile: Call log file. Only inputFileLocal and inputFileGenerated are supported.

Ok is returned on completion.

Inheritance

Constructors

SendCallLog({required int callId, required InputFile logFile})
SendCallLog (sendCallLog) - TDLib function
const

Properties

callId → int
Call identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
logFile → InputFile
Call log file. Only inputFileLocal and inputFileGenerated are supported
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? callId, InputFile? logFile}) → SendCallLog
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type