SendEmailAddressVerificationCode class final

SendEmailAddressVerificationCode (sendEmailAddressVerificationCode) - TDLib function

Sends a code to verify an email address to be added to a user's Telegram Passport.

EmailAddressAuthenticationCodeInfo is returned on completion.

Inheritance

Constructors

SendEmailAddressVerificationCode({required String emailAddress})
SendEmailAddressVerificationCode (sendEmailAddressVerificationCode) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
emailAddress → String
Email address
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? emailAddress}) → SendEmailAddressVerificationCode
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type