SetArchiveChatListSettings class final

SetArchiveChatListSettings (setArchiveChatListSettings) - TDLib function

Changes settings for automatic moving of chats to and from the Archive chat lists.

Ok is returned on completion.

Inheritance

Constructors

SetArchiveChatListSettings({required ArchiveChatListSettings settings})
SetArchiveChatListSettings (setArchiveChatListSettings) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → ArchiveChatListSettings
New settings
final

Methods

copyWith({ArchiveChatListSettings? settings}) → SetArchiveChatListSettings
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type