SetBusinessMessageIsPinned class final

SetBusinessMessageIsPinned (setBusinessMessageIsPinned) - TDLib function

Pins or unpins a message sent on behalf of a business account; for bots only.

  • businessConnectionId: Unique identifier of business connection on behalf of which the message was sent.
  • chatId: The chat the message belongs to.
  • messageId: Identifier of the message.
  • isPinned: Pass true to pin the message, pass false to unpin it.

Ok is returned on completion.

Inheritance

Constructors

SetBusinessMessageIsPinned({required String businessConnectionId, required int chatId, required int messageId, required bool isPinned})
SetBusinessMessageIsPinned (setBusinessMessageIsPinned) - TDLib function
const

Properties

businessConnectionId → String
Unique identifier of business connection on behalf of which the message was sent
final
chatId → int
The chat the message belongs to
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
isPinned → bool
Pass true to pin the message, pass false to unpin it
final
messageId → int
Identifier of the message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? businessConnectionId, int? chatId, int? messageId, bool? isPinned}) → SetBusinessMessageIsPinned
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type