SetChatActiveStoriesList class final

SetChatActiveStoriesList (setChatActiveStoriesList) - TDLib function

Changes story list in which stories from the chat are shown.

  • chatId: Identifier of the chat that posted stories.
  • storyList: New list for active stories posted by the chat.

Ok is returned on completion.

Inheritance

Constructors

SetChatActiveStoriesList({required int chatId, required StoryList storyList})
SetChatActiveStoriesList (setChatActiveStoriesList) - TDLib function
const

Properties

chatId → int
Identifier of the chat that posted stories
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storyList → StoryList
New list for active stories posted by the chat
final

Methods

copyWith({int? chatId, StoryList? storyList}) → SetChatActiveStoriesList
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type