SetChatMessageSender class final

SetChatMessageSender (setChatMessageSender) - TDLib function

Selects a message sender to send messages in a chat.

Ok is returned on completion.

Inheritance

Constructors

SetChatMessageSender({required int chatId, required MessageSender messageSenderId})
SetChatMessageSender (setChatMessageSender) - TDLib function
const

Properties

chatId → int
Chat identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
messageSenderId → MessageSender
New message sender for the chat
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, MessageSender? messageSenderId}) → SetChatMessageSender
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type