SetChatPinnedStories class final

SetChatPinnedStories (setChatPinnedStories) - TDLib function

Changes the list of pinned stories on a chat page; requires can_edit_stories right in the chat.

  • chatId: Identifier of the chat that posted the stories.
  • storyIds: New list of pinned stories. All stories must be posted to the chat page first. There can be up to getOption("pinned_story_count_max") pinned stories on a chat page.

Ok is returned on completion.

Inheritance

Constructors

SetChatPinnedStories({required int chatId, required List<int> storyIds})
SetChatPinnedStories (setChatPinnedStories) - TDLib function
const

Properties

chatId → int
Identifier of the chat that posted the stories
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storyIds → List<int>
New list of pinned stories. All stories must be posted to the chat page first. There can be up to getOption("pinned_story_count_max") pinned stories on a chat page
final

Methods

copyWith({int? chatId, List<int>? storyIds}) → SetChatPinnedStories
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type