SetForumTopicNotificationSettings class final

SetForumTopicNotificationSettings (setForumTopicNotificationSettings) - TDLib function

Changes the notification settings of a forum topic.

  • chatId: Chat identifier.
  • messageThreadId: Message thread identifier of the forum topic.
  • notificationSettings: New notification settings for the forum topic. If the topic is muted for more than 366 days, it is considered to be muted forever.

Ok is returned on completion.

Inheritance

Constructors

SetForumTopicNotificationSettings({required int chatId, required int messageThreadId, required ChatNotificationSettings notificationSettings})
SetForumTopicNotificationSettings (setForumTopicNotificationSettings) - TDLib function
const

Properties

chatId → int
Chat identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
messageThreadId → int
Message thread identifier of the forum topic
final
notificationSettings → ChatNotificationSettings
New notification settings for the forum topic. If the topic is muted for more than 366 days, it is considered to be muted forever
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageThreadId, ChatNotificationSettings? notificationSettings}) → SetForumTopicNotificationSettings
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type