SetGroupCallTitle class final

SetGroupCallTitle (setGroupCallTitle) - TDLib function

Sets group call title. Requires groupCall.can_be_managed group call flag.

  • groupCallId: Group call identifier.
  • title: New group call title; 1-64 characters.

Ok is returned on completion.

Inheritance

Constructors

SetGroupCallTitle({required int groupCallId, required String title})
SetGroupCallTitle (setGroupCallTitle) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
groupCallId → int
Group call identifier
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
New group call title; 1-64 characters
final

Methods

copyWith({int? groupCallId, String? title}) → SetGroupCallTitle
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type