SetInactiveSessionTtl class final

SetInactiveSessionTtl (setInactiveSessionTtl) - TDLib function

Changes the period of inactivity after which sessions will automatically be terminated.

  • inactiveSessionTtlDays: New number of days of inactivity before sessions will be automatically terminated; 1-366 days.

Ok is returned on completion.

Inheritance

Constructors

SetInactiveSessionTtl({required int inactiveSessionTtlDays})
SetInactiveSessionTtl (setInactiveSessionTtl) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
inactiveSessionTtlDays → int
New number of days of inactivity before sessions will be automatically terminated; 1-366 days
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? inactiveSessionTtlDays}) → SetInactiveSessionTtl
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type