SetName class final
SetName (setName) - TDLib function
Changes the first and last name of the current user.
- firstName: The new value of the first name for the current user; 1-64 characters.
- lastName: The new value of the optional last name for the current user; 0-64 characters.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- SetName
Constructors
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- firstName → String
-
The new value of the first name for the current user; 1-64 characters
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastName → String
-
The new value of the optional last name for the current user; 0-64 characters
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? firstName, String? lastName}) → SetName - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type