SetOption class final

SetOption (setOption) - TDLib function

Sets the value of an option. (Check the list of available options on https://core.telegram.org/tdlib/options.) Only writable options can be set. Can be called before authorization.

  • name: The name of the option.
  • value: The new value of the option; pass null to reset option value to a default value (optional).

Ok is returned on completion.

Inheritance

Constructors

SetOption({required String name, OptionValue? value})
SetOption (setOption) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the option
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → OptionValue?
The new value of the option; pass null to reset option value to a default value
final

Methods

copyWith({String? name, OptionValue? value}) → SetOption
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type