SetPassportElement class final

SetPassportElement (setPassportElement) - TDLib function

Adds an element to the user's Telegram Passport. May return an error with a message "PHONE_VERIFICATION_NEEDED" or "EMAIL_VERIFICATION_NEEDED" if the chosen phone number or the chosen email address must be verified first.

  • element: Input Telegram Passport element.
  • password: The 2-step verification password of the current user.

PassportElement is returned on completion.

Inheritance

Constructors

SetPassportElement({required InputPassportElement element, required String password})
SetPassportElement (setPassportElement) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
element → InputPassportElement
Input Telegram Passport element
final
hashCode → int
The hash code for this object.
no setterinherited
password → String
The 2-step verification password of the current user
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({InputPassportElement? element, String? password}) → SetPassportElement
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type