SetPinnedSavedMessagesTopics class final

SetPinnedSavedMessagesTopics (setPinnedSavedMessagesTopics) - TDLib function

Changes the order of pinned Saved Messages topics.

Ok is returned on completion.

Inheritance

Constructors

SetPinnedSavedMessagesTopics({required List<int> savedMessagesTopicIds})
SetPinnedSavedMessagesTopics (setPinnedSavedMessagesTopics) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
savedMessagesTopicIds → List<int>
Identifiers of the new pinned Saved Messages topics
final

Methods

copyWith({List<int>? savedMessagesTopicIds}) → SetPinnedSavedMessagesTopics
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type