SetQuickReplyShortcutName class final

SetQuickReplyShortcutName (setQuickReplyShortcutName) - TDLib function

Changes name of a quick reply shortcut.

  • shortcutId: Unique identifier of the quick reply shortcut.
  • name: New name for the shortcut. Use checkQuickReplyShortcutName to check its validness.

Ok is returned on completion.

Inheritance

Constructors

SetQuickReplyShortcutName({required int shortcutId, required String name})
SetQuickReplyShortcutName (setQuickReplyShortcutName) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
name → String
New name for the shortcut. Use checkQuickReplyShortcutName to check its validness
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortcutId → int
Unique identifier of the quick reply shortcut
final

Methods

copyWith({int? shortcutId, String? name}) → SetQuickReplyShortcutName
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type