SetStoryPrivacySettings class final

SetStoryPrivacySettings (setStoryPrivacySettings) - TDLib function

Changes privacy settings of a story. The method can be called only for stories posted on behalf of the current user and if story.can_be_edited == true.

Ok is returned on completion.

Inheritance

Constructors

SetStoryPrivacySettings({required int storyId, required StoryPrivacySettings privacySettings})
SetStoryPrivacySettings (setStoryPrivacySettings) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
privacySettings → StoryPrivacySettings
The new privacy settigs for the story
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storyId → int
Identifier of the story
final

Methods

copyWith({int? storyId, StoryPrivacySettings? privacySettings}) → SetStoryPrivacySettings
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type