SetUserPersonalProfilePhoto class final

SetUserPersonalProfilePhoto (setUserPersonalProfilePhoto) - TDLib function

Changes a personal profile photo of a contact user.

  • userId: User identifier.
  • photo: Profile photo to set; pass null to delete the photo; inputChatPhotoPrevious isn't supported in this function (optional).

Ok is returned on completion.

Inheritance

Constructors

SetUserPersonalProfilePhoto({required int userId, InputChatPhoto? photo})
SetUserPersonalProfilePhoto (setUserPersonalProfilePhoto) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
photo → InputChatPhoto?
Profile photo to set; pass null to delete the photo; inputChatPhotoPrevious isn't supported in this function
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
User identifier
final

Methods

copyWith({int? userId, InputChatPhoto? photo}) → SetUserPersonalProfilePhoto
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type