SetUserSupportInfo class final
SetUserSupportInfo (setUserSupportInfo) - TDLib function
Sets support information for the given user; for Telegram support only.
UserSupportInfo is returned on completion.
- Inheritance
-
- Object
- TdFunction
- SetUserSupportInfo
Constructors
- SetUserSupportInfo({required int userId, required FormattedText message})
-
SetUserSupportInfo (setUserSupportInfo) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → FormattedText
-
New information message
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
User identifier
final
Methods
-
copyWith(
{int? userId, FormattedText? message}) → SetUserSupportInfo - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type