SetUsername class final

SetUsername (setUsername) - TDLib function

Changes the editable username of the current user.

  • username: The new value of the username. Use an empty string to remove the username. The username can't be completely removed if there is another active or disabled username.

Ok is returned on completion.

Inheritance

Constructors

SetUsername({required String username})
SetUsername (setUsername) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username → String
The new value of the username. Use an empty string to remove the username. The username can't be completely removed if there is another active or disabled username
final

Methods

copyWith({String? username}) → SetUsername
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type