ShareUsersWithBot class final

ShareUsersWithBot (shareUsersWithBot) - TDLib function

Shares users after pressing a keyboardButtonTypeRequestUsers button with the bot.

  • chatId: Identifier of the chat with the bot.
  • messageId: Identifier of the message with the button.
  • buttonId: Identifier of the button.
  • sharedUserIds: Identifiers of the shared users.
  • onlyCheck: Pass true to check that the users can be shared by the button instead of actually sharing them.

Ok is returned on completion.

Inheritance

Constructors

ShareUsersWithBot({required int chatId, required int messageId, required int buttonId, required List<int> sharedUserIds, required bool onlyCheck})
ShareUsersWithBot (shareUsersWithBot) - TDLib function
const

Properties

buttonId → int
Identifier of the button
final
chatId → int
Identifier of the chat with the bot
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
Identifier of the message with the button
final
onlyCheck → bool
Pass true to check that the users can be shared by the button instead of actually sharing them
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharedUserIds → List<int>
Identifiers of the shared users
final

Methods

copyWith({int? chatId, int? messageId, int? buttonId, List<int>? sharedUserIds, bool? onlyCheck}) → ShareUsersWithBot
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type