onlyCheck property
Pass true to check that the users can be shared by the button instead of actually sharing them
Implementation
final bool onlyCheck;
Pass true to check that the users can be shared by the button instead of actually sharing them
final bool onlyCheck;