StartGroupCallScreenSharing class final

StartGroupCallScreenSharing (startGroupCallScreenSharing) - TDLib function

Starts screen sharing in a joined group call. Returns join response payload for tgcalls.

  • groupCallId: Group call identifier.
  • audioSourceId: Screen sharing audio channel synchronization source identifier; received from tgcalls.
  • payload: Group call join payload; received from tgcalls.

Text is returned on completion.

Inheritance

Constructors

StartGroupCallScreenSharing({required int groupCallId, required int audioSourceId, required String payload})
StartGroupCallScreenSharing (startGroupCallScreenSharing) - TDLib function
const

Properties

audioSourceId → int
Screen sharing audio channel synchronization source identifier; received from tgcalls
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
groupCallId → int
Group call identifier
final
hashCode → int
The hash code for this object.
no setterinherited
payload → String
Group call join payload; received from tgcalls
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, int? audioSourceId, String? payload}) → StartGroupCallScreenSharing
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type