StickerSetInfo class final

StickerSetInfo (stickerSetInfo) - basic class

Represents short information about a sticker set.

  • id: Identifier of the sticker set.
  • title: Title of the sticker set.
  • name: Name of the sticker set.
  • thumbnail: Sticker set thumbnail in WEBP, TGS, or WEBM format with width and height 100; may be null. The file can be downloaded only before the thumbnail is changed (optional).
  • thumbnailOutline: Sticker set thumbnail's outline represented as a list of closed vector paths; may be empty. The coordinate system origin is in the upper-left corner.
  • isOwned: True, if the sticker set is owned by the current user.
  • isInstalled: True, if the sticker set has been installed by the current user.
  • isArchived: True, if the sticker set has been archived. A sticker set can't be installed and archived simultaneously.
  • isOfficial: True, if the sticker set is official.
  • stickerType: Type of the stickers in the set.
  • needsRepainting: True, if stickers in the sticker set are custom emoji that must be repainted; for custom emoji sticker sets only.
  • isAllowedAsChatEmojiStatus: True, if stickers in the sticker set are custom emoji that can be used as chat emoji status; for custom emoji sticker sets only.
  • isViewed: True for already viewed trending sticker sets.
  • size: Total number of stickers in the set.
  • covers: Up to the first 5 stickers from the set, depending on the context. If the application needs more stickers the full sticker set needs to be requested.
Inheritance

Constructors

StickerSetInfo({required int id, required String title, required String name, Thumbnail? thumbnail, required List<ClosedVectorPath> thumbnailOutline, required bool isOwned, required bool isInstalled, required bool isArchived, required bool isOfficial, required StickerType stickerType, required bool needsRepainting, required bool isAllowedAsChatEmojiStatus, required bool isViewed, required int size, required List<Sticker> covers})
StickerSetInfo (stickerSetInfo) - basic class
const
StickerSetInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
covers → List<Sticker>
Up to the first 5 stickers from the set, depending on the context. If the application needs more stickers the full sticker set needs to be requested
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
Identifier of the sticker set
final
isAllowedAsChatEmojiStatus → bool
True, if stickers in the sticker set are custom emoji that can be used as chat emoji status; for custom emoji sticker sets only
final
isArchived → bool
True, if the sticker set has been archived. A sticker set can't be installed and archived simultaneously
final
isInstalled → bool
True, if the sticker set has been installed by the current user
final
isOfficial → bool
True, if the sticker set is official
final
isOwned → bool
True, if the sticker set is owned by the current user
final
isViewed → bool
True for already viewed trending sticker sets
final
name → String
Name of the sticker set
final
needsRepainting → bool
True, if stickers in the sticker set are custom emoji that must be repainted; for custom emoji sticker sets only
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
Total number of stickers in the set
final
stickerType → StickerType
Type of the stickers in the set
final
thumbnail → Thumbnail?
Sticker set thumbnail in WEBP, TGS, or WEBM format with width and height 100; may be null. The file can be downloaded only before the thumbnail is changed
final
thumbnailOutline → List<ClosedVectorPath>
Sticker set thumbnail's outline represented as a list of closed vector paths; may be empty. The coordinate system origin is in the upper-left corner
final
title → String
Title of the sticker set
final

Methods

copyWith({int? id, String? title, String? name, Thumbnail? thumbnail, List<ClosedVectorPath>? thumbnailOutline, bool? isOwned, bool? isInstalled, bool? isArchived, bool? isOfficial, StickerType? stickerType, bool? needsRepainting, bool? isAllowedAsChatEmojiStatus, bool? isViewed, int? size, List<Sticker>? covers}) → StickerSetInfo
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type