StickerSetInfo constructor

const StickerSetInfo({
  1. required int id,
  2. required String title,
  3. required String name,
  4. Thumbnail? thumbnail,
  5. required List<ClosedVectorPath> thumbnailOutline,
  6. required bool isOwned,
  7. required bool isInstalled,
  8. required bool isArchived,
  9. required bool isOfficial,
  10. required StickerType stickerType,
  11. required bool needsRepainting,
  12. required bool isAllowedAsChatEmojiStatus,
  13. required bool isViewed,
  14. required int size,
  15. required List<Sticker> covers,
})

StickerSetInfo (stickerSetInfo) - basic class

Represents short information about a sticker set.

  • id: Identifier of the sticker set.
  • title: Title of the sticker set.
  • name: Name of the sticker set.
  • thumbnail: Sticker set thumbnail in WEBP, TGS, or WEBM format with width and height 100; may be null. The file can be downloaded only before the thumbnail is changed (optional).
  • thumbnailOutline: Sticker set thumbnail's outline represented as a list of closed vector paths; may be empty. The coordinate system origin is in the upper-left corner.
  • isOwned: True, if the sticker set is owned by the current user.
  • isInstalled: True, if the sticker set has been installed by the current user.
  • isArchived: True, if the sticker set has been archived. A sticker set can't be installed and archived simultaneously.
  • isOfficial: True, if the sticker set is official.
  • stickerType: Type of the stickers in the set.
  • needsRepainting: True, if stickers in the sticker set are custom emoji that must be repainted; for custom emoji sticker sets only.
  • isAllowedAsChatEmojiStatus: True, if stickers in the sticker set are custom emoji that can be used as chat emoji status; for custom emoji sticker sets only.
  • isViewed: True for already viewed trending sticker sets.
  • size: Total number of stickers in the set.
  • covers: Up to the first 5 stickers from the set, depending on the context. If the application needs more stickers the full sticker set needs to be requested.

Implementation

const StickerSetInfo({
  required this.id,
  required this.title,
  required this.name,
  this.thumbnail,
  required this.thumbnailOutline,
  required this.isOwned,
  required this.isInstalled,
  required this.isArchived,
  required this.isOfficial,
  required this.stickerType,
  required this.needsRepainting,
  required this.isAllowedAsChatEmojiStatus,
  required this.isViewed,
  required this.size,
  required this.covers,
});