Stickers class final

Stickers (stickers) - basic class

Represents a list of stickers.

Inheritance

Constructors

Stickers({required List<Sticker> stickers, dynamic extra, int? clientId})
Stickers (stickers) - basic class
const
Stickers.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stickers → List<Sticker>
List of stickers
final

Methods

copyWith({List<Sticker>? stickers, dynamic extra, int? clientId}) → Stickers
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type