StoryRepostInfo class final

StoryRepostInfo (storyRepostInfo) - basic class

Contains information about original story that was reposted.

  • origin: Origin of the story that was reposted.
  • isContentModified: True, if story content was modified during reposting; otherwise, story wasn't modified.
Inheritance

Constructors

StoryRepostInfo({required StoryOrigin origin, required bool isContentModified})
StoryRepostInfo (storyRepostInfo) - basic class
const
StoryRepostInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isContentModified → bool
True, if story content was modified during reposting; otherwise, story wasn't modified
final
origin → StoryOrigin
Origin of the story that was reposted
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({StoryOrigin? origin, bool? isContentModified}) → StoryRepostInfo
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type