SuggestUserProfilePhoto class final

SuggestUserProfilePhoto (suggestUserProfilePhoto) - TDLib function

Suggests a profile photo to another regular user with common messages.

  • userId: User identifier.
  • photo: Profile photo to suggest; inputChatPhotoPrevious isn't supported in this function.

Ok is returned on completion.

Inheritance

Constructors

SuggestUserProfilePhoto({required int userId, required InputChatPhoto photo})
SuggestUserProfilePhoto (suggestUserProfilePhoto) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
photo → InputChatPhoto
Profile photo to suggest; inputChatPhotoPrevious isn't supported in this function
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
User identifier
final

Methods

copyWith({int? userId, InputChatPhoto? photo}) → SuggestUserProfilePhoto
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type