TargetChatChosen class final

TargetChatChosen (targetChatChosen) - child of TargetChat

The chat needs to be chosen by the user among chats of the specified types.

Inheritance

Constructors

TargetChatChosen({required bool allowUserChats, required bool allowBotChats, required bool allowGroupChats, required bool allowChannelChats})
TargetChatChosen (targetChatChosen) - child of TargetChat
const
TargetChatChosen.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

allowBotChats → bool
True, if private chats with other bots are allowed
final
allowChannelChats → bool
True, if channel chats are allowed
final
allowGroupChats → bool
True, if basic group and supergroup chats are allowed
final
allowUserChats → bool
True, if private chats with ordinary users are allowed
final
clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? allowUserChats, bool? allowBotChats, bool? allowGroupChats, bool? allowChannelChats}) → TargetChatChosen
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type