TestProxy class final

TestProxy (testProxy) - TDLib function

Sends a simple network request to the Telegram servers via proxy; for testing only. Can be called before authorization.

  • server: Proxy server domain or IP address.
  • port: Proxy server port.
  • type: Proxy type.
  • dcId: Identifier of a datacenter with which to test connection.
  • timeout: The maximum overall timeout for the request.

Ok is returned on completion.

Inheritance

Constructors

TestProxy({required String server, required int port, required ProxyType type, required int dcId, required double timeout})
TestProxy (testProxy) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
dcId → int
Identifier of a datacenter with which to test connection
final
hashCode → int
The hash code for this object.
no setterinherited
port → int
Proxy server port
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
server → String
Proxy server domain or IP address
final
timeout → double
The maximum overall timeout for the request
final
type → ProxyType
Proxy type
final

Methods

copyWith({String? server, int? port, ProxyType? type, int? dcId, double? timeout}) → TestProxy
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type