Thumbnail class final

Thumbnail (thumbnail) - basic class

Represents a thumbnail.

Inheritance

Constructors

Thumbnail({required ThumbnailFormat format, required int width, required int height, required File file})
Thumbnail (thumbnail) - basic class
const
Thumbnail.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
file → File
The thumbnail
final
format → ThumbnailFormat
Thumbnail format
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
Thumbnail height
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
Thumbnail width
final

Methods

copyWith({ThumbnailFormat? format, int? width, int? height, File? file}) → Thumbnail
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type