ToggleGroupCallEnabledStartNotification class final

ToggleGroupCallEnabledStartNotification (toggleGroupCallEnabledStartNotification) - TDLib function

Toggles whether the current user will receive a notification when the group call starts; scheduled group calls only.

Ok is returned on completion.

Inheritance

Constructors

ToggleGroupCallEnabledStartNotification({required int groupCallId, required bool enabledStartNotification})
ToggleGroupCallEnabledStartNotification (toggleGroupCallEnabledStartNotification) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
enabledStartNotification → bool
New value of the enabled_start_notification setting
final
groupCallId → int
Group call identifier
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, bool? enabledStartNotification}) → ToggleGroupCallEnabledStartNotification
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type