ToggleSupergroupIsAllHistoryAvailable class final

ToggleSupergroupIsAllHistoryAvailable (toggleSupergroupIsAllHistoryAvailable) - TDLib function

Toggles whether the message history of a supergroup is available to new members; requires can_change_info member right.

Ok is returned on completion.

Inheritance

Constructors

ToggleSupergroupIsAllHistoryAvailable({required int supergroupId, required bool isAllHistoryAvailable})
ToggleSupergroupIsAllHistoryAvailable (toggleSupergroupIsAllHistoryAvailable) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
isAllHistoryAvailable → bool
The new value of is_all_history_available
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supergroupId → int
The identifier of the supergroup
final

Methods

copyWith({int? supergroupId, bool? isAllHistoryAvailable}) → ToggleSupergroupIsAllHistoryAvailable
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type