ToggleSupergroupJoinByRequest class final

ToggleSupergroupJoinByRequest (toggleSupergroupJoinByRequest) - TDLib function

Toggles whether all users directly joining the supergroup need to be approved by supergroup administrators; requires can_restrict_members administrator right.

Ok is returned on completion.

Inheritance

Constructors

ToggleSupergroupJoinByRequest({required int supergroupId, required bool joinByRequest})
ToggleSupergroupJoinByRequest (toggleSupergroupJoinByRequest) - TDLib function
const

Properties

currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
joinByRequest → bool
New value of join_by_request
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supergroupId → int
Identifier of the supergroup that isn't a broadcast group
final

Methods

copyWith({int? supergroupId, bool? joinByRequest}) → ToggleSupergroupJoinByRequest
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type