TransferChatOwnership class final

TransferChatOwnership (transferChatOwnership) - TDLib function

Changes the owner of a chat; requires owner privileges in the chat. Use the method canTransferOwnership to check whether the ownership can be transferred from the current session. Available only for supergroups and channel chats.

  • chatId: Chat identifier.
  • userId: Identifier of the user to which transfer the ownership. The ownership can't be transferred to a bot or to a deleted user.
  • password: The 2-step verification password of the current user.

Ok is returned on completion.

Inheritance

Constructors

TransferChatOwnership({required int chatId, required int userId, required String password})
TransferChatOwnership (transferChatOwnership) - TDLib function
const

Properties

chatId → int
Chat identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
password → String
The 2-step verification password of the current user
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
Identifier of the user to which transfer the ownership. The ownership can't be transferred to a bot or to a deleted user
final

Methods

copyWith({int? chatId, int? userId, String? password}) → TransferChatOwnership
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type