UpdateAutosaveSettings class final

UpdateAutosaveSettings (updateAutosaveSettings) - child of Update

Autosave settings for some type of chats were updated.

  • scope: Type of chats for which autosave settings were updated.
  • settings: The new autosave settings; may be null if the settings are reset to default (optional).
Inheritance

Constructors

UpdateAutosaveSettings({required AutosaveSettingsScope scope, ScopeAutosaveSettings? settings, dynamic extra, int? clientId})
UpdateAutosaveSettings (updateAutosaveSettings) - child of Update
const
UpdateAutosaveSettings.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → AutosaveSettingsScope
Type of chats for which autosave settings were updated
final
settings → ScopeAutosaveSettings?
The new autosave settings; may be null if the settings are reset to default
final

Methods

copyWith({AutosaveSettingsScope? scope, ScopeAutosaveSettings? settings, dynamic extra, int? clientId}) → UpdateAutosaveSettings
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type