UpdateAvailableMessageEffects class final

UpdateAvailableMessageEffects (updateAvailableMessageEffects) - child of Update

The list of available message effects has changed.

  • reactionEffectIds: The new list of available message effects from emoji reactions.
  • stickerEffectIds: The new list of available message effects from Premium stickers.
Inheritance

Constructors

UpdateAvailableMessageEffects({required List<int> reactionEffectIds, required List<int> stickerEffectIds, dynamic extra, int? clientId})
UpdateAvailableMessageEffects (updateAvailableMessageEffects) - child of Update
const
UpdateAvailableMessageEffects.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
reactionEffectIds → List<int>
The new list of available message effects from emoji reactions
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stickerEffectIds → List<int>
The new list of available message effects from Premium stickers
final

Methods

copyWith({List<int>? reactionEffectIds, List<int>? stickerEffectIds, dynamic extra, int? clientId}) → UpdateAvailableMessageEffects
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type