UpdateChatAvailableReactions class final

UpdateChatAvailableReactions (updateChatAvailableReactions) - child of Update

The chat available reactions were changed.

Inheritance

Constructors

UpdateChatAvailableReactions({required int chatId, required ChatAvailableReactions availableReactions, dynamic extra, int? clientId})
UpdateChatAvailableReactions (updateChatAvailableReactions) - child of Update
const
UpdateChatAvailableReactions.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

availableReactions → ChatAvailableReactions
The new reactions, available in the chat
final
chatId → int
Chat identifier
final
clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, ChatAvailableReactions? availableReactions, dynamic extra, int? clientId}) → UpdateChatAvailableReactions
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type