UpdateChatBusinessBotManageBar class final

UpdateChatBusinessBotManageBar (updateChatBusinessBotManageBar) - child of Update

The bar for managing business bot was changed in a chat.

Inheritance

Constructors

UpdateChatBusinessBotManageBar({required int chatId, BusinessBotManageBar? businessBotManageBar, dynamic extra, int? clientId})
UpdateChatBusinessBotManageBar (updateChatBusinessBotManageBar) - child of Update
const
UpdateChatBusinessBotManageBar.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

businessBotManageBar → BusinessBotManageBar?
The new value of the business bot manage bar; may be null
final
chatId → int
Chat identifier
final
clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, BusinessBotManageBar? businessBotManageBar, dynamic extra, int? clientId}) → UpdateChatBusinessBotManageBar
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type