UpdateChatDraftMessage constructor

const UpdateChatDraftMessage({
  1. required int chatId,
  2. DraftMessage? draftMessage,
  3. required List<ChatPosition> positions,
  4. dynamic extra,
  5. int? clientId,
})

UpdateChatDraftMessage (updateChatDraftMessage) - child of Update

A chat draft has changed. Be aware that the update may come in the currently opened chat but with old content of the draft. If the user has changed the content of the draft, this update mustn't be applied.

  • chatId: Chat identifier.
  • draftMessage: The new draft message; may be null if none (optional).
  • positions: The new chat positions in the chat lists.

Implementation

const UpdateChatDraftMessage({
  required this.chatId,
  this.draftMessage,
  required this.positions,
  this.extra,
  this.clientId,
});