UpdateChatNotificationSettings class final
UpdateChatNotificationSettings (updateChatNotificationSettings) - child of Update
Notification settings for a chat were changed.
- chatId: Chat identifier.
- notificationSettings: The new notification settings.
Constructors
- UpdateChatNotificationSettings({required int chatId, required ChatNotificationSettings notificationSettings, dynamic extra, int? clientId})
-
UpdateChatNotificationSettings (updateChatNotificationSettings) - child of Update
const
-
UpdateChatNotificationSettings.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- chatId → int
-
Chat identifier
final
- clientId → int?
-
clientId client identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
extra callback sign
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- notificationSettings → ChatNotificationSettings
-
The new notification settings
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, ChatNotificationSettings? notificationSettings, dynamic extra, int? clientId}) → UpdateChatNotificationSettings -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type