UpdateChatReadInbox class final

UpdateChatReadInbox (updateChatReadInbox) - child of Update

Incoming messages were read or the number of unread messages has been changed.

Inheritance

Constructors

UpdateChatReadInbox({required int chatId, required int lastReadInboxMessageId, required int unreadCount, dynamic extra, int? clientId})
UpdateChatReadInbox (updateChatReadInbox) - child of Update
const
UpdateChatReadInbox.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
Chat identifier
final
clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
lastReadInboxMessageId → int
Identifier of the last read incoming message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreadCount → int
The number of unread messages left in the chat
final

Methods

copyWith({int? chatId, int? lastReadInboxMessageId, int? unreadCount, dynamic extra, int? clientId}) → UpdateChatReadInbox
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type