UpdateChatReplyMarkup class final

UpdateChatReplyMarkup (updateChatReplyMarkup) - child of Update

The default chat reply markup was changed. Can occur because new messages with reply markup were received or because an old reply markup was hidden by the user.

  • chatId: Chat identifier.
  • replyMarkupMessageId: Identifier of the message from which reply markup needs to be used; 0 if there is no default custom reply markup in the chat.
Inheritance

Constructors

UpdateChatReplyMarkup({required int chatId, required int replyMarkupMessageId, dynamic extra, int? clientId})
UpdateChatReplyMarkup (updateChatReplyMarkup) - child of Update
const
UpdateChatReplyMarkup.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
Chat identifier
final
clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
replyMarkupMessageId → int
Identifier of the message from which reply markup needs to be used; 0 if there is no default custom reply markup in the chat
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? replyMarkupMessageId, dynamic extra, int? clientId}) → UpdateChatReplyMarkup
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type