replyMarkupMessageId property
Identifier of the message from which reply markup needs to be used; 0 if there is no default custom reply markup in the chat
Implementation
final int replyMarkupMessageId;
Identifier of the message from which reply markup needs to be used; 0 if there is no default custom reply markup in the chat
final int replyMarkupMessageId;