UpdateChatRevenueAmount class final

UpdateChatRevenueAmount (updateChatRevenueAmount) - child of Update

The revenue earned from sponsored messages in a chat has changed. If chat revenue screen is opened, then getChatRevenueTransactions may be called to fetch new transactions.

Inheritance

Constructors

UpdateChatRevenueAmount({required int chatId, required ChatRevenueAmount revenueAmount, dynamic extra, int? clientId})
UpdateChatRevenueAmount (updateChatRevenueAmount) - child of Update
const
UpdateChatRevenueAmount.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
Identifier of the chat
final
clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
revenueAmount → ChatRevenueAmount
New amount of earned revenue
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, ChatRevenueAmount? revenueAmount, dynamic extra, int? clientId}) → UpdateChatRevenueAmount
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type