UpdateChatTheme class final

UpdateChatTheme (updateChatTheme) - child of Update

The chat theme was changed.

  • chatId: Chat identifier.
  • themeName: The new name of the chat theme; may be empty if theme was reset to default.
Inheritance

Constructors

UpdateChatTheme({required int chatId, required String themeName, dynamic extra, int? clientId})
UpdateChatTheme (updateChatTheme) - child of Update
const
UpdateChatTheme.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
Chat identifier
final
clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
themeName → String
The new name of the chat theme; may be empty if theme was reset to default
final

Methods

copyWith({int? chatId, String? themeName, dynamic extra, int? clientId}) → UpdateChatTheme
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type