UpdateChatTitle class final

UpdateChatTitle (updateChatTitle) - child of Update

The title of a chat was changed.

Inheritance

Constructors

UpdateChatTitle({required int chatId, required String title, dynamic extra, int? clientId})
UpdateChatTitle (updateChatTitle) - child of Update
const
UpdateChatTitle.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
Chat identifier
final
clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
The new chat title
final

Methods

copyWith({int? chatId, String? title, dynamic extra, int? clientId}) → UpdateChatTitle
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type