UpdateLanguagePackStrings class final

UpdateLanguagePackStrings (updateLanguagePackStrings) - child of Update

Some language pack strings have been updated.

  • localizationTarget: Localization target to which the language pack belongs.
  • languagePackId: Identifier of the updated language pack.
  • strings: List of changed language pack strings; empty if all strings have changed.
Inheritance

Constructors

UpdateLanguagePackStrings({required String localizationTarget, required String languagePackId, required List<LanguagePackString> strings, dynamic extra, int? clientId})
UpdateLanguagePackStrings (updateLanguagePackStrings) - child of Update
const
UpdateLanguagePackStrings.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
languagePackId → String
Identifier of the updated language pack
final
localizationTarget → String
Localization target to which the language pack belongs
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strings → List<LanguagePackString>
List of changed language pack strings; empty if all strings have changed
final

Methods

copyWith({String? localizationTarget, String? languagePackId, List<LanguagePackString>? strings, dynamic extra, int? clientId}) → UpdateLanguagePackStrings
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type