UpdateMessageSendFailed class final

UpdateMessageSendFailed (updateMessageSendFailed) - child of Update

A message failed to send. Be aware that some messages being sent can be irrecoverably deleted, in which case updateDeleteMessages will be received instead of this update.

  • message: The failed to send message.
  • oldMessageId: The previous temporary message identifier.
  • error: The cause of the message sending failure.
Inheritance

Constructors

UpdateMessageSendFailed({required Message message, required int oldMessageId, required TdError error, dynamic extra, int? clientId})
UpdateMessageSendFailed (updateMessageSendFailed) - child of Update
const
UpdateMessageSendFailed.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
error → TdError
The cause of the message sending failure
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
message → Message
The failed to send message
final
oldMessageId → int
The previous temporary message identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Message? message, int? oldMessageId, TdError? error, dynamic extra, int? clientId}) → UpdateMessageSendFailed
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type