UpdateMessageUnreadReactions class final

UpdateMessageUnreadReactions (updateMessageUnreadReactions) - child of Update

The list of unread reactions added to a message was changed.

Inheritance

Constructors

UpdateMessageUnreadReactions({required int chatId, required int messageId, required List<UnreadReaction> unreadReactions, required int unreadReactionCount, dynamic extra, int? clientId})
UpdateMessageUnreadReactions (updateMessageUnreadReactions) - child of Update
const
UpdateMessageUnreadReactions.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
Chat identifier
final
clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
Message identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreadReactionCount → int
The new number of messages with unread reactions left in the chat
final
unreadReactions → List<UnreadReaction>
The new list of unread reactions
final

Methods

copyWith({int? chatId, int? messageId, List<UnreadReaction>? unreadReactions, int? unreadReactionCount, dynamic extra, int? clientId}) → UpdateMessageUnreadReactions
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type