UpdateNewBusinessMessage class final

UpdateNewBusinessMessage (updateNewBusinessMessage) - child of Update

A new message was added to a business account; for bots only.

Inheritance

Constructors

UpdateNewBusinessMessage({required String connectionId, required BusinessMessage message, dynamic extra, int? clientId})
UpdateNewBusinessMessage (updateNewBusinessMessage) - child of Update
const
UpdateNewBusinessMessage.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
connectionId → String
Unique identifier of the business connection
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
message → BusinessMessage
The new message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? connectionId, BusinessMessage? message, dynamic extra, int? clientId}) → UpdateNewBusinessMessage
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type