UpdatePollAnswer class final

UpdatePollAnswer (updatePollAnswer) - child of Update

A user changed the answer to a poll; for bots only.

  • pollId: Unique poll identifier.
  • voterId: Identifier of the message sender that changed the answer to the poll.
  • optionIds: 0-based identifiers of answer options, chosen by the user.
Inheritance

Constructors

UpdatePollAnswer({required int pollId, required MessageSender voterId, required List<int> optionIds, dynamic extra, int? clientId})
UpdatePollAnswer (updatePollAnswer) - child of Update
const
UpdatePollAnswer.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
optionIds → List<int>
0-based identifiers of answer options, chosen by the user
final
pollId → int
Unique poll identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
voterId → MessageSender
Identifier of the message sender that changed the answer to the poll
final

Methods

copyWith({int? pollId, MessageSender? voterId, List<int>? optionIds, dynamic extra, int? clientId}) → UpdatePollAnswer
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type