UpdateQuickReplyShortcutDeleted class final

UpdateQuickReplyShortcutDeleted (updateQuickReplyShortcutDeleted) - child of Update

A quick reply shortcut and all its messages were deleted.

  • shortcutId: The identifier of the deleted shortcut.
Inheritance

Constructors

UpdateQuickReplyShortcutDeleted({required int shortcutId, dynamic extra, int? clientId})
UpdateQuickReplyShortcutDeleted (updateQuickReplyShortcutDeleted) - child of Update
const
UpdateQuickReplyShortcutDeleted.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortcutId → int
The identifier of the deleted shortcut
final

Methods

copyWith({int? shortcutId, dynamic extra, int? clientId}) → UpdateQuickReplyShortcutDeleted
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type