UpdateScopeNotificationSettings class final

UpdateScopeNotificationSettings (updateScopeNotificationSettings) - child of Update

Notification settings for some type of chats were updated.

Inheritance

Constructors

UpdateScopeNotificationSettings({required NotificationSettingsScope scope, required ScopeNotificationSettings notificationSettings, dynamic extra, int? clientId})
UpdateScopeNotificationSettings (updateScopeNotificationSettings) - child of Update
const
UpdateScopeNotificationSettings.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
notificationSettings → ScopeNotificationSettings
The new notification settings
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → NotificationSettingsScope
Types of chats for which notification settings were updated
final

Methods

copyWith({NotificationSettingsScope? scope, ScopeNotificationSettings? notificationSettings, dynamic extra, int? clientId}) → UpdateScopeNotificationSettings
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type