UpdateSpeedLimitNotification class final

UpdateSpeedLimitNotification (updateSpeedLimitNotification) - child of Update

Download or upload file speed for the user was limited, but it can be restored by subscription to Telegram Premium. The notification can be postponed until a being downloaded or uploaded file is visible to the user. Use getOption("premium_download_speedup") or getOption("premium_upload_speedup") to get expected speedup after subscription to Telegram Premium.

  • isUpload: True, if upload speed was limited; false, if download speed was limited.
Inheritance

Constructors

UpdateSpeedLimitNotification({required bool isUpload, dynamic extra, int? clientId})
UpdateSpeedLimitNotification (updateSpeedLimitNotification) - child of Update
const
UpdateSpeedLimitNotification.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
isUpload → bool
True, if upload speed was limited; false, if download speed was limited
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isUpload, dynamic extra, int? clientId}) → UpdateSpeedLimitNotification
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type