UpdateStickerSet class final

UpdateStickerSet (updateStickerSet) - child of Update

A sticker set has changed.

Inheritance

Constructors

UpdateStickerSet({required StickerSet stickerSet, dynamic extra, int? clientId})
UpdateStickerSet (updateStickerSet) - child of Update
const
UpdateStickerSet.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stickerSet → StickerSet
The sticker set
final

Methods

copyWith({StickerSet? stickerSet, dynamic extra, int? clientId}) → UpdateStickerSet
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type