UpdateStorySendFailed class final

UpdateStorySendFailed (updateStorySendFailed) - child of Update

A story failed to send. If the story sending is canceled, then updateStoryDeleted will be received instead of this update.

  • story: The failed to send story.
  • error: The cause of the story sending failure.
  • errorType: Type of the error; may be null if unknown (optional).
Inheritance

Constructors

UpdateStorySendFailed({required Story story, required TdError error, CanSendStoryResult? errorType, dynamic extra, int? clientId})
UpdateStorySendFailed (updateStorySendFailed) - child of Update
const
UpdateStorySendFailed.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
error → TdError
The cause of the story sending failure
final
errorType → CanSendStoryResult?
Type of the error; may be null if unknown
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
story → Story
The failed to send story
final

Methods

copyWith({Story? story, TdError? error, CanSendStoryResult? errorType, dynamic extra, int? clientId}) → UpdateStorySendFailed
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type