UpdateTrendingStickerSets class final

UpdateTrendingStickerSets (updateTrendingStickerSets) - child of Update

The list of trending sticker sets was updated or some of them were viewed.

  • stickerType: Type of the affected stickers.
  • stickerSets: The prefix of the list of trending sticker sets with the newest trending sticker sets.
Inheritance

Constructors

UpdateTrendingStickerSets({required StickerType stickerType, required TrendingStickerSets stickerSets, dynamic extra, int? clientId})
UpdateTrendingStickerSets (updateTrendingStickerSets) - child of Update
const
UpdateTrendingStickerSets.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stickerSets → TrendingStickerSets
The prefix of the list of trending sticker sets with the newest trending sticker sets
final
stickerType → StickerType
Type of the affected stickers
final

Methods

copyWith({StickerType? stickerType, TrendingStickerSets? stickerSets, dynamic extra, int? clientId}) → UpdateTrendingStickerSets
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type