UpdateUnconfirmedSession class final

UpdateUnconfirmedSession (updateUnconfirmedSession) - child of Update

The first unconfirmed session has changed.

  • session: The unconfirmed session; may be null if none (optional).
Inheritance

Constructors

UpdateUnconfirmedSession({UnconfirmedSession? session, dynamic extra, int? clientId})
UpdateUnconfirmedSession (updateUnconfirmedSession) - child of Update
const
UpdateUnconfirmedSession.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
session → UnconfirmedSession?
The unconfirmed session; may be null if none
final

Methods

copyWith({UnconfirmedSession? session, dynamic extra, int? clientId}) → UpdateUnconfirmedSession
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type