UpdateUnreadMessageCount class final

UpdateUnreadMessageCount (updateUnreadMessageCount) - child of Update

Number of unread messages in a chat list has changed. This update is sent only if the message database is used.

Inheritance

Constructors

UpdateUnreadMessageCount({required ChatList chatList, required int unreadCount, required int unreadUnmutedCount, dynamic extra, int? clientId})
UpdateUnreadMessageCount (updateUnreadMessageCount) - child of Update
const
UpdateUnreadMessageCount.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatList → ChatList
The chat list with changed number of unread messages
final
clientId → int?
clientId client identifier
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreadCount → int
Total number of unread messages
final
unreadUnmutedCount → int
Total number of unread messages in unmuted chats
final

Methods

copyWith({ChatList? chatList, int? unreadCount, int? unreadUnmutedCount, dynamic extra, int? clientId}) → UpdateUnreadMessageCount
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type