UpdateUserStatus class final
UpdateUserStatus (updateUserStatus) - child of Update
The user went online or offline.
Constructors
- UpdateUserStatus({required int userId, required UserStatus status, dynamic extra, int? clientId})
-
UpdateUserStatus (updateUserStatus) - child of Update
const
-
UpdateUserStatus.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
clientId client identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
extra callback sign
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → UserStatus
-
New status of the user
final
- userId → int
-
User identifier
final
Methods
-
copyWith(
{int? userId, UserStatus? status, dynamic extra, int? clientId}) → UpdateUserStatus -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type