VideoNote class final

VideoNote (videoNote) - basic class

Describes a video note. The video must be equal in width and height, cropped to a circle, and stored in MPEG4 format.

  • duration: Duration of the video, in seconds; as defined by the sender.
  • waveform: A waveform representation of the video note's audio in 5-bit format; may be empty if unknown.
  • length: Video width and height; as defined by the sender.
  • minithumbnail: Video minithumbnail; may be null (optional).
  • thumbnail: Video thumbnail in JPEG format; as defined by the sender; may be null (optional).
  • speechRecognitionResult: Result of speech recognition in the video note; may be null (optional).
  • video: File containing the video.
Inheritance

Constructors

VideoNote({required int duration, required String waveform, required int length, Minithumbnail? minithumbnail, Thumbnail? thumbnail, SpeechRecognitionResult? speechRecognitionResult, required File video})
VideoNote (videoNote) - basic class
const
VideoNote.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
Client ID, from which this object was received
no setterinherited
currentObjectId → String
TDLib object type for current class instance
no setteroverride
duration → int
Duration of the video, in seconds; as defined by the sender
final
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
length → int
Video width and height; as defined by the sender
final
minithumbnail → Minithumbnail?
Video minithumbnail; may be null
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speechRecognitionResult → SpeechRecognitionResult?
Result of speech recognition in the video note; may be null
final
thumbnail → Thumbnail?
Video thumbnail in JPEG format; as defined by the sender; may be null
final
video → File
File containing the video
final
waveform → String
A waveform representation of the video note's audio in 5-bit format; may be empty if unknown
final

Methods

copyWith({int? duration, String? waveform, int? length, Minithumbnail? minithumbnail, Thumbnail? thumbnail, SpeechRecognitionResult? speechRecognitionResult, File? video}) → VideoNote
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type