ViewPremiumFeature class final
ViewPremiumFeature (viewPremiumFeature) - TDLib function
Informs TDLib that the user viewed detailed information about a Premium feature on the Premium features screen.
- feature: The viewed premium feature.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- ViewPremiumFeature
Constructors
- ViewPremiumFeature({required PremiumFeature feature})
-
ViewPremiumFeature (viewPremiumFeature) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- feature → PremiumFeature
-
The viewed premium feature
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{PremiumFeature? feature}) → ViewPremiumFeature - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type