AddBotMediaPreview class final
AddBotMediaPreview (addBotMediaPreview) - TDLib function
Adds a new media preview to the beginning of the list of media previews of a bot. Returns the added preview after addition is completed server-side. The total number of previews must not exceed getOption("bot_media_preview_count_max") for the given language.
- botUserId: Identifier of the target bot. The bot must be owned and must have the main Web App.
- languageCode: A two-letter ISO 639-1 language code for which preview is added. If empty, then the preview will be shown to all users for whose languages there are no dedicated previews.. If non-empty, then there must be an official language pack of the same name, which is returned by getLocalizationTargetInfo.
- content: Content of the added preview.
BotMediaPreview is returned on completion.
- Inheritance
-
- Object
- TdFunction
- AddBotMediaPreview
Constructors
- AddBotMediaPreview({required int botUserId, required String languageCode, required InputStoryContent content})
-
AddBotMediaPreview (addBotMediaPreview) - TDLib function
const
Properties
- botUserId → int
-
Identifier of the target bot. The bot must be owned and must have the main Web App
final
- content → InputStoryContent
-
Content of the added preview
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- languageCode → String
-
A two-letter ISO 639-1 language code for which preview is added. If empty, then the preview will be shown to all users for whose languages there are no dedicated previews.. If non-empty, then there must be an official language pack of the same name, which is returned by getLocalizationTargetInfo
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? botUserId, String? languageCode, InputStoryContent? content}) → AddBotMediaPreview - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type