AddCustomServerLanguagePack class final
AddCustomServerLanguagePack (addCustomServerLanguagePack) - TDLib function
Adds a custom server language pack to the list of installed language packs in current localization target. Can be called before authorization.
- languagePackId: Identifier of a language pack to be added.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- AddCustomServerLanguagePack
Constructors
- AddCustomServerLanguagePack({required String languagePackId})
-
AddCustomServerLanguagePack (addCustomServerLanguagePack) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- languagePackId → String
-
Identifier of a language pack to be added
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? languagePackId}) → AddCustomServerLanguagePack - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type