AddQuickReplyShortcutMessage class final
AddQuickReplyShortcutMessage (addQuickReplyShortcutMessage) - TDLib function
Adds a message to a quick reply shortcut. If shortcut doesn't exist and there are less than getOption("quick_reply_shortcut_count_max") shortcuts, then a new shortcut is created.. The shortcut must not contain more than getOption("quick_reply_shortcut_message_count_max") messages after adding the new message. Returns the added message.
- shortcutName: Name of the target shortcut.
- replyToMessageId: Identifier of a quick reply message in the same shortcut to be replied; pass 0 if none.
- inputMessageContent: The content of the message to be added; inputMessagePoll, inputMessageForwarded and inputMessageLocation with live_period aren't supported.
QuickReplyMessage is returned on completion.
- Inheritance
-
- Object
- TdFunction
- AddQuickReplyShortcutMessage
Constructors
- AddQuickReplyShortcutMessage({required String shortcutName, required int replyToMessageId, required InputMessageContent inputMessageContent})
-
AddQuickReplyShortcutMessage (addQuickReplyShortcutMessage) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputMessageContent → InputMessageContent
-
The content of the message to be added; inputMessagePoll, inputMessageForwarded and inputMessageLocation with live_period aren't supported
final
- replyToMessageId → int
-
Identifier of a quick reply message in the same shortcut to be replied; pass 0 if none
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortcutName → String
-
Name of the target shortcut
final
Methods
-
copyWith(
{String? shortcutName, int? replyToMessageId, InputMessageContent? inputMessageContent}) → AddQuickReplyShortcutMessage - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type