AddRecentlyFoundChat class final
AddRecentlyFoundChat (addRecentlyFoundChat) - TDLib function
Adds a chat to the list of recently found chats. The chat is added to the beginning of the list. If the chat is already in the list, it will be removed from the list first.
- chatId: Identifier of the chat to add.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- AddRecentlyFoundChat
Constructors
- AddRecentlyFoundChat({required int chatId})
-
AddRecentlyFoundChat (addRecentlyFoundChat) - TDLib function
const
Properties
- chatId → int
-
Identifier of the chat to add
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId}) → AddRecentlyFoundChat - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type