Address class final
Address (address) - basic class
Describes an address.
- countryCode: A two-letter ISO 3166-1 alpha-2 country code.
- state: State, if applicable.
- streetLine1: First line of the address.
- streetLine2: Second line of the address.
- postalCode: Address postal code.
Constructors
Properties
- city → String
-
City
final
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- countryCode → String
-
A two-letter ISO 3166-1 alpha-2 country code
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- postalCode → String
-
Address postal code
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → String
-
State, if applicable
final
- streetLine1 → String
-
First line of the address
final
- streetLine2 → String
-
Second line of the address
final
Methods
-
copyWith(
{String? countryCode, String? state, String? city, String? streetLine1, String? streetLine2, String? postalCode}) → Address - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type