BanChatMember class final
BanChatMember (banChatMember) - TDLib function
Bans a member in a chat; requires can_restrict_members administrator right. Members can't be banned in private or secret chats. In supergroups and channels, the user will not be able to return to the group on their own using invite links, etc., unless unbanned first.
- chatId: Chat identifier.
- memberId: Member identifier.
- bannedUntilDate: Point in time (Unix timestamp) when the user will be unbanned; 0 if never. If the user is banned for more than 366 days or for less than 30 seconds from the current time, the user is considered to be banned forever. Ignored in basic groups and if a chat is banned.
- revokeMessages: Pass true to delete all messages in the chat for the user that is being removed. Always true for supergroups and channels.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- BanChatMember
Constructors
- BanChatMember({required int chatId, required MessageSender memberId, required int bannedUntilDate, required bool revokeMessages})
-
BanChatMember (banChatMember) - TDLib function
const
Properties
- bannedUntilDate → int
-
Point in time (Unix timestamp) when the user will be unbanned; 0 if never. If the user is banned for more than 366 days or for less than 30 seconds from the current time, the user is considered to be banned forever. Ignored in basic groups and if a chat is banned
final
- chatId → int
-
Chat identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- memberId → MessageSender
-
Member identifier
final
- revokeMessages → bool
-
Pass true to delete all messages in the chat for the user that is being removed. Always true for supergroups and channels
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, MessageSender? memberId, int? bannedUntilDate, bool? revokeMessages}) → BanChatMember - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type