BasicGroup class final
BasicGroup (basicGroup) - basic class
Represents a basic group of 0-200 users (must be upgraded to a supergroup to accommodate more than 200 users).
- id: Group identifier.
- memberCount: Number of members in the group.
- status: Status of the current user in the group.
- isActive: True, if the group is active.
- upgradedToSupergroupId: Identifier of the supergroup to which this group was upgraded; 0 if none.
Constructors
- BasicGroup({required int id, required int memberCount, required ChatMemberStatus status, required bool isActive, required int upgradedToSupergroupId, dynamic extra, int? clientId})
-
BasicGroup (basicGroup) - basic class
const
-
BasicGroup.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
clientId client identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
extra callback sign
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Group identifier
final
- isActive → bool
-
True, if the group is active
final
- memberCount → int
-
Number of members in the group
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → ChatMemberStatus
-
Status of the current user in the group
final
- upgradedToSupergroupId → int
-
Identifier of the supergroup to which this group was upgraded; 0 if none
final
Methods
-
copyWith(
{int? id, int? memberCount, ChatMemberStatus? status, bool? isActive, int? upgradedToSupergroupId, dynamic extra, int? clientId}) → BasicGroup - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type