Birthdate class final
Birthdate (birthdate) - basic class
Represents a birthdate of a user.
Constructors
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- day → int
-
Day of the month; 1-31
final
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- month → int
-
Month of the year; 1-12
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- year → int
-
Birth year; 0 if unknown
final
Methods
-
copyWith(
{int? day, int? month, int? year}) → Birthdate - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type