BotMenuButton class final
BotMenuButton (botMenuButton) - basic class
Describes a button to be shown instead of bot commands menu button.
Constructors
- BotMenuButton({required String text, required String url, dynamic extra, int? clientId})
-
BotMenuButton (botMenuButton) - basic class
const
-
BotMenuButton.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
clientId client identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
extra callback sign
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
Text of the button
final
- url → String
-
URL of a Web App to open when the button is pressed. If the link is of the type internalLinkTypeWebApp, then it must be processed accordingly. Otherwise, the link must be passed to openWebApp
final
Methods
-
copyWith(
{String? text, String? url, dynamic extra, int? clientId}) → BotMenuButton - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type