CallServer class final
CallServer (callServer) - basic class
Describes a server for relaying call data.
- id: Server identifier.
- ipAddress: Server IPv4 address.
- ipv6Address: Server IPv6 address.
- port: Server port number.
- type: Server type.
Constructors
- CallServer({required int id, required String ipAddress, required String ipv6Address, required int port, required CallServerType type})
-
CallServer (callServer) - basic class
const
-
CallServer.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Server identifier
final
- ipAddress → String
-
Server IPv4 address
final
- ipv6Address → String
-
Server IPv6 address
final
- port → int
-
Server port number
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → CallServerType
-
Server type
final
Methods
-
copyWith(
{int? id, String? ipAddress, String? ipv6Address, int? port, CallServerType? type}) → CallServer - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type