CanPurchaseFromStore class final
CanPurchaseFromStore (canPurchaseFromStore) - TDLib function
Checks whether an in-store purchase is possible. Must be called before any in-store purchase.
- purpose: Transaction purpose.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- CanPurchaseFromStore
Constructors
- CanPurchaseFromStore({required StorePaymentPurpose purpose})
-
CanPurchaseFromStore (canPurchaseFromStore) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- purpose → StorePaymentPurpose
-
Transaction purpose
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{StorePaymentPurpose? purpose}) → CanPurchaseFromStore - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type