ChatActionBarReportAddBlock class final
ChatActionBarReportAddBlock (chatActionBarReportAddBlock) - child of ChatActionBar
The chat is a private or secret chat, which can be reported using the method reportChat, or the other user can be blocked using the method setMessageSenderBlockList,. or the other user can be added to the contact list using the method addContact. If the chat is a private chat with a user with an emoji status, then a notice about emoji status usage must be shown.
- canUnarchive: If true, the chat was automatically archived and can be moved back to the main chat list using addChatToList simultaneously with setting chat notification settings to default using setChatNotificationSettings.
- distance: If non-negative, the current user was found by the other user through searchChatsNearby and this is the distance between the users.
- Inheritance
-
- Object
- TdObject
- ChatActionBar
- ChatActionBarReportAddBlock
Constructors
- ChatActionBarReportAddBlock({required bool canUnarchive, required int distance})
-
ChatActionBarReportAddBlock (chatActionBarReportAddBlock) - child of ChatActionBar
const
-
ChatActionBarReportAddBlock.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- canUnarchive → bool
-
If true, the chat was automatically archived and can be moved back to the main chat list using addChatToList simultaneously with setting chat notification settings to default using setChatNotificationSettings
final
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- distance → int
-
If non-negative, the current user was found by the other user through searchChatsNearby and this is the distance between the users
final
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? canUnarchive, int? distance}) → ChatActionBarReportAddBlock -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type