ChatAdministrators class final
ChatAdministrators (chatAdministrators) - basic class
Represents a list of chat administrators.
- administrators: A list of chat administrators.
Constructors
-
ChatAdministrators({required List<
ChatAdministrator> administrators, dynamic extra, int? clientId}) -
ChatAdministrators (chatAdministrators) - basic class
const
-
ChatAdministrators.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
-
administrators
→ List<
ChatAdministrator> -
A list of chat administrators
final
- clientId → int?
-
clientId client identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
extra callback sign
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< ChatAdministrator> ? administrators, dynamic extra, int? clientId}) → ChatAdministrators - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type