ChatBoostSlot class final
ChatBoostSlot (chatBoostSlot) - basic class
Describes a slot for chat boost.
- slotId: Unique identifier of the slot.
- currentlyBoostedChatId: Identifier of the currently boosted chat; 0 if none.
- startDate: Point in time (Unix timestamp) when the chat was boosted; 0 if none.
- expirationDate: Point in time (Unix timestamp) when the boost will expire.
- cooldownUntilDate: Point in time (Unix timestamp) after which the boost can be used for another chat.
Constructors
- ChatBoostSlot({required int slotId, required int currentlyBoostedChatId, required int startDate, required int expirationDate, required int cooldownUntilDate})
-
ChatBoostSlot (chatBoostSlot) - basic class
const
-
ChatBoostSlot.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- cooldownUntilDate → int
-
Point in time (Unix timestamp) after which the boost can be used for another chat
final
- currentlyBoostedChatId → int
-
Identifier of the currently boosted chat; 0 if none
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- expirationDate → int
-
Point in time (Unix timestamp) when the boost will expire
final
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slotId → int
-
Unique identifier of the slot
final
- startDate → int
-
Point in time (Unix timestamp) when the chat was boosted; 0 if none
final
Methods
-
copyWith(
{int? slotId, int? currentlyBoostedChatId, int? startDate, int? expirationDate, int? cooldownUntilDate}) → ChatBoostSlot - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type