ChatEventBackgroundChanged class final
ChatEventBackgroundChanged (chatEventBackgroundChanged) - child of ChatEventAction
The chat background was changed.
- oldBackground: Previous background; may be null if none (optional).
- newBackground: New background; may be null if none (optional).
- Inheritance
-
- Object
- TdObject
- ChatEventAction
- ChatEventBackgroundChanged
Constructors
- ChatEventBackgroundChanged({ChatBackground? oldBackground, ChatBackground? newBackground})
-
ChatEventBackgroundChanged (chatEventBackgroundChanged) - child of ChatEventAction
const
-
ChatEventBackgroundChanged.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- newBackground → ChatBackground?
-
New background; may be null if none
final
- oldBackground → ChatBackground?
-
Previous background; may be null if none
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ChatBackground? oldBackground, ChatBackground? newBackground}) → ChatEventBackgroundChanged -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type