ChatFolderInviteLinkInfo class final
ChatFolderInviteLinkInfo (chatFolderInviteLinkInfo) - basic class
Contains information about an invite link to a chat folder.
- chatFolderInfo: Basic information about the chat folder; chat folder identifier will be 0 if the user didn't have the chat folder yet.
- missingChatIds: Identifiers of the chats from the link, which aren't added to the folder yet.
- addedChatIds: Identifiers of the chats from the link, which are added to the folder already.
Constructors
-
ChatFolderInviteLinkInfo({required ChatFolderInfo chatFolderInfo, required List<
int> missingChatIds, required List<int> addedChatIds, dynamic extra, int? clientId}) -
ChatFolderInviteLinkInfo (chatFolderInviteLinkInfo) - basic class
const
-
ChatFolderInviteLinkInfo.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
-
addedChatIds
→ List<
int> -
Identifiers of the chats from the link, which are added to the folder already
final
- chatFolderInfo → ChatFolderInfo
-
Basic information about the chat folder; chat folder identifier will be 0 if the user didn't have the chat folder yet
final
- clientId → int?
-
clientId client identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
extra callback sign
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
missingChatIds
→ List<
int> -
Identifiers of the chats from the link, which aren't added to the folder yet
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ChatFolderInfo? chatFolderInfo, List< int> ? missingChatIds, List<int> ? addedChatIds, dynamic extra, int? clientId}) → ChatFolderInviteLinkInfo - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type