copyWith method
Copy model with modified properties.
Properties:
chat_folder_info: Basic information about the chat folder; chat folder identifier will be 0 if the user didn't have the chat folder yetmissing_chat_ids: Identifiers of the chats from the link, which aren't added to the folder yetadded_chat_ids: Identifiers of the chats from the link, which are added to the folder already
Implementation
ChatFolderInviteLinkInfo copyWith({
ChatFolderInfo? chatFolderInfo,
List<int>? missingChatIds,
List<int>? addedChatIds,
dynamic extra,
int? clientId,
}) =>
ChatFolderInviteLinkInfo(
chatFolderInfo: chatFolderInfo ?? this.chatFolderInfo,
missingChatIds: missingChatIds ?? this.missingChatIds,
addedChatIds: addedChatIds ?? this.addedChatIds,
extra: extra ?? this.extra,
clientId: clientId ?? this.clientId,
);