ChatInviteLinkInfo class final
ChatInviteLinkInfo (chatInviteLinkInfo) - basic class
Contains information about a chat invite link.
- chatId: Chat identifier of the invite link; 0 if the user has no access to the chat before joining.
- accessibleFor: If non-zero, the amount of time for which read access to the chat will remain available, in seconds.
- type: Type of the chat.
- title: Title of the chat.
- photo: Chat photo; may be null (optional).
- accentColorId: Identifier of the accent color for chat title and background of chat photo.
- description: Chat description.
- memberCount: Number of members in the chat.
- memberUserIds: User identifiers of some chat members that may be known to the current user.
- subscriptionInfo: Information about subscription plan that must be paid by the user to use the link; may be null if the link doesn't require subscription (optional).
- createsJoinRequest: True, if the link only creates join request.
- isPublic: True, if the chat is a public supergroup or channel, i.e. it has a username or it is a location-based supergroup.
- isVerified: True, if the chat is verified.
- isScam: True, if many users reported this chat as a scam.
- isFake: True, if many users reported this chat as a fake account.
Constructors
-
ChatInviteLinkInfo({required int chatId, required int accessibleFor, required InviteLinkChatType type, required String title, ChatPhotoInfo? photo, required int accentColorId, required String description, required int memberCount, required List<
int> memberUserIds, ChatInviteLinkSubscriptionInfo? subscriptionInfo, required bool createsJoinRequest, required bool isPublic, required bool isVerified, required bool isScam, required bool isFake, dynamic extra, int? clientId}) -
ChatInviteLinkInfo (chatInviteLinkInfo) - basic class
const
-
ChatInviteLinkInfo.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- accentColorId → int
-
Identifier of the accent color for chat title and background of chat photo
final
- accessibleFor → int
-
If non-zero, the amount of time for which read access to the chat will remain available, in seconds
final
- chatId → int
-
Chat identifier of the invite link; 0 if the user has no access to the chat before joining
final
- clientId → int?
-
clientId client identifier
final
- createsJoinRequest → bool
-
True, if the link only creates join request
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- description → String
-
Chat description
final
- extra → dynamic
-
extra callback sign
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFake → bool
-
True, if many users reported this chat as a fake account
final
- isPublic → bool
-
True, if the chat is a public supergroup or channel, i.e. it has a username or it is a location-based supergroup
final
- isScam → bool
-
True, if many users reported this chat as a scam
final
- isVerified → bool
-
True, if the chat is verified
final
- memberCount → int
-
Number of members in the chat
final
-
memberUserIds
→ List<
int> -
User identifiers of some chat members that may be known to the current user
final
- photo → ChatPhotoInfo?
-
Chat photo; may be null
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscriptionInfo → ChatInviteLinkSubscriptionInfo?
-
Information about subscription plan that must be paid by the user to use the link; may be null if the link doesn't require subscription
final
- title → String
-
Title of the chat
final
- type → InviteLinkChatType
-
Type of the chat
final
Methods
-
copyWith(
{int? chatId, int? accessibleFor, InviteLinkChatType? type, String? title, ChatPhotoInfo? photo, int? accentColorId, String? description, int? memberCount, List< int> ? memberUserIds, ChatInviteLinkSubscriptionInfo? subscriptionInfo, bool? createsJoinRequest, bool? isPublic, bool? isVerified, bool? isScam, bool? isFake, dynamic extra, int? clientId}) → ChatInviteLinkInfo - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type