ChatInviteLinkMember class final
ChatInviteLinkMember (chatInviteLinkMember) - basic class
Describes a chat member joined a chat via an invite link.
- userId: User identifier.
- joinedChatDate: Point in time (Unix timestamp) when the user joined the chat.
- viaChatFolderInviteLink: True, if the user has joined the chat using an invite link for a chat folder.
- approverUserId: User identifier of the chat administrator, approved user join request.
Constructors
- ChatInviteLinkMember({required int userId, required int joinedChatDate, required bool viaChatFolderInviteLink, required int approverUserId})
-
ChatInviteLinkMember (chatInviteLinkMember) - basic class
const
-
ChatInviteLinkMember.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- approverUserId → int
-
User identifier of the chat administrator, approved user join request
final
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- joinedChatDate → int
-
Point in time (Unix timestamp) when the user joined the chat
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
User identifier
final
- viaChatFolderInviteLink → bool
-
True, if the user has joined the chat using an invite link for a chat folder
final
Methods
-
copyWith(
{int? userId, int? joinedChatDate, bool? viaChatFolderInviteLink, int? approverUserId}) → ChatInviteLinkMember - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type