ChatNotificationSettings class final
ChatNotificationSettings (chatNotificationSettings) - basic class
Contains information about notification settings for a chat or a forum topic.
- useDefaultMuteFor: If true, the value for the relevant type of chat or the forum chat is used instead of mute_for.
- muteFor: Time left before notifications will be unmuted, in seconds.
- useDefaultSound: If true, the value for the relevant type of chat or the forum chat is used instead of sound_id.
- soundId: Identifier of the notification sound to be played for messages; 0 if sound is disabled.
- useDefaultShowPreview: If true, the value for the relevant type of chat or the forum chat is used instead of show_preview.
- showPreview: True, if message content must be displayed in notifications.
- useDefaultMuteStories: If true, the value for the relevant type of chat is used instead of mute_stories.
- muteStories: True, if story notifications are disabled for the chat.
- useDefaultStorySound: If true, the value for the relevant type of chat is used instead of story_sound_id.
- storySoundId: Identifier of the notification sound to be played for stories; 0 if sound is disabled.
- useDefaultShowStorySender: If true, the value for the relevant type of chat is used instead of show_story_sender.
- showStorySender: True, if the sender of stories must be displayed in notifications.
- useDefaultDisablePinnedMessageNotifications: If true, the value for the relevant type of chat or the forum chat is used instead of disable_pinned_message_notifications.
- disablePinnedMessageNotifications: If true, notifications for incoming pinned messages will be created as for an ordinary unread message.
- useDefaultDisableMentionNotifications: If true, the value for the relevant type of chat or the forum chat is used instead of disable_mention_notifications.
- disableMentionNotifications: If true, notifications for messages with mentions will be created as for an ordinary unread message.
Constructors
- ChatNotificationSettings({required bool useDefaultMuteFor, required int muteFor, required bool useDefaultSound, required int soundId, required bool useDefaultShowPreview, required bool showPreview, required bool useDefaultMuteStories, required bool muteStories, required bool useDefaultStorySound, required int storySoundId, required bool useDefaultShowStorySender, required bool showStorySender, required bool useDefaultDisablePinnedMessageNotifications, required bool disablePinnedMessageNotifications, required bool useDefaultDisableMentionNotifications, required bool disableMentionNotifications})
-
ChatNotificationSettings (chatNotificationSettings) - basic class
const
-
ChatNotificationSettings.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- disableMentionNotifications → bool
-
If true, notifications for messages with mentions will be created as for an ordinary unread message
final
- disablePinnedMessageNotifications → bool
-
If true, notifications for incoming pinned messages will be created as for an ordinary unread message
final
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- muteFor → int
-
Time left before notifications will be unmuted, in seconds
final
- muteStories → bool
-
True, if story notifications are disabled for the chat
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showPreview → bool
-
True, if message content must be displayed in notifications
final
- showStorySender → bool
-
True, if the sender of stories must be displayed in notifications
final
- soundId → int
-
Identifier of the notification sound to be played for messages; 0 if sound is disabled
final
- storySoundId → int
-
Identifier of the notification sound to be played for stories; 0 if sound is disabled
final
- useDefaultDisableMentionNotifications → bool
-
If true, the value for the relevant type of chat or the forum chat is used instead of disable_mention_notifications
final
- useDefaultDisablePinnedMessageNotifications → bool
-
If true, the value for the relevant type of chat or the forum chat is used instead of disable_pinned_message_notifications
final
- useDefaultMuteFor → bool
-
If true, the value for the relevant type of chat or the forum chat is used instead of mute_for
final
- useDefaultMuteStories → bool
-
If true, the value for the relevant type of chat is used instead of mute_stories
final
- useDefaultShowPreview → bool
-
If true, the value for the relevant type of chat or the forum chat is used instead of show_preview
final
- useDefaultShowStorySender → bool
-
If true, the value for the relevant type of chat is used instead of show_story_sender
final
- useDefaultSound → bool
-
If true, the value for the relevant type of chat or the forum chat is used instead of sound_id
final
- useDefaultStorySound → bool
-
If true, the value for the relevant type of chat is used instead of story_sound_id
final
Methods
-
copyWith(
{bool? useDefaultMuteFor, int? muteFor, bool? useDefaultSound, int? soundId, bool? useDefaultShowPreview, bool? showPreview, bool? useDefaultMuteStories, bool? muteStories, bool? useDefaultStorySound, int? storySoundId, bool? useDefaultShowStorySender, bool? showStorySender, bool? useDefaultDisablePinnedMessageNotifications, bool? disablePinnedMessageNotifications, bool? useDefaultDisableMentionNotifications, bool? disableMentionNotifications}) → ChatNotificationSettings - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type