ClickChatSponsoredMessage constructor
ClickChatSponsoredMessage (clickChatSponsoredMessage) - TDLib function
Informs TDLib that the user opened the sponsored chat via the button, the name, the photo, or a mention in the sponsored message.
chatId: Chat identifier of the sponsored message.messageId: Identifier of the sponsored message.
Ok is returned on completion.
Implementation
const ClickChatSponsoredMessage({
required this.chatId,
required this.messageId,
});