CreateNewBasicGroupChat class final
CreateNewBasicGroupChat (createNewBasicGroupChat) - TDLib function
Creates a new basic group and sends a corresponding messageBasicGroupChatCreate. Returns information about the newly created chat.
- userIds: Identifiers of users to be added to the basic group; may be empty to create a basic group without other members.
- title: Title of the new basic group; 1-128 characters.
- messageAutoDeleteTime: Message auto-delete time value, in seconds; must be from 0 up to 365 * 86400 and be divisible by 86400. If 0, then messages aren't deleted automatically.
CreatedBasicGroupChat is returned on completion.
- Inheritance
-
- Object
- TdFunction
- CreateNewBasicGroupChat
Constructors
-
CreateNewBasicGroupChat({required List<
int> userIds, required String title, required int messageAutoDeleteTime}) -
CreateNewBasicGroupChat (createNewBasicGroupChat) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageAutoDeleteTime → int
-
Message auto-delete time value, in seconds; must be from 0 up to 365 * 86400 and be divisible by 86400. If 0, then messages aren't deleted automatically
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
Title of the new basic group; 1-128 characters
final
-
userIds
→ List<
int> -
Identifiers of users to be added to the basic group; may be empty to create a basic group without other members
final
Methods
-
copyWith(
{List< int> ? userIds, String? title, int? messageAutoDeleteTime}) → CreateNewBasicGroupChat - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type