copyWith method
Copy model with modified properties.
Properties:
user_ids: Identifiers of users to be added to the basic group; may be empty to create a basic group without other memberstitle: Title of the new basic group; 1-128 charactersmessage_auto_delete_time: Message auto-delete time value, in seconds; must be from 0 up to 365 * 86400 and be divisible by 86400. If 0, then messages aren't deleted automatically
Implementation
CreateNewBasicGroupChat copyWith({
List<int>? userIds,
String? title,
int? messageAutoDeleteTime,
}) =>
CreateNewBasicGroupChat(
userIds: userIds ?? this.userIds,
title: title ?? this.title,
messageAutoDeleteTime:
messageAutoDeleteTime ?? this.messageAutoDeleteTime,
);