CreateVideoChat class final
CreateVideoChat (createVideoChat) - TDLib function
Creates a video chat (a group call bound to a chat). Available only for basic groups, supergroups and channels; requires can_manage_video_chats administrator right.
- chatId: Identifier of a chat in which the video chat will be created.
- title: Group call title; if empty, chat title will be used.
- startDate: Point in time (Unix timestamp) when the group call is supposed to be started by an administrator; 0 to start the video chat immediately. The date must be at least 10 seconds and at most 8 days in the future.
- isRtmpStream: Pass true to create an RTMP stream instead of an ordinary video chat; requires owner privileges.
GroupCallId is returned on completion.
- Inheritance
-
- Object
- TdFunction
- CreateVideoChat
Constructors
- CreateVideoChat({required int chatId, required String title, required int startDate, required bool isRtmpStream})
-
CreateVideoChat (createVideoChat) - TDLib function
const
Properties
- chatId → int
-
Identifier of a chat in which the video chat will be created
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRtmpStream → bool
-
Pass true to create an RTMP stream instead of an ordinary video chat; requires owner privileges
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDate → int
-
Point in time (Unix timestamp) when the group call is supposed to be started by an administrator; 0 to start the video chat immediately. The date must be at least 10 seconds and at most 8 days in the future
final
- title → String
-
Group call title; if empty, chat title will be used
final
Methods
-
copyWith(
{int? chatId, String? title, int? startDate, bool? isRtmpStream}) → CreateVideoChat - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type