DeleteChatFolder class final
DeleteChatFolder (deleteChatFolder) - TDLib function
Deletes existing chat folder.
- chatFolderId: Chat folder identifier.
- leaveChatIds: Identifiers of the chats to leave. The chats must be pinned or always included in the folder.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- DeleteChatFolder
Constructors
-
DeleteChatFolder({required int chatFolderId, required List<
int> leaveChatIds}) -
DeleteChatFolder (deleteChatFolder) - TDLib function
const
Properties
- chatFolderId → int
-
Chat folder identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
leaveChatIds
→ List<
int> -
Identifiers of the chats to leave. The chats must be pinned or always included in the folder
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatFolderId, List< int> ? leaveChatIds}) → DeleteChatFolder - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type