EditBotMediaPreview class final
EditBotMediaPreview (editBotMediaPreview) - TDLib function
Replaces media preview in the list of media previews of a bot. Returns the new preview after edit is completed server-side.
- botUserId: Identifier of the target bot. The bot must be owned and must have the main Web App.
- languageCode: Language code of the media preview to edit.
- fileId: File identifier of the media to replace.
- content: Content of the new preview.
BotMediaPreview is returned on completion.
- Inheritance
-
- Object
- TdFunction
- EditBotMediaPreview
Constructors
- EditBotMediaPreview({required int botUserId, required String languageCode, required int fileId, required InputStoryContent content})
-
EditBotMediaPreview (editBotMediaPreview) - TDLib function
const
Properties
- botUserId → int
-
Identifier of the target bot. The bot must be owned and must have the main Web App
final
- content → InputStoryContent
-
Content of the new preview
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- fileId → int
-
File identifier of the media to replace
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- languageCode → String
-
Language code of the media preview to edit
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? botUserId, String? languageCode, int? fileId, InputStoryContent? content}) → EditBotMediaPreview - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type