EditInlineMessageText class final
EditInlineMessageText (editInlineMessageText) - TDLib function
Edits the text of an inline text or game message sent via a bot; for bots only.
- inlineMessageId: Inline message identifier.
- replyMarkup: The new message reply markup; pass null if none (optional).
- inputMessageContent: New text content of the message. Must be of type inputMessageText.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- EditInlineMessageText
Constructors
- EditInlineMessageText({required String inlineMessageId, ReplyMarkup? replyMarkup, required InputMessageContent inputMessageContent})
-
EditInlineMessageText (editInlineMessageText) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- inlineMessageId → String
-
Inline message identifier
final
- inputMessageContent → InputMessageContent
-
New text content of the message. Must be of type inputMessageText
final
- replyMarkup → ReplyMarkup?
-
The new message reply markup; pass null if none
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? inlineMessageId, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) → EditInlineMessageText - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type