EditMessageCaption class final
EditMessageCaption (editMessageCaption) - TDLib function
Edits the message content caption. Returns the edited message after the edit is completed on the server side.
- chatId: The chat the message belongs to.
- messageId: Identifier of the message. Use messageProperties.can_be_edited to check whether the message can be edited.
- replyMarkup: The new message reply markup; pass null if none; for bots only (optional).
- caption: New message content caption; 0-getOption("message_caption_length_max") characters; pass null to remove caption (optional).
- showCaptionAboveMedia: Pass true to show the caption above the media; otherwise, the caption will be shown below the media. Can be true only for animation, photo, and video messages.
Message is returned on completion.
- Inheritance
-
- Object
- TdFunction
- EditMessageCaption
Constructors
- EditMessageCaption({required int chatId, required int messageId, ReplyMarkup? replyMarkup, FormattedText? caption, required bool showCaptionAboveMedia})
-
EditMessageCaption (editMessageCaption) - TDLib function
const
Properties
- caption → FormattedText?
-
New message content caption; 0-getOption("message_caption_length_max") characters; pass null to remove caption
final
- chatId → int
-
The chat the message belongs to
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageId → int
-
Identifier of the message. Use messageProperties.can_be_edited to check whether the message can be edited
final
- replyMarkup → ReplyMarkup?
-
The new message reply markup; pass null if none; for bots only
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showCaptionAboveMedia → bool
-
Pass true to show the caption above the media; otherwise, the caption will be shown below the media. Can be true only for animation, photo, and video messages
final
Methods
-
copyWith(
{int? chatId, int? messageId, ReplyMarkup? replyMarkup, FormattedText? caption, bool? showCaptionAboveMedia}) → EditMessageCaption - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type