EditQuickReplyMessage class final
EditQuickReplyMessage (editQuickReplyMessage) - TDLib function
Asynchronously edits the text, media or caption of a quick reply message. Use quickReplyMessage.can_be_edited to check whether a message can be edited.. Text message can be edited only to a text message. The type of message content in an album can't be changed with exception of replacing a photo with a video or vice versa.
- shortcutId: Unique identifier of the quick reply shortcut with the message.
- messageId: Identifier of the message.
- inputMessageContent: New content of the message. Must be one of the following types: inputMessageText, inputMessageAnimation, inputMessageAudio, inputMessageDocument, inputMessagePhoto or inputMessageVideo.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- EditQuickReplyMessage
Constructors
- EditQuickReplyMessage({required int shortcutId, required int messageId, required InputMessageContent inputMessageContent})
-
EditQuickReplyMessage (editQuickReplyMessage) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputMessageContent → InputMessageContent
-
New content of the message. Must be one of the following types: inputMessageText, inputMessageAnimation, inputMessageAudio, inputMessageDocument, inputMessagePhoto or inputMessageVideo
final
- messageId → int
-
Identifier of the message
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortcutId → int
-
Unique identifier of the quick reply shortcut with the message
final
Methods
-
copyWith(
{int? shortcutId, int? messageId, InputMessageContent? inputMessageContent}) → EditQuickReplyMessage - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type