EditStarSubscription class final
EditStarSubscription (editStarSubscription) - TDLib function
Cancels or reenables Telegram Star subscription to a channel.
- subscriptionId: Identifier of the subscription to change.
- isCanceled: New value of is_canceled.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- EditStarSubscription
Constructors
- EditStarSubscription({required String subscriptionId, required bool isCanceled})
-
EditStarSubscription (editStarSubscription) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCanceled → bool
-
New value of is_canceled
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscriptionId → String
-
Identifier of the subscription to change
final
Methods
-
copyWith(
{String? subscriptionId, bool? isCanceled}) → EditStarSubscription - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type