File class final
File (file) - basic class
Represents a file.
- id: Unique file identifier.
- size: File size, in bytes; 0 if unknown.
- expectedSize: Approximate file size in bytes in case the exact file size is unknown. Can be used to show download/upload progress.
- local: Information about the local copy of the file.
- remote: Information about the remote copy of the file.
Constructors
- File({required int id, required int size, required int expectedSize, required LocalFile local, required RemoteFile remote, dynamic extra, int? clientId})
-
File (file) - basic class
const
-
File.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
clientId client identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- expectedSize → int
-
Approximate file size in bytes in case the exact file size is unknown. Can be used to show download/upload progress
final
- extra → dynamic
-
extra callback sign
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Unique file identifier
final
- local → LocalFile
-
Information about the local copy of the file
final
- remote → RemoteFile
-
Information about the remote copy of the file
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
File size, in bytes; 0 if unknown
final
Methods
-
copyWith(
{int? id, int? size, int? expectedSize, LocalFile? local, RemoteFile? remote, dynamic extra, int? clientId}) → File - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type