FoundChatBoosts class final
FoundChatBoosts (foundChatBoosts) - basic class
Contains a list of boosts applied to a chat.
- totalCount: Total number of boosts applied to the chat.
- boosts: List of boosts.
- nextOffset: The offset for the next request. If empty, then there are no more results.
Constructors
-
FoundChatBoosts({required int totalCount, required List<
ChatBoost> boosts, required String nextOffset, dynamic extra, int? clientId}) -
FoundChatBoosts (foundChatBoosts) - basic class
const
-
FoundChatBoosts.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
-
boosts
→ List<
ChatBoost> -
List of boosts
final
- clientId → int?
-
clientId client identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
extra callback sign
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextOffset → String
-
The offset for the next request. If empty, then there are no more results
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalCount → int
-
Total number of boosts applied to the chat
final
Methods
-
copyWith(
{int? totalCount, List< ChatBoost> ? boosts, String? nextOffset, dynamic extra, int? clientId}) → FoundChatBoosts - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type