GetArchivedStickerSets class final
GetArchivedStickerSets (getArchivedStickerSets) - TDLib function
Returns a list of archived sticker sets.
- stickerType: Type of the sticker sets to return.
- offsetStickerSetId: Identifier of the sticker set from which to return the result; use 0 to get results from the beginning.
- limit: The maximum number of sticker sets to return; up to 100.
StickerSets is returned on completion.
- Inheritance
-
- Object
- TdFunction
- GetArchivedStickerSets
Constructors
- GetArchivedStickerSets({required StickerType stickerType, required int offsetStickerSetId, required int limit})
-
GetArchivedStickerSets (getArchivedStickerSets) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int
-
The maximum number of sticker sets to return; up to 100
final
- offsetStickerSetId → int
-
Identifier of the sticker set from which to return the result; use 0 to get results from the beginning
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stickerType → StickerType
-
Type of the sticker sets to return
final
Methods
-
copyWith(
{StickerType? stickerType, int? offsetStickerSetId, int? limit}) → GetArchivedStickerSets - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type