GetAttachedStickerSets class final
GetAttachedStickerSets (getAttachedStickerSets) - TDLib function
Returns a list of sticker sets attached to a file, including regular, mask, and emoji sticker sets. Currently, only animations, photos, and videos can have attached sticker sets.
- fileId: File identifier.
StickerSets is returned on completion.
- Inheritance
-
- Object
- TdFunction
- GetAttachedStickerSets
Constructors
- GetAttachedStickerSets({required int fileId})
-
GetAttachedStickerSets (getAttachedStickerSets) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- fileId → int
-
File identifier
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? fileId}) → GetAttachedStickerSets - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type