GetBotMediaPreviewInfo class final
GetBotMediaPreviewInfo (getBotMediaPreviewInfo) - TDLib function
Returns the list of media previews for the given language and the list of languages for which the bot has dedicated previews.
- botUserId: Identifier of the target bot. The bot must be owned and must have the main Web App.
- languageCode: A two-letter ISO 639-1 language code for which to get previews. If empty, then default previews are returned.
BotMediaPreviewInfo is returned on completion.
- Inheritance
-
- Object
- TdFunction
- GetBotMediaPreviewInfo
Constructors
- GetBotMediaPreviewInfo({required int botUserId, required String languageCode})
-
GetBotMediaPreviewInfo (getBotMediaPreviewInfo) - TDLib function
const
Properties
- botUserId → int
-
Identifier of the target bot. The bot must be owned and must have the main Web App
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- languageCode → String
-
A two-letter ISO 639-1 language code for which to get previews. If empty, then default previews are returned
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? botUserId, String? languageCode}) → GetBotMediaPreviewInfo - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type