GetChatBoostLinkInfo class final
GetChatBoostLinkInfo (getChatBoostLinkInfo) - TDLib function
Returns information about a link to boost a chat. Can be called for any internal link of the type internalLinkTypeChatBoost.
- url: The link to boost a chat.
ChatBoostLinkInfo is returned on completion.
- Inheritance
-
- Object
- TdFunction
- GetChatBoostLinkInfo
Constructors
- GetChatBoostLinkInfo({required String url})
-
GetChatBoostLinkInfo (getChatBoostLinkInfo) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
The link to boost a chat
final
Methods
-
copyWith(
{String? url}) → GetChatBoostLinkInfo - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type