GetChatMessageByDate class final
GetChatMessageByDate (getChatMessageByDate) - TDLib function
Returns the last message sent in a chat no later than the specified date.
- chatId: Chat identifier.
- date: Point in time (Unix timestamp) relative to which to search for messages.
Message is returned on completion.
- Inheritance
-
- Object
- TdFunction
- GetChatMessageByDate
Constructors
- GetChatMessageByDate({required int chatId, required int date})
-
GetChatMessageByDate (getChatMessageByDate) - TDLib function
const
Properties
- chatId → int
-
Chat identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- date → int
-
Point in time (Unix timestamp) relative to which to search for messages
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? date}) → GetChatMessageByDate - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type