GetChatMessagePosition class final
GetChatMessagePosition (getChatMessagePosition) - TDLib function
Returns approximate 1-based position of a message among messages, which can be found by the specified filter in the chat. Cannot be used in secret chats.
- chatId: Identifier of the chat in which to find message position.
- messageId: Message identifier.
- filter: Filter for message content; searchMessagesFilterEmpty, searchMessagesFilterUnreadMention, searchMessagesFilterUnreadReaction, and searchMessagesFilterFailedToSend are unsupported in this function.
- messageThreadId: If not 0, only messages in the specified thread will be considered; supergroups only.
- savedMessagesTopicId: If not 0, only messages in the specified Saved Messages topic will be considered; pass 0 to consider all relevant messages, or for chats other than Saved Messages.
Count is returned on completion.
- Inheritance
-
- Object
- TdFunction
- GetChatMessagePosition
Constructors
- GetChatMessagePosition({required int chatId, required int messageId, required SearchMessagesFilter filter, required int messageThreadId, required int savedMessagesTopicId})
-
GetChatMessagePosition (getChatMessagePosition) - TDLib function
const
Properties
- chatId → int
-
Identifier of the chat in which to find message position
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- filter → SearchMessagesFilter
-
Filter for message content; searchMessagesFilterEmpty, searchMessagesFilterUnreadMention, searchMessagesFilterUnreadReaction, and searchMessagesFilterFailedToSend are unsupported in this function
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageId → int
-
Message identifier
final
- messageThreadId → int
-
If not 0, only messages in the specified thread will be considered; supergroups only
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- savedMessagesTopicId → int
-
If not 0, only messages in the specified Saved Messages topic will be considered; pass 0 to consider all relevant messages, or for chats other than Saved Messages
final
Methods
-
copyWith(
{int? chatId, int? messageId, SearchMessagesFilter? filter, int? messageThreadId, int? savedMessagesTopicId}) → GetChatMessagePosition - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type