GetForumTopicLink class final
GetForumTopicLink (getForumTopicLink) - TDLib function
Returns an HTTPS link to a topic in a forum chat. This is an offline request.
- chatId: Identifier of the chat.
- messageThreadId: Message thread identifier of the forum topic.
MessageLink is returned on completion.
- Inheritance
-
- Object
- TdFunction
- GetForumTopicLink
Constructors
- GetForumTopicLink({required int chatId, required int messageThreadId})
-
GetForumTopicLink (getForumTopicLink) - TDLib function
const
Properties
- chatId → int
-
Identifier of the chat
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageThreadId → int
-
Message thread identifier of the forum topic
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageThreadId}) → GetForumTopicLink - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type