GetForumTopics class final
GetForumTopics (getForumTopics) - TDLib function
Returns found forum topics in a forum chat. This is a temporary method for getting information about topic list from the server.
- chatId: Identifier of the forum chat.
- query: Query to search for in the forum topic's name.
- offsetDate: The date starting from which the results need to be fetched. Use 0 or any date in the future to get results from the last topic.
- offsetMessageId: The message identifier of the last message in the last found topic, or 0 for the first request.
- offsetMessageThreadId: The message thread identifier of the last found topic, or 0 for the first request.
- limit: The maximum number of forum topics to be returned; up to 100. For optimal performance, the number of returned forum topics is chosen by TDLib and can be smaller than the specified limit.
ForumTopics is returned on completion.
- Inheritance
-
- Object
- TdFunction
- GetForumTopics
Constructors
Properties
- chatId → int
-
Identifier of the forum chat
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int
-
The maximum number of forum topics to be returned; up to 100. For optimal performance, the number of returned forum topics is chosen by TDLib and can be smaller than the specified limit
final
- offsetDate → int
-
The date starting from which the results need to be fetched. Use 0 or any date in the future to get results from the last topic
final
- offsetMessageId → int
-
The message identifier of the last message in the last found topic, or 0 for the first request
final
- offsetMessageThreadId → int
-
The message thread identifier of the last found topic, or 0 for the first request
final
- query → String
-
Query to search for in the forum topic's name
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, String? query, int? offsetDate, int? offsetMessageId, int? offsetMessageThreadId, int? limit}) → GetForumTopics - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type