GetLanguagePackStrings class final
GetLanguagePackStrings (getLanguagePackStrings) - TDLib function
Returns strings from a language pack in the current localization target by their keys. Can be called before authorization.
- languagePackId: Language pack identifier of the strings to be returned.
- keys: Language pack keys of the strings to be returned; leave empty to request all available strings.
LanguagePackStrings is returned on completion.
- Inheritance
-
- Object
- TdFunction
- GetLanguagePackStrings
Constructors
-
GetLanguagePackStrings({required String languagePackId, required List<
String> keys}) -
GetLanguagePackStrings (getLanguagePackStrings) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
keys
→ List<
String> -
Language pack keys of the strings to be returned; leave empty to request all available strings
final
- languagePackId → String
-
Language pack identifier of the strings to be returned
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? languagePackId, List< String> ? keys}) → GetLanguagePackStrings - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type