GetMapThumbnailFile class final
GetMapThumbnailFile (getMapThumbnailFile) - TDLib function
Returns information about a file with a map thumbnail in PNG format. Only map thumbnail files with size less than 1MB can be downloaded.
- location: Location of the map center.
- zoom: Map zoom level; 13-20.
- width: Map width in pixels before applying scale; 16-1024.
- height: Map height in pixels before applying scale; 16-1024.
- scale: Map scale; 1-3.
- chatId: Identifier of a chat in which the thumbnail will be shown. Use 0 if unknown.
File is returned on completion.
- Inheritance
-
- Object
- TdFunction
- GetMapThumbnailFile
Constructors
Properties
- chatId → int
-
Identifier of a chat in which the thumbnail will be shown. Use 0 if unknown
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
Map height in pixels before applying scale; 16-1024
final
- location → Location
-
Location of the map center
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → int
-
Map scale; 1-3
final
- width → int
-
Map width in pixels before applying scale; 16-1024
final
- zoom → int
-
Map zoom level; 13-20
final
Methods
-
copyWith(
{Location? location, int? zoom, int? width, int? height, int? scale, int? chatId}) → GetMapThumbnailFile - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type