GetMessageImportConfirmationText constructor
const
GetMessageImportConfirmationText({
- required int chatId,
GetMessageImportConfirmationText (getMessageImportConfirmationText) - TDLib function
Returns a confirmation text to be shown to the user before starting message import.
chatId: Identifier of a chat to which the messages will be imported. It must be an identifier of a private chat with a mutual contact or an identifier of a supergroup chat with can_change_info member right.
Text is returned on completion.
Implementation
const GetMessageImportConfirmationText({
required this.chatId,
});