GetPreferredCountryLanguage class final
GetPreferredCountryLanguage (getPreferredCountryLanguage) - TDLib function
Returns an IETF language tag of the language preferred in the country, which must be used to fill native fields in Telegram Passport personal details. Returns a 404 error if unknown.
- countryCode: A two-letter ISO 3166-1 alpha-2 country code.
Text is returned on completion.
- Inheritance
-
- Object
- TdFunction
- GetPreferredCountryLanguage
Constructors
- GetPreferredCountryLanguage({required String countryCode})
-
GetPreferredCountryLanguage (getPreferredCountryLanguage) - TDLib function
const
Properties
- countryCode → String
-
A two-letter ISO 3166-1 alpha-2 country code
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? countryCode}) → GetPreferredCountryLanguage - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type