GetSavedMessagesTopicMessageByDate class final
GetSavedMessagesTopicMessageByDate (getSavedMessagesTopicMessageByDate) - TDLib function
Returns the last message sent in a Saved Messages topic no later than the specified date.
- savedMessagesTopicId: Identifier of Saved Messages topic which message will be returned.
- date: Point in time (Unix timestamp) relative to which to search for messages.
Message is returned on completion.
- Inheritance
-
- Object
- TdFunction
- GetSavedMessagesTopicMessageByDate
Constructors
- GetSavedMessagesTopicMessageByDate({required int savedMessagesTopicId, required int date})
-
GetSavedMessagesTopicMessageByDate (getSavedMessagesTopicMessageByDate) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- date → int
-
Point in time (Unix timestamp) relative to which to search for messages
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- savedMessagesTopicId → int
-
Identifier of Saved Messages topic which message will be returned
final
Methods
-
copyWith(
{int? savedMessagesTopicId, int? date}) → GetSavedMessagesTopicMessageByDate - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type