GetStoryStatistics class final
GetStoryStatistics (getStoryStatistics) - TDLib function
Returns detailed statistics about a story. Can be used only if story.can_get_statistics == true.
- chatId: Chat identifier.
- storyId: Story identifier.
- isDark: Pass true if a dark theme is used by the application.
StoryStatistics is returned on completion.
- Inheritance
-
- Object
- TdFunction
- GetStoryStatistics
Constructors
- GetStoryStatistics({required int chatId, required int storyId, required bool isDark})
-
GetStoryStatistics (getStoryStatistics) - TDLib function
const
Properties
- chatId → int
-
Chat identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDark → bool
-
Pass true if a dark theme is used by the application
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storyId → int
-
Story identifier
final
Methods
-
copyWith(
{int? chatId, int? storyId, bool? isDark}) → GetStoryStatistics - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type