GetTextEntities class final
GetTextEntities (getTextEntities) - TDLib function
Returns all entities (mentions, hashtags, cashtags, bot commands, bank card numbers, URLs, and email addresses) found in the text. Can be called synchronously.
- text: The text in which to look for entities.
TextEntities is returned on completion.
- Inheritance
-
- Object
- TdFunction
- GetTextEntities
Constructors
- GetTextEntities({required String text})
-
GetTextEntities (getTextEntities) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
The text in which to look for entities
final
Methods
-
copyWith(
{String? text}) → GetTextEntities - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type