GetUserFullInfo class final
GetUserFullInfo (getUserFullInfo) - TDLib function
Returns full information about a user by their identifier.
- userId: User identifier.
UserFullInfo is returned on completion.
- Inheritance
-
- Object
- TdFunction
- GetUserFullInfo
Constructors
- GetUserFullInfo({required int userId})
-
GetUserFullInfo (getUserFullInfo) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
User identifier
final
Methods
-
copyWith(
{int? userId}) → GetUserFullInfo - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type