GetUserProfilePhotos class final
GetUserProfilePhotos (getUserProfilePhotos) - TDLib function
Returns the profile photos of a user. Personal and public photo aren't returned.
- userId: User identifier.
- offset: The number of photos to skip; must be non-negative.
- limit: The maximum number of photos to be returned; up to 100.
ChatPhotos is returned on completion.
- Inheritance
-
- Object
- TdFunction
- GetUserProfilePhotos
Constructors
- GetUserProfilePhotos({required int userId, required int offset, required int limit})
-
GetUserProfilePhotos (getUserProfilePhotos) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int
-
The maximum number of photos to be returned; up to 100
final
- offset → int
-
The number of photos to skip; must be non-negative
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
User identifier
final
Methods
-
copyWith(
{int? userId, int? offset, int? limit}) → GetUserProfilePhotos - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type