InputBusinessChatLink class final
InputBusinessChatLink (inputBusinessChatLink) - basic class
Describes a business chat link to create or edit.
Constructors
- InputBusinessChatLink({required FormattedText text, required String title})
-
InputBusinessChatLink (inputBusinessChatLink) - basic class
const
-
InputBusinessChatLink.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → FormattedText
-
Message draft text that will be added to the input field
final
- title → String
-
Link title
final
Methods
-
copyWith(
{FormattedText? text, String? title}) → InputBusinessChatLink - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type