InputInlineQueryResultVoiceNote class final
InputInlineQueryResultVoiceNote (inputInlineQueryResultVoiceNote) - child of InputInlineQueryResult
Represents a link to an opus-encoded audio file within an OGG container, single channel audio.
- id: Unique identifier of the query result.
- title: Title of the voice note.
- voiceNoteUrl: The URL of the voice note file.
- voiceNoteDuration: Duration of the voice note, in seconds.
- replyMarkup: The message reply markup; pass null if none. Must be of type replyMarkupInlineKeyboard or null (optional).
- inputMessageContent: The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageVoiceNote, inputMessageInvoice, inputMessageLocation, inputMessageVenue or inputMessageContact.
- Inheritance
-
- Object
- TdObject
- InputInlineQueryResult
- InputInlineQueryResultVoiceNote
Constructors
- InputInlineQueryResultVoiceNote({required String id, required String title, required String voiceNoteUrl, required int voiceNoteDuration, ReplyMarkup? replyMarkup, required InputMessageContent inputMessageContent})
-
InputInlineQueryResultVoiceNote (inputInlineQueryResultVoiceNote) - child of InputInlineQueryResult
const
-
InputInlineQueryResultVoiceNote.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier of the query result
final
- inputMessageContent → InputMessageContent
-
The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageVoiceNote, inputMessageInvoice, inputMessageLocation, inputMessageVenue or inputMessageContact
final
- replyMarkup → ReplyMarkup?
-
The message reply markup; pass null if none. Must be of type replyMarkupInlineKeyboard or null
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
Title of the voice note
final
- voiceNoteDuration → int
-
Duration of the voice note, in seconds
final
- voiceNoteUrl → String
-
The URL of the voice note file
final
Methods
-
copyWith(
{String? id, String? title, String? voiceNoteUrl, int? voiceNoteDuration, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) → InputInlineQueryResultVoiceNote -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type