InputMessageAnimation class final
InputMessageAnimation (inputMessageAnimation) - child of InputMessageContent
An animation message (GIF-style).
- animation: Animation file to be sent.
- thumbnail: Animation thumbnail; pass null to skip thumbnail uploading (optional).
- addedStickerFileIds: File identifiers of the stickers added to the animation, if applicable.
- duration: Duration of the animation, in seconds.
- width: Width of the animation; may be replaced by the server.
- height: Height of the animation; may be replaced by the server.
- caption: Animation caption; pass null to use an empty caption; 0-getOption("message_caption_length_max") characters (optional).
- showCaptionAboveMedia: True, if the caption must be shown above the animation; otherwise, the caption must be shown below the animation; not supported in secret chats.
- hasSpoiler: True, if the animation preview must be covered by a spoiler animation; not supported in secret chats.
- Inheritance
-
- Object
- TdObject
- InputMessageContent
- InputMessageAnimation
Constructors
-
InputMessageAnimation({required InputFile animation, InputThumbnail? thumbnail, required List<
int> addedStickerFileIds, required int duration, required int width, required int height, FormattedText? caption, required bool showCaptionAboveMedia, required bool hasSpoiler}) -
InputMessageAnimation (inputMessageAnimation) - child of InputMessageContent
const
-
InputMessageAnimation.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
-
addedStickerFileIds
→ List<
int> -
File identifiers of the stickers added to the animation, if applicable
final
- animation → InputFile
-
Animation file to be sent
final
- caption → FormattedText?
-
Animation caption; pass null to use an empty caption; 0-getOption("message_caption_length_max") characters
final
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- duration → int
-
Duration of the animation, in seconds
final
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasSpoiler → bool
-
True, if the animation preview must be covered by a spoiler animation; not supported in secret chats
final
- height → int
-
Height of the animation; may be replaced by the server
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showCaptionAboveMedia → bool
-
True, if the caption must be shown above the animation; otherwise, the caption must be shown below the animation; not supported in secret chats
final
- thumbnail → InputThumbnail?
-
Animation thumbnail; pass null to skip thumbnail uploading
final
- width → int
-
Width of the animation; may be replaced by the server
final
Methods
-
copyWith(
{InputFile? animation, InputThumbnail? thumbnail, List< int> ? addedStickerFileIds, int? duration, int? width, int? height, FormattedText? caption, bool? showCaptionAboveMedia, bool? hasSpoiler}) → InputMessageAnimation -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type