InputMessageAnimation constructor
const
InputMessageAnimation({
- required InputFile animation,
- InputThumbnail? thumbnail,
- required List<
int> addedStickerFileIds, - required int duration,
- required int width,
- required int height,
- FormattedText? caption,
- required bool showCaptionAboveMedia,
- required bool hasSpoiler,
InputMessageAnimation (inputMessageAnimation) - child of InputMessageContent
An animation message (GIF-style).
animation: Animation file to be sent.thumbnail: Animation thumbnail; pass null to skip thumbnail uploading (optional).addedStickerFileIds: File identifiers of the stickers added to the animation, if applicable.duration: Duration of the animation, in seconds.width: Width of the animation; may be replaced by the server.height: Height of the animation; may be replaced by the server.caption: Animation caption; pass null to use an empty caption; 0-getOption("message_caption_length_max") characters (optional).showCaptionAboveMedia: True, if the caption must be shown above the animation; otherwise, the caption must be shown below the animation; not supported in secret chats.hasSpoiler: True, if the animation preview must be covered by a spoiler animation; not supported in secret chats.
Implementation
const InputMessageAnimation({
required this.animation,
this.thumbnail,
required this.addedStickerFileIds,
required this.duration,
required this.width,
required this.height,
this.caption,
required this.showCaptionAboveMedia,
required this.hasSpoiler,
});