InputMessagePhoto class final
InputMessagePhoto (inputMessagePhoto) - child of InputMessageContent
A photo message.
- photo: Photo to send. The photo must be at most 10 MB in size. The photo's width and height must not exceed 10000 in total. Width and height ratio must be at most 20.
- thumbnail: Photo thumbnail to be sent; pass null to skip thumbnail uploading. The thumbnail is sent to the other party only in secret chats (optional).
- addedStickerFileIds: File identifiers of the stickers added to the photo, if applicable.
- width: Photo width.
- height: Photo height.
- caption: Photo caption; pass null to use an empty caption; 0-getOption("message_caption_length_max") characters (optional).
- showCaptionAboveMedia: True, if the caption must be shown above the photo; otherwise, the caption must be shown below the photo; not supported in secret chats.
- selfDestructType: Photo self-destruct type; pass null if none; private chats only (optional).
- hasSpoiler: True, if the photo preview must be covered by a spoiler animation; not supported in secret chats.
- Inheritance
-
- Object
- TdObject
- InputMessageContent
- InputMessagePhoto
Constructors
-
InputMessagePhoto({required InputFile photo, InputThumbnail? thumbnail, required List<
int> addedStickerFileIds, required int width, required int height, FormattedText? caption, required bool showCaptionAboveMedia, MessageSelfDestructType? selfDestructType, required bool hasSpoiler}) -
InputMessagePhoto (inputMessagePhoto) - child of InputMessageContent
const
-
InputMessagePhoto.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
-
addedStickerFileIds
→ List<
int> -
File identifiers of the stickers added to the photo, if applicable
final
- caption → FormattedText?
-
Photo caption; pass null to use an empty caption; 0-getOption("message_caption_length_max") characters
final
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasSpoiler → bool
-
True, if the photo preview must be covered by a spoiler animation; not supported in secret chats
final
- height → int
-
Photo height
final
- photo → InputFile
-
Photo to send. The photo must be at most 10 MB in size. The photo's width and height must not exceed 10000 in total. Width and height ratio must be at most 20
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfDestructType → MessageSelfDestructType?
-
Photo self-destruct type; pass null if none; private chats only
final
- showCaptionAboveMedia → bool
-
True, if the caption must be shown above the photo; otherwise, the caption must be shown below the photo; not supported in secret chats
final
- thumbnail → InputThumbnail?
-
Photo thumbnail to be sent; pass null to skip thumbnail uploading. The thumbnail is sent to the other party only in secret chats
final
- width → int
-
Photo width
final
Methods
-
copyWith(
{InputFile? photo, InputThumbnail? thumbnail, List< int> ? addedStickerFileIds, int? width, int? height, FormattedText? caption, bool? showCaptionAboveMedia, MessageSelfDestructType? selfDestructType, bool? hasSpoiler}) → InputMessagePhoto -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type