InputMessageReplyToMessage class final
InputMessageReplyToMessage (inputMessageReplyToMessage) - child of InputMessageReplyTo
Describes a message to be replied in the same chat and forum topic.
- messageId: The identifier of the message to be replied in the same chat and forum topic. A message can be replied in the same chat and forum topic only if messageProperties.can_be_replied.
- quote: Quote from the message to be replied; pass null if none. Must always be null for replies in secret chats (optional).
- Inheritance
-
- Object
- TdObject
- InputMessageReplyTo
- InputMessageReplyToMessage
Constructors
- InputMessageReplyToMessage({required int messageId, InputTextQuote? quote})
-
InputMessageReplyToMessage (inputMessageReplyToMessage) - child of InputMessageReplyTo
const
-
InputMessageReplyToMessage.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageId → int
-
The identifier of the message to be replied in the same chat and forum topic. A message can be replied in the same chat and forum topic only if messageProperties.can_be_replied
final
- quote → InputTextQuote?
-
Quote from the message to be replied; pass null if none. Must always be null for replies in secret chats
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? messageId, InputTextQuote? quote}) → InputMessageReplyToMessage -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type