InputMessageVoiceNote class final
InputMessageVoiceNote (inputMessageVoiceNote) - child of InputMessageContent
A voice note message.
- voiceNote: Voice note to be sent. The voice note must be encoded with the Opus codec and stored inside an OGG container with a single audio channel, or be in MP3 or M4A format as regular audio.
- duration: Duration of the voice note, in seconds.
- waveform: Waveform representation of the voice note in 5-bit format.
- caption: Voice note caption; may be null if empty; pass null to use an empty caption; 0-getOption("message_caption_length_max") characters (optional).
- selfDestructType: Voice note self-destruct type; may be null if none; pass null if none; private chats only (optional).
- Inheritance
-
- Object
- TdObject
- InputMessageContent
- InputMessageVoiceNote
Constructors
- InputMessageVoiceNote({required InputFile voiceNote, required int duration, required String waveform, FormattedText? caption, MessageSelfDestructType? selfDestructType})
-
InputMessageVoiceNote (inputMessageVoiceNote) - child of InputMessageContent
const
-
InputMessageVoiceNote.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- caption → FormattedText?
-
Voice note caption; may be null if empty; pass null to use an empty caption; 0-getOption("message_caption_length_max") characters
final
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- duration → int
-
Duration of the voice note, in seconds
final
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfDestructType → MessageSelfDestructType?
-
Voice note self-destruct type; may be null if none; pass null if none; private chats only
final
- voiceNote → InputFile
-
Voice note to be sent. The voice note must be encoded with the Opus codec and stored inside an OGG container with a single audio channel, or be in MP3 or M4A format as regular audio
final
- waveform → String
-
Waveform representation of the voice note in 5-bit format
final
Methods
-
copyWith(
{InputFile? voiceNote, int? duration, String? waveform, FormattedText? caption, MessageSelfDestructType? selfDestructType}) → InputMessageVoiceNote -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type