InputPassportElementErrorSourceUnspecified class final
InputPassportElementErrorSourceUnspecified (inputPassportElementErrorSourceUnspecified) - child of InputPassportElementErrorSource
The element contains an error in an unspecified place. The error will be considered resolved when new data is added.
- elementHash: Current hash of the entire element.
- Inheritance
-
- Object
- TdObject
- InputPassportElementErrorSource
- InputPassportElementErrorSourceUnspecified
Constructors
- InputPassportElementErrorSourceUnspecified({required String elementHash})
-
InputPassportElementErrorSourceUnspecified (inputPassportElementErrorSourceUnspecified) - child of InputPassportElementErrorSource
const
-
InputPassportElementErrorSourceUnspecified.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- elementHash → String
-
Current hash of the entire element
final
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? elementHash}) → InputPassportElementErrorSourceUnspecified -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type