LanguagePackStringValuePluralized class final
LanguagePackStringValuePluralized (languagePackStringValuePluralized) - child of LanguagePackStringValue
A language pack string which has different forms based on the number of some object it mentions. See https://www.unicode.org/cldr/charts/latest/supplemental/language_plural_rules.html for more information.
- Inheritance
-
- Object
- TdObject
- LanguagePackStringValue
- LanguagePackStringValuePluralized
Constructors
- LanguagePackStringValuePluralized({required String zeroValue, required String oneValue, required String twoValue, required String fewValue, required String manyValue, required String otherValue, dynamic extra, int? clientId})
-
LanguagePackStringValuePluralized (languagePackStringValuePluralized) - child of LanguagePackStringValue
const
-
LanguagePackStringValuePluralized.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
clientId client identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
extra callback sign
final
- fewValue → String
-
Value for few objects
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- manyValue → String
-
Value for many objects
final
- oneValue → String
-
Value for one object
final
- otherValue → String
-
Default value
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- twoValue → String
-
Value for two objects
final
- zeroValue → String
-
Value for zero objects
final
Methods
-
copyWith(
{String? zeroValue, String? oneValue, String? twoValue, String? fewValue, String? manyValue, String? otherValue, dynamic extra, int? clientId}) → LanguagePackStringValuePluralized -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type