MaskPosition class final
MaskPosition (maskPosition) - basic class
Position on a photo where a mask is placed.
- point: Part of the face, relative to which the mask is placed.
- xShift: Shift by X-axis measured in widths of the mask scaled to the face size, from left to right. (For example, -1.0 will place the mask just to the left of the default mask position).
- yShift: Shift by Y-axis measured in heights of the mask scaled to the face size, from top to bottom. (For example, 1.0 will place the mask just below the default mask position).
- scale: Mask scaling coefficient. (For example, 2.0 means a doubled size).
Constructors
- MaskPosition({required MaskPoint point, required double xShift, required double yShift, required double scale})
-
MaskPosition (maskPosition) - basic class
const
-
MaskPosition.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- point → MaskPoint
-
Part of the face, relative to which the mask is placed
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → double
-
Mask scaling coefficient. (For example, 2.0 means a doubled size)
final
- xShift → double
-
Shift by X-axis measured in widths of the mask scaled to the face size, from left to right. (For example, -1.0 will place the mask just to the left of the default mask position)
final
- yShift → double
-
Shift by Y-axis measured in heights of the mask scaled to the face size, from top to bottom. (For example, 1.0 will place the mask just below the default mask position)
final
Methods
-
copyWith(
{MaskPoint? point, double? xShift, double? yShift, double? scale}) → MaskPosition - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type