copyWith method
Copy model with modified properties.
Properties:
game_message_id: Identifier of the message with the game, can be an identifier of a deleted messagegame_id: Identifier of the game; may be different from the games presented in the message with the gamescore: New score
Implementation
@override
MessageGameScore copyWith({
int? gameMessageId,
int? gameId,
int? score,
}) =>
MessageGameScore(
gameMessageId: gameMessageId ?? this.gameMessageId,
gameId: gameId ?? this.gameId,
score: score ?? this.score,
);