MessageInvoice class final
MessageInvoice (messageInvoice) - child of MessageContent
A message with an invoice from a bot. Use getInternalLink with internalLinkTypeBotStart to share the invoice.
- productInfo: Information about the product.
- currency: Currency for the product price.
- totalAmount: Product total price in the smallest units of the currency.
- startParameter: Unique invoice bot start_parameter to be passed to getInternalLink.
- isTest: True, if the invoice is a test invoice.
- needShippingAddress: True, if the shipping address must be specified.
- receiptMessageId: The identifier of the message with the receipt, after the product has been purchased.
- paidMedia: Extended media attached to the invoice; may be null if none (optional).
- paidMediaCaption: Extended media caption; may be null if none (optional).
- Inheritance
-
- Object
- TdObject
- MessageContent
- MessageInvoice
Constructors
- MessageInvoice({required ProductInfo productInfo, required String currency, required int totalAmount, required String startParameter, required bool isTest, required bool needShippingAddress, required int receiptMessageId, PaidMedia? paidMedia, FormattedText? paidMediaCaption})
-
MessageInvoice (messageInvoice) - child of MessageContent
const
-
MessageInvoice.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currency → String
-
Currency for the product price
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isTest → bool
-
True, if the invoice is a test invoice
final
- needShippingAddress → bool
-
True, if the shipping address must be specified
final
- paidMedia → PaidMedia?
-
Extended media attached to the invoice; may be null if none
final
- paidMediaCaption → FormattedText?
-
Extended media caption; may be null if none
final
- productInfo → ProductInfo
-
Information about the product
final
- receiptMessageId → int
-
The identifier of the message with the receipt, after the product has been purchased
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startParameter → String
-
Unique invoice bot start_parameter to be passed to getInternalLink
final
- totalAmount → int
-
Product total price in the smallest units of the currency
final
Methods
-
copyWith(
{ProductInfo? productInfo, String? currency, int? totalAmount, String? startParameter, bool? isTest, bool? needShippingAddress, int? receiptMessageId, PaidMedia? paidMedia, FormattedText? paidMediaCaption}) → MessageInvoice -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type