MessageVoiceNote class final
MessageVoiceNote (messageVoiceNote) - child of MessageContent
A voice note message.
- voiceNote: The voice note description.
- caption: Voice note caption.
- isListened: True, if at least one of the recipients has listened to the voice note.
- Inheritance
-
- Object
- TdObject
- MessageContent
- MessageVoiceNote
Constructors
- MessageVoiceNote({required VoiceNote voiceNote, required FormattedText caption, required bool isListened})
-
MessageVoiceNote (messageVoiceNote) - child of MessageContent
const
-
MessageVoiceNote.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- caption → FormattedText
-
Voice note caption
final
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isListened → bool
-
True, if at least one of the recipients has listened to the voice note
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- voiceNote → VoiceNote
-
The voice note description
final
Methods
-
copyWith(
{VoiceNote? voiceNote, FormattedText? caption, bool? isListened}) → MessageVoiceNote -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type