PageBlockCollage class final
PageBlockCollage (pageBlockCollage) - child of PageBlock
A collage.
- pageBlocks: Collage item contents.
- caption: Block caption.
Constructors
-
PageBlockCollage({required List<
PageBlock> pageBlocks, required PageBlockCaption caption}) -
PageBlockCollage (pageBlockCollage) - child of PageBlock
const
-
PageBlockCollage.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- caption → PageBlockCaption
-
Block caption
final
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
pageBlocks
→ List<
PageBlock> -
Collage item contents
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< PageBlock> ? pageBlocks, PageBlockCaption? caption}) → PageBlockCollage -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type