PageBlockEmbedded class final
PageBlockEmbedded (pageBlockEmbedded) - child of PageBlock
An embedded web page.
- url: URL of the embedded page, if available.
- html: HTML-markup of the embedded page.
- posterPhoto: Poster photo, if available; may be null (optional).
- width: Block width; 0 if unknown.
- height: Block height; 0 if unknown.
- caption: Block caption.
- isFullWidth: True, if the block must be full width.
- allowScrolling: True, if scrolling needs to be allowed.
Constructors
- PageBlockEmbedded({required String url, required String html, Photo? posterPhoto, required int width, required int height, required PageBlockCaption caption, required bool isFullWidth, required bool allowScrolling})
-
PageBlockEmbedded (pageBlockEmbedded) - child of PageBlock
const
-
PageBlockEmbedded.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- allowScrolling → bool
-
True, if scrolling needs to be allowed
final
- caption → PageBlockCaption
-
Block caption
final
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
Block height; 0 if unknown
final
- html → String
-
HTML-markup of the embedded page
final
- isFullWidth → bool
-
True, if the block must be full width
final
- posterPhoto → Photo?
-
Poster photo, if available; may be null
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
URL of the embedded page, if available
final
- width → int
-
Block width; 0 if unknown
final
Methods
-
copyWith(
{String? url, String? html, Photo? posterPhoto, int? width, int? height, PageBlockCaption? caption, bool? isFullWidth, bool? allowScrolling}) → PageBlockEmbedded -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type