PageBlockRelatedArticle class final
PageBlockRelatedArticle (pageBlockRelatedArticle) - basic class
Contains information about a related article.
- url: Related article URL.
- title: Article title; may be empty.
- description: Article description; may be empty.
- photo: Article photo; may be null (optional).
- author: Article author; may be empty.
- publishDate: Point in time (Unix timestamp) when the article was published; 0 if unknown.
Constructors
- PageBlockRelatedArticle({required String url, required String title, required String description, Photo? photo, required String author, required int publishDate})
-
PageBlockRelatedArticle (pageBlockRelatedArticle) - basic class
const
-
PageBlockRelatedArticle.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
-
Article author; may be empty
final
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- description → String
-
Article description; may be empty
final
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- photo → Photo?
-
Article photo; may be null
final
- publishDate → int
-
Point in time (Unix timestamp) when the article was published; 0 if unknown
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
Article title; may be empty
final
- url → String
-
Related article URL
final
Methods
-
copyWith(
{String? url, String? title, String? description, Photo? photo, String? author, int? publishDate}) → PageBlockRelatedArticle - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type