PersonalDocument class final
PersonalDocument (personalDocument) - basic class
A personal document, containing some information about a user.
- files: List of files containing the pages of the document.
- translation: List of files containing a certified English translation of the document.
Constructors
-
PersonalDocument({required List<
DatedFile> files, required List<DatedFile> translation}) -
PersonalDocument (personalDocument) - basic class
const
-
PersonalDocument.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
-
files
→ List<
DatedFile> -
List of files containing the pages of the document
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
translation
→ List<
DatedFile> -
List of files containing a certified English translation of the document
final
Methods
-
copyWith(
{List< DatedFile> ? files, List<DatedFile> ? translation}) → PersonalDocument - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type