ProcessChatFolderNewChats class final
ProcessChatFolderNewChats (processChatFolderNewChats) - TDLib function
Process new chats added to a shareable chat folder by its owner.
- chatFolderId: Chat folder identifier.
- addedChatIds: Identifiers of the new chats, which are added to the chat folder. The chats are automatically joined if they aren't joined yet.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- ProcessChatFolderNewChats
Constructors
-
ProcessChatFolderNewChats({required int chatFolderId, required List<
int> addedChatIds}) -
ProcessChatFolderNewChats (processChatFolderNewChats) - TDLib function
const
Properties
-
addedChatIds
→ List<
int> -
Identifiers of the new chats, which are added to the chat folder. The chats are automatically joined if they aren't joined yet
final
- chatFolderId → int
-
Chat folder identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatFolderId, List< int> ? addedChatIds}) → ProcessChatFolderNewChats - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type