ProcessChatJoinRequests class final
ProcessChatJoinRequests (processChatJoinRequests) - TDLib function
Handles all pending join requests for a given link in a chat.
- chatId: Chat identifier.
- inviteLink: Invite link for which to process join requests. If empty, all join requests will be processed. Requires administrator privileges and can_invite_users right in the chat for own links and owner privileges for other links.
- approve: Pass true to approve all requests; pass false to decline them.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- ProcessChatJoinRequests
Constructors
- ProcessChatJoinRequests({required int chatId, required String inviteLink, required bool approve})
-
ProcessChatJoinRequests (processChatJoinRequests) - TDLib function
const
Properties
- approve → bool
-
Pass true to approve all requests; pass false to decline them
final
- chatId → int
-
Chat identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- inviteLink → String
-
Invite link for which to process join requests. If empty, all join requests will be processed. Requires administrator privileges and can_invite_users right in the chat for own links and owner privileges for other links
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, String? inviteLink, bool? approve}) → ProcessChatJoinRequests - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type