QuickReplyShortcut class final
QuickReplyShortcut (quickReplyShortcut) - basic class
Describes a shortcut that can be used for a quick reply.
- id: Unique shortcut identifier.
- name: The name of the shortcut that can be used to use the shortcut.
- firstMessage: The first shortcut message.
- messageCount: The total number of messages in the shortcut.
Constructors
- QuickReplyShortcut({required int id, required String name, required QuickReplyMessage firstMessage, required int messageCount})
-
QuickReplyShortcut (quickReplyShortcut) - basic class
const
-
QuickReplyShortcut.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- firstMessage → QuickReplyMessage
-
The first shortcut message
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Unique shortcut identifier
final
- messageCount → int
-
The total number of messages in the shortcut
final
- name → String
-
The name of the shortcut that can be used to use the shortcut
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? id, String? name, QuickReplyMessage? firstMessage, int? messageCount}) → QuickReplyShortcut - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type