RecoverAuthenticationPassword class final
RecoverAuthenticationPassword (recoverAuthenticationPassword) - TDLib function
Recovers the 2-step verification password with a password recovery code sent to an email address that was previously set up. Works only when the current authorization state is authorizationStateWaitPassword.
- recoveryCode: Recovery code to check.
- newPassword: New 2-step verification password of the user; may be empty to remove the password.
- newHint: New password hint; may be empty.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- RecoverAuthenticationPassword
Constructors
- RecoverAuthenticationPassword({required String recoveryCode, required String newPassword, required String newHint})
-
RecoverAuthenticationPassword (recoverAuthenticationPassword) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- newHint → String
-
New password hint; may be empty
final
- newPassword → String
-
New 2-step verification password of the user; may be empty to remove the password
final
- recoveryCode → String
-
Recovery code to check
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? recoveryCode, String? newPassword, String? newHint}) → RecoverAuthenticationPassword - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type