RegisterDevice class final
RegisterDevice (registerDevice) - TDLib function
Registers the currently used device for receiving push notifications. Returns a globally unique identifier of the push notification subscription.
- deviceToken: Device token.
- otherUserIds: List of user identifiers of other users currently using the application.
PushReceiverId is returned on completion.
- Inheritance
-
- Object
- TdFunction
- RegisterDevice
Constructors
-
RegisterDevice({required DeviceToken deviceToken, required List<
int> otherUserIds}) -
RegisterDevice (registerDevice) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- deviceToken → DeviceToken
-
Device token
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
otherUserIds
→ List<
int> -
List of user identifiers of other users currently using the application
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{DeviceToken? deviceToken, List< int> ? otherUserIds}) → RegisterDevice - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type