RemoteFile constructor
const
RemoteFile({})
RemoteFile (remoteFile) - basic class
Represents a remote file.
id: Remote file identifier; may be empty. Can be used by the current user across application restarts or even from other devices. Uniquely identifies a file, but a file can have a lot of different valid identifiers.. If the identifier starts with "http://" or "https://", it represents the HTTP URL of the file. TDLib is currently unable to download files if only their URL is known.. If downloadFile/addFileToDownloads is called on such a file or if it is sent to a secret chat, TDLib starts a file generation process by sending updateFileGenerationStart to the application with the HTTP URL in the original_path and "#url#" as the conversion string.. Application must generate the file by downloading it to the specified location.uniqueId: Unique file identifier; may be empty if unknown. The unique file identifier which is the same for the same file even for different users and is persistent over time.isUploadingActive: True, if the file is currently being uploaded (or a remote copy is being generated by some other means).isUploadingCompleted: True, if a remote copy is fully available.uploadedSize: Size of the remote available part of the file, in bytes; 0 if unknown.
Implementation
const RemoteFile({
required this.id,
required this.uniqueId,
required this.isUploadingActive,
required this.isUploadingCompleted,
required this.uploadedSize,
});