RemoveFileFromDownloads class final
RemoveFileFromDownloads (removeFileFromDownloads) - TDLib function
Removes a file from the file download list.
- fileId: Identifier of the downloaded file.
- deleteFromCache: Pass true to delete the file from the TDLib file cache.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- RemoveFileFromDownloads
Constructors
- RemoveFileFromDownloads({required int fileId, required bool deleteFromCache})
-
RemoveFileFromDownloads (removeFileFromDownloads) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- deleteFromCache → bool
-
Pass true to delete the file from the TDLib file cache
final
- fileId → int
-
Identifier of the downloaded file
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? fileId, bool? deleteFromCache}) → RemoveFileFromDownloads - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type