ReorderBotMediaPreviews class final
ReorderBotMediaPreviews (reorderBotMediaPreviews) - TDLib function
Changes order of media previews in the list of media previews of a bot.
- botUserId: Identifier of the target bot. The bot must be owned and must have the main Web App.
- languageCode: Language code of the media previews to reorder.
- fileIds: File identifiers of the media in the new order.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- ReorderBotMediaPreviews
Constructors
-
ReorderBotMediaPreviews({required int botUserId, required String languageCode, required List<
int> fileIds}) -
ReorderBotMediaPreviews (reorderBotMediaPreviews) - TDLib function
const
Properties
- botUserId → int
-
Identifier of the target bot. The bot must be owned and must have the main Web App
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
-
fileIds
→ List<
int> -
File identifiers of the media in the new order
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- languageCode → String
-
Language code of the media previews to reorder
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? botUserId, String? languageCode, List< int> ? fileIds}) → ReorderBotMediaPreviews - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type