RequestQrCodeAuthentication class final
RequestQrCodeAuthentication (requestQrCodeAuthentication) - TDLib function
Requests QR code authentication by scanning a QR code on another logged in device. Works only when the current authorization state is authorizationStateWaitPhoneNumber,. or if there is no pending authentication query and the current authorization state is authorizationStateWaitEmailAddress, authorizationStateWaitEmailCode, authorizationStateWaitCode, authorizationStateWaitRegistration, or authorizationStateWaitPassword.
- otherUserIds: List of user identifiers of other users currently using the application.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- RequestQrCodeAuthentication
Constructors
-
RequestQrCodeAuthentication({required List<
int> otherUserIds}) -
RequestQrCodeAuthentication (requestQrCodeAuthentication) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
otherUserIds
→ List<
int> -
List of user identifiers of other users currently using the application
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< int> ? otherUserIds}) → RequestQrCodeAuthentication - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type