SavedMessagesTopic class final
SavedMessagesTopic (savedMessagesTopic) - basic class
Contains information about a Saved Messages topic.
- id: Unique topic identifier.
- type: Type of the topic.
- isPinned: True, if the topic is pinned.
- order: A parameter used to determine order of the topic in the topic list. Topics must be sorted by the order in descending order.
- lastMessage: Last message in the topic; may be null if none or unknown (optional).
- draftMessage: A draft of a message in the topic; may be null if none (optional).
Constructors
- SavedMessagesTopic({required int id, required SavedMessagesTopicType type, required bool isPinned, required int order, Message? lastMessage, DraftMessage? draftMessage})
-
SavedMessagesTopic (savedMessagesTopic) - basic class
const
-
SavedMessagesTopic.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- draftMessage → DraftMessage?
-
A draft of a message in the topic; may be null if none
final
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Unique topic identifier
final
- isPinned → bool
-
True, if the topic is pinned
final
- lastMessage → Message?
-
Last message in the topic; may be null if none or unknown
final
- order → int
-
A parameter used to determine order of the topic in the topic list. Topics must be sorted by the order in descending order
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → SavedMessagesTopicType
-
Type of the topic
final
Methods
-
copyWith(
{int? id, SavedMessagesTopicType? type, bool? isPinned, int? order, Message? lastMessage, DraftMessage? draftMessage}) → SavedMessagesTopic - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type