SearchOutgoingDocumentMessages class final
SearchOutgoingDocumentMessages (searchOutgoingDocumentMessages) - TDLib function
Searches for outgoing messages with content of the type messageDocument in all chats except secret chats. Returns the results in reverse chronological order.
- query: Query to search for in document file name and message caption.
- limit: The maximum number of messages to be returned; up to 100.
FoundMessages is returned on completion.
- Inheritance
-
- Object
- TdFunction
- SearchOutgoingDocumentMessages
Constructors
- SearchOutgoingDocumentMessages({required String query, required int limit})
-
SearchOutgoingDocumentMessages (searchOutgoingDocumentMessages) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int
-
The maximum number of messages to be returned; up to 100
final
- query → String
-
Query to search for in document file name and message caption
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? query, int? limit}) → SearchOutgoingDocumentMessages - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type