SetBio class final
SetBio (setBio) - TDLib function
Changes the bio of the current user.
- bio: The new value of the user bio; 0-getOption("bio_length_max") characters without line feeds.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- SetBio
Properties
- bio → String
-
The new value of the user bio; 0-getOption("bio_length_max") characters without line feeds
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? bio}) → SetBio - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type