SetBotInfoShortDescription class final
SetBotInfoShortDescription (setBotInfoShortDescription) - TDLib function
Sets the text shown on a bot's profile page and sent together with the link when users share the bot. Can be called only if userTypeBot.can_be_edited == true.
- botUserId: Identifier of the target bot.
- languageCode: A two-letter ISO 639-1 language code. If empty, the short description will be shown to all users for whose languages there is no dedicated description.
- shortDescription: New bot's short description on the specified language.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- SetBotInfoShortDescription
Constructors
- SetBotInfoShortDescription({required int botUserId, required String languageCode, required String shortDescription})
-
SetBotInfoShortDescription (setBotInfoShortDescription) - TDLib function
const
Properties
- botUserId → int
-
Identifier of the target bot
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- languageCode → String
-
A two-letter ISO 639-1 language code. If empty, the short description will be shown to all users for whose languages there is no dedicated description
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortDescription → String
-
New bot's short description on the specified language
final
Methods
-
copyWith(
{int? botUserId, String? languageCode, String? shortDescription}) → SetBotInfoShortDescription - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type