SetChatAvailableReactions class final
SetChatAvailableReactions (setChatAvailableReactions) - TDLib function
Changes reactions, available in a chat. Available for basic groups, supergroups, and channels. Requires can_change_info member right.
- chatId: Identifier of the chat.
- availableReactions: Reactions available in the chat. All explicitly specified emoji reactions must be active. In channel chats up to the chat's boost level custom emoji reactions can be explicitly specified.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- SetChatAvailableReactions
Constructors
- SetChatAvailableReactions({required int chatId, required ChatAvailableReactions availableReactions})
-
SetChatAvailableReactions (setChatAvailableReactions) - TDLib function
const
Properties
- availableReactions → ChatAvailableReactions
-
Reactions available in the chat. All explicitly specified emoji reactions must be active. In channel chats up to the chat's boost level custom emoji reactions can be explicitly specified
final
- chatId → int
-
Identifier of the chat
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, ChatAvailableReactions? availableReactions}) → SetChatAvailableReactions - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type