SetChatMemberStatus class final
SetChatMemberStatus (setChatMemberStatus) - TDLib function
Changes the status of a chat member; requires can_invite_users member right to add a chat member, can_promote_members administrator right to change administrator rights of the member,. and can_restrict_members administrator right to change restrictions of a user. This function is currently not suitable for transferring chat ownership; use transferChatOwnership instead.. Use addChatMember or banChatMember if some additional parameters needs to be passed.
- chatId: Chat identifier.
- memberId: Member identifier. Chats can be only banned and unbanned in supergroups and channels.
- status: The new status of the member in the chat.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- SetChatMemberStatus
Constructors
- SetChatMemberStatus({required int chatId, required MessageSender memberId, required ChatMemberStatus status})
-
SetChatMemberStatus (setChatMemberStatus) - TDLib function
const
Properties
- chatId → int
-
Chat identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- memberId → MessageSender
-
Member identifier. Chats can be only banned and unbanned in supergroups and channels
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → ChatMemberStatus
-
The new status of the member in the chat
final
Methods
-
copyWith(
{int? chatId, MessageSender? memberId, ChatMemberStatus? status}) → SetChatMemberStatus - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type