SetCommands class final
SetCommands (setCommands) - TDLib function
Sets the list of commands supported by the bot for the given user scope and language; for bots only.
- scope: The scope to which the commands are relevant; pass null to change commands in the default bot command scope (optional).
- languageCode: A two-letter ISO 639-1 language code. If empty, the commands will be applied to all users from the given scope, for which language there are no dedicated commands.
- commands: List of the bot's commands.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- SetCommands
Constructors
-
SetCommands({BotCommandScope? scope, required String languageCode, required List<
BotCommand> commands}) -
SetCommands (setCommands) - TDLib function
const
Properties
-
commands
→ List<
BotCommand> -
List of the bot's commands
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- languageCode → String
-
A two-letter ISO 639-1 language code. If empty, the commands will be applied to all users from the given scope, for which language there are no dedicated commands
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → BotCommandScope?
-
The scope to which the commands are relevant; pass null to change commands in the default bot command scope
final
Methods
-
copyWith(
{BotCommandScope? scope, String? languageCode, List< BotCommand> ? commands}) → SetCommands - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type