SetDefaultMessageAutoDeleteTime class final
SetDefaultMessageAutoDeleteTime (setDefaultMessageAutoDeleteTime) - TDLib function
Changes the default message auto-delete time for new chats.
- messageAutoDeleteTime: New default message auto-delete time; must be from 0 up to 365 * 86400 and be divisible by 86400. If 0, then messages aren't deleted automatically.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- SetDefaultMessageAutoDeleteTime
Constructors
- SetDefaultMessageAutoDeleteTime({required MessageAutoDeleteTime messageAutoDeleteTime})
-
SetDefaultMessageAutoDeleteTime (setDefaultMessageAutoDeleteTime) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageAutoDeleteTime → MessageAutoDeleteTime
-
New default message auto-delete time; must be from 0 up to 365 * 86400 and be divisible by 86400. If 0, then messages aren't deleted automatically
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{MessageAutoDeleteTime? messageAutoDeleteTime}) → SetDefaultMessageAutoDeleteTime - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type