SetEmojiStatus class final
SetEmojiStatus (setEmojiStatus) - TDLib function
Changes the emoji status of the current user; for Telegram Premium users only.
- emojiStatus: New emoji status; pass null to switch to the default badge (optional).
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- SetEmojiStatus
Constructors
- SetEmojiStatus({EmojiStatus? emojiStatus})
-
SetEmojiStatus (setEmojiStatus) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- emojiStatus → EmojiStatus?
-
New emoji status; pass null to switch to the default badge
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{EmojiStatus? emojiStatus}) → SetEmojiStatus - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type