SetInlineGameScore class final
SetInlineGameScore (setInlineGameScore) - TDLib function
Updates the game score of the specified user in a game; for bots only.
- inlineMessageId: Inline message identifier.
- editMessage: Pass true to edit the game message to include the current scoreboard.
- userId: User identifier.
- score: The new score.
- force: Pass true to update the score even if it decreases. If the score is 0, the user will be deleted from the high score table.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- SetInlineGameScore
Constructors
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- editMessage → bool
-
Pass true to edit the game message to include the current scoreboard
final
- force → bool
-
Pass true to update the score even if it decreases. If the score is 0, the user will be deleted from the high score table
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inlineMessageId → String
-
Inline message identifier
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- score → int
-
The new score
final
- userId → int
-
User identifier
final
Methods
-
copyWith(
{String? inlineMessageId, bool? editMessage, int? userId, int? score, bool? force}) → SetInlineGameScore - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type