SetPollAnswer class final
SetPollAnswer (setPollAnswer) - TDLib function
Changes the user answer to a poll. A poll in quiz mode can be answered only once.
- chatId: Identifier of the chat to which the poll belongs.
- messageId: Identifier of the message containing the poll.
- optionIds: 0-based identifiers of answer options, chosen by the user. User can choose more than 1 answer option only is the poll allows multiple answers.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- SetPollAnswer
Constructors
-
SetPollAnswer({required int chatId, required int messageId, required List<
int> optionIds}) -
SetPollAnswer (setPollAnswer) - TDLib function
const
Properties
- chatId → int
-
Identifier of the chat to which the poll belongs
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageId → int
-
Identifier of the message containing the poll
final
-
optionIds
→ List<
int> -
0-based identifiers of answer options, chosen by the user. User can choose more than 1 answer option only is the poll allows multiple answers
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageId, List< int> ? optionIds}) → SetPollAnswer - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type