SetProfileAccentColor class final
SetProfileAccentColor (setProfileAccentColor) - TDLib function
Changes accent color and background custom emoji for profile of the current user; for Telegram Premium users only.
- profileAccentColorId: Identifier of the accent color to use for profile; pass -1 if none.
- profileBackgroundCustomEmojiId: Identifier of a custom emoji to be shown on the user's profile photo background; 0 if none.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- SetProfileAccentColor
Constructors
- SetProfileAccentColor({required int profileAccentColorId, required int profileBackgroundCustomEmojiId})
-
SetProfileAccentColor (setProfileAccentColor) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- profileAccentColorId → int
-
Identifier of the accent color to use for profile; pass -1 if none
final
- profileBackgroundCustomEmojiId → int
-
Identifier of a custom emoji to be shown on the user's profile photo background; 0 if none
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? profileAccentColorId, int? profileBackgroundCustomEmojiId}) → SetProfileAccentColor - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type