SetStickerEmojis class final
SetStickerEmojis (setStickerEmojis) - TDLib function
Changes the list of emojis corresponding to a sticker. The sticker must belong to a regular or custom emoji sticker set that is owned by the current user.
- emojis: New string with 1-20 emoji corresponding to the sticker.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- SetStickerEmojis
Constructors
- SetStickerEmojis({required InputFile sticker, required String emojis})
-
SetStickerEmojis (setStickerEmojis) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- emojis → String
-
New string with 1-20 emoji corresponding to the sticker
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sticker → InputFile
-
Sticker
final
Methods
-
copyWith(
{InputFile? sticker, String? emojis}) → SetStickerEmojis - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type