SetStickerEmojis constructor
SetStickerEmojis (setStickerEmojis) - TDLib function
Changes the list of emojis corresponding to a sticker. The sticker must belong to a regular or custom emoji sticker set that is owned by the current user.
emojis: New string with 1-20 emoji corresponding to the sticker.
Ok is returned on completion.
Implementation
const SetStickerEmojis({
required this.sticker,
required this.emojis,
});