StarRevenueStatus class final
StarRevenueStatus (starRevenueStatus) - basic class
Contains information about Telegram Stars earned by a bot or a chat.
- totalCount: Total number of Telegram Stars earned.
- currentCount: The number of Telegram Stars that aren't withdrawn yet.
- availableCount: The number of Telegram Stars that are available for withdrawal.
- withdrawalEnabled: True, if Telegram Stars can be withdrawn now or later.
- nextWithdrawalIn: Time left before the next withdrawal can be started, in seconds; 0 if withdrawal can be started now.
Constructors
- StarRevenueStatus({required int totalCount, required int currentCount, required int availableCount, required bool withdrawalEnabled, required int nextWithdrawalIn})
-
StarRevenueStatus (starRevenueStatus) - basic class
const
-
StarRevenueStatus.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- availableCount → int
-
The number of Telegram Stars that are available for withdrawal
final
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentCount → int
-
The number of Telegram Stars that aren't withdrawn yet
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextWithdrawalIn → int
-
Time left before the next withdrawal can be started, in seconds; 0 if withdrawal can be started now
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalCount → int
-
Total number of Telegram Stars earned
final
- withdrawalEnabled → bool
-
True, if Telegram Stars can be withdrawn now or later
final
Methods
-
copyWith(
{int? totalCount, int? currentCount, int? availableCount, bool? withdrawalEnabled, int? nextWithdrawalIn}) → StarRevenueStatus - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type