StatisticalValue class final
StatisticalValue (statisticalValue) - basic class
A value with information about its recent changes.
- value: The current value.
- previousValue: The value for the previous day.
- growthRatePercentage: The growth rate of the value, as a percentage.
Constructors
- StatisticalValue({required double value, required double previousValue, required double growthRatePercentage})
-
StatisticalValue (statisticalValue) - basic class
const
-
StatisticalValue.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- growthRatePercentage → double
-
The growth rate of the value, as a percentage
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- previousValue → double
-
The value for the previous day
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → double
-
The current value
final
Methods
-
copyWith(
{double? value, double? previousValue, double? growthRatePercentage}) → StatisticalValue - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type