StickerSetInfo constructor
const
StickerSetInfo({
- required int id,
- required String title,
- required String name,
- Thumbnail? thumbnail,
- required List<
ClosedVectorPath> thumbnailOutline, - required bool isOwned,
- required bool isInstalled,
- required bool isArchived,
- required bool isOfficial,
- required StickerType stickerType,
- required bool needsRepainting,
- required bool isAllowedAsChatEmojiStatus,
- required bool isViewed,
- required int size,
- required List<
Sticker> covers,
StickerSetInfo (stickerSetInfo) - basic class
Represents short information about a sticker set.
id: Identifier of the sticker set.title: Title of the sticker set.name: Name of the sticker set.thumbnail: Sticker set thumbnail in WEBP, TGS, or WEBM format with width and height 100; may be null. The file can be downloaded only before the thumbnail is changed (optional).thumbnailOutline: Sticker set thumbnail's outline represented as a list of closed vector paths; may be empty. The coordinate system origin is in the upper-left corner.isOwned: True, if the sticker set is owned by the current user.isInstalled: True, if the sticker set has been installed by the current user.isArchived: True, if the sticker set has been archived. A sticker set can't be installed and archived simultaneously.isOfficial: True, if the sticker set is official.stickerType: Type of the stickers in the set.needsRepainting: True, if stickers in the sticker set are custom emoji that must be repainted; for custom emoji sticker sets only.isAllowedAsChatEmojiStatus: True, if stickers in the sticker set are custom emoji that can be used as chat emoji status; for custom emoji sticker sets only.isViewed: True for already viewed trending sticker sets.size: Total number of stickers in the set.covers: Up to the first 5 stickers from the set, depending on the context. If the application needs more stickers the full sticker set needs to be requested.
Implementation
const StickerSetInfo({
required this.id,
required this.title,
required this.name,
this.thumbnail,
required this.thumbnailOutline,
required this.isOwned,
required this.isInstalled,
required this.isArchived,
required this.isOfficial,
required this.stickerType,
required this.needsRepainting,
required this.isAllowedAsChatEmojiStatus,
required this.isViewed,
required this.size,
required this.covers,
});