StoryAreaPosition class final
StoryAreaPosition (storyAreaPosition) - basic class
Describes position of a clickable rectangle area on a story media.
- xPercentage: The abscissa of the rectangle's center, as a percentage of the media width.
- yPercentage: The ordinate of the rectangle's center, as a percentage of the media height.
- widthPercentage: The width of the rectangle, as a percentage of the media width.
- heightPercentage: The height of the rectangle, as a percentage of the media height.
- rotationAngle: Clockwise rotation angle of the rectangle, in degrees; 0-360.
- cornerRadiusPercentage: The radius of the rectangle corner rounding, as a percentage of the media width.
Constructors
- StoryAreaPosition({required double xPercentage, required double yPercentage, required double widthPercentage, required double heightPercentage, required double rotationAngle, required double cornerRadiusPercentage})
-
StoryAreaPosition (storyAreaPosition) - basic class
const
-
StoryAreaPosition.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- cornerRadiusPercentage → double
-
The radius of the rectangle corner rounding, as a percentage of the media width
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- heightPercentage → double
-
The height of the rectangle, as a percentage of the media height
final
- rotationAngle → double
-
Clockwise rotation angle of the rectangle, in degrees; 0-360
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widthPercentage → double
-
The width of the rectangle, as a percentage of the media width
final
- xPercentage → double
-
The abscissa of the rectangle's center, as a percentage of the media width
final
- yPercentage → double
-
The ordinate of the rectangle's center, as a percentage of the media height
final
Methods
-
copyWith(
{double? xPercentage, double? yPercentage, double? widthPercentage, double? heightPercentage, double? rotationAngle, double? cornerRadiusPercentage}) → StoryAreaPosition - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type