StoryInteraction class final
StoryInteraction (storyInteraction) - basic class
Represents interaction with a story.
- actorId: Identifier of the user or chat that made the interaction.
- interactionDate: Approximate point in time (Unix timestamp) when the interaction happened.
- blockList: Block list to which the actor is added; may be null if none or for chat stories (optional).
- type: Type of the interaction.
Constructors
- StoryInteraction({required MessageSender actorId, required int interactionDate, BlockList? blockList, required StoryInteractionType type})
-
StoryInteraction (storyInteraction) - basic class
const
-
StoryInteraction.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- actorId → MessageSender
-
Identifier of the user or chat that made the interaction
final
- blockList → BlockList?
-
Block list to which the actor is added; may be null if none or for chat stories
final
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- interactionDate → int
-
Approximate point in time (Unix timestamp) when the interaction happened
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → StoryInteractionType
-
Type of the interaction
final
Methods
-
copyWith(
{MessageSender? actorId, int? interactionDate, BlockList? blockList, StoryInteractionType? type}) → StoryInteraction - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type