StoryStatistics class final
StoryStatistics (storyStatistics) - basic class
A detailed statistics about a story.
- storyInteractionGraph: A graph containing number of story views and shares.
- storyReactionGraph: A graph containing number of story reactions.
Constructors
- StoryStatistics({required StatisticalGraph storyInteractionGraph, required StatisticalGraph storyReactionGraph, dynamic extra, int? clientId})
-
StoryStatistics (storyStatistics) - basic class
const
-
StoryStatistics.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
clientId client identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
extra callback sign
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storyInteractionGraph → StatisticalGraph
-
A graph containing number of story views and shares
final
- storyReactionGraph → StatisticalGraph
-
A graph containing number of story reactions
final
Methods
-
copyWith(
{StatisticalGraph? storyInteractionGraph, StatisticalGraph? storyReactionGraph, dynamic extra, int? clientId}) → StoryStatistics - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type