TestProxy constructor
const
TestProxy({})
TestProxy (testProxy) - TDLib function
Sends a simple network request to the Telegram servers via proxy; for testing only. Can be called before authorization.
server: Proxy server domain or IP address.port: Proxy server port.type: Proxy type.dcId: Identifier of a datacenter with which to test connection.timeout: The maximum overall timeout for the request.
Ok is returned on completion.
Implementation
const TestProxy({
required this.server,
required this.port,
required this.type,
required this.dcId,
required this.timeout,
});