ToggleBotUsernameIsActive constructor
const
ToggleBotUsernameIsActive({})
ToggleBotUsernameIsActive (toggleBotUsernameIsActive) - TDLib function
Changes active state for a username of a bot. The editable username can't be disabled. May return an error with a message "USERNAMES_ACTIVE_TOO_MUCH" if the maximum number of active usernames has been reached. Can be called only if userTypeBot.can_be_edited == true.
botUserId: Identifier of the target bot.username: The username to change.isActive: Pass true to activate the username; pass false to disable it.
Ok is returned on completion.
Implementation
const ToggleBotUsernameIsActive({
required this.botUserId,
required this.username,
required this.isActive,
});