ToggleChatIsPinned class final
ToggleChatIsPinned (toggleChatIsPinned) - TDLib function
Changes the pinned state of a chat. There can be up to getOption("pinned_chat_count_max")/getOption("pinned_archived_chat_count_max") pinned non-secret chats and the same number of secret chats in the main/archive chat list. The limit can be increased with Telegram Premium.
- chatList: Chat list in which to change the pinned state of the chat.
- chatId: Chat identifier.
- isPinned: Pass true to pin the chat; pass false to unpin it.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- ToggleChatIsPinned
Constructors
- ToggleChatIsPinned({required ChatList chatList, required int chatId, required bool isPinned})
-
ToggleChatIsPinned (toggleChatIsPinned) - TDLib function
const
Properties
- chatId → int
-
Chat identifier
final
- chatList → ChatList
-
Chat list in which to change the pinned state of the chat
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPinned → bool
-
Pass true to pin the chat; pass false to unpin it
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ChatList? chatList, int? chatId, bool? isPinned}) → ToggleChatIsPinned - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type