UpdateApplicationVerificationRequired class final
UpdateApplicationVerificationRequired (updateApplicationVerificationRequired) - child of Update
A request can't be completed unless application verification is performed; for official mobile applications only.. The method setApplicationVerificationToken must be called once the verification is completed or failed.
- verificationId: Unique identifier for the verification process.
- nonce: Unique base64url-encoded nonce for the classic Play Integrity verification (https://developer.android.com/google/play/integrity/classic) for Android,. or a unique string to compare with verify_nonce field from a push notification for iOS.
- cloudProjectNumber: Cloud project number to pass to the Play Integrity API on Android.
Constructors
- UpdateApplicationVerificationRequired({required int verificationId, required String nonce, required int cloudProjectNumber, dynamic extra, int? clientId})
-
UpdateApplicationVerificationRequired (updateApplicationVerificationRequired) - child of Update
const
-
UpdateApplicationVerificationRequired.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
clientId client identifier
final
- cloudProjectNumber → int
-
Cloud project number to pass to the Play Integrity API on Android
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
extra callback sign
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nonce → String
-
Unique base64url-encoded nonce for the classic Play Integrity verification (https://developer.android.com/google/play/integrity/classic) for Android,. or a unique string to compare with verify_nonce field from a push notification for iOS
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verificationId → int
-
Unique identifier for the verification process
final
Methods
-
copyWith(
{int? verificationId, String? nonce, int? cloudProjectNumber, dynamic extra, int? clientId}) → UpdateApplicationVerificationRequired -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type