UpdateAttachmentMenuBots class final
UpdateAttachmentMenuBots (updateAttachmentMenuBots) - child of Update
The list of bots added to attachment or side menu has changed.
- bots: The new list of bots. The bots must not be shown on scheduled messages screen.
Constructors
-
UpdateAttachmentMenuBots({required List<
AttachmentMenuBot> bots, dynamic extra, int? clientId}) -
UpdateAttachmentMenuBots (updateAttachmentMenuBots) - child of Update
const
-
UpdateAttachmentMenuBots.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
-
bots
→ List<
AttachmentMenuBot> -
The new list of bots. The bots must not be shown on scheduled messages screen
final
- clientId → int?
-
clientId client identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
extra callback sign
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< AttachmentMenuBot> ? bots, dynamic extra, int? clientId}) → UpdateAttachmentMenuBots -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type