UpdateChatActiveStories class final
UpdateChatActiveStories (updateChatActiveStories) - child of Update
The list of active stories posted by a specific chat has changed.
- activeStories: The new list of active stories.
Constructors
- UpdateChatActiveStories({required ChatActiveStories activeStories, dynamic extra, int? clientId})
-
UpdateChatActiveStories (updateChatActiveStories) - child of Update
const
-
UpdateChatActiveStories.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- activeStories → ChatActiveStories
-
The new list of active stories
final
- clientId → int?
-
clientId client identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
extra callback sign
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ChatActiveStories? activeStories, dynamic extra, int? clientId}) → UpdateChatActiveStories -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type