UpdateChatViewAsTopics class final
UpdateChatViewAsTopics (updateChatViewAsTopics) - child of Update
A chat default appearance has changed.
- chatId: Chat identifier.
- viewAsTopics: New value of view_as_topics.
Constructors
- UpdateChatViewAsTopics({required int chatId, required bool viewAsTopics, dynamic extra, int? clientId})
-
UpdateChatViewAsTopics (updateChatViewAsTopics) - child of Update
const
-
UpdateChatViewAsTopics.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- chatId → int
-
Chat identifier
final
- clientId → int?
-
clientId client identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
extra callback sign
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- viewAsTopics → bool
-
New value of view_as_topics
final
Methods
-
copyWith(
{int? chatId, bool? viewAsTopics, dynamic extra, int? clientId}) → UpdateChatViewAsTopics -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type