UpdateConnectionState class final
UpdateConnectionState (updateConnectionState) - child of Update
The connection state has changed. This update must be used only to show a human-readable description of the connection state.
- state: The new connection state.
Constructors
- UpdateConnectionState({required ConnectionState state, dynamic extra, int? clientId})
-
UpdateConnectionState (updateConnectionState) - child of Update
const
-
UpdateConnectionState.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
clientId client identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
extra callback sign
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → ConnectionState
-
The new connection state
final
Methods
-
copyWith(
{ConnectionState? state, dynamic extra, int? clientId}) → UpdateConnectionState -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type