UpdateContactCloseBirthdays class final
UpdateContactCloseBirthdays (updateContactCloseBirthdays) - child of Update
The list of contacts that had birthdays recently or will have birthday soon has changed.
- closeBirthdayUsers: List of contact users with close birthday.
Constructors
-
UpdateContactCloseBirthdays({required List<
CloseBirthdayUser> closeBirthdayUsers, dynamic extra, int? clientId}) -
UpdateContactCloseBirthdays (updateContactCloseBirthdays) - child of Update
const
-
UpdateContactCloseBirthdays.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
clientId client identifier
final
-
closeBirthdayUsers
→ List<
CloseBirthdayUser> -
List of contact users with close birthday
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
extra callback sign
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< CloseBirthdayUser> ? closeBirthdayUsers, dynamic extra, int? clientId}) → UpdateContactCloseBirthdays -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type