UpdateMessageReaction class final
UpdateMessageReaction (updateMessageReaction) - child of Update
User changed its reactions on a message with public reactions; for bots only.
- chatId: Chat identifier.
- messageId: Message identifier.
- actorId: Identifier of the user or chat that changed reactions.
- date: Point in time (Unix timestamp) when the reactions were changed.
- oldReactionTypes: Old list of chosen reactions.
- newReactionTypes: New list of chosen reactions.
Constructors
-
UpdateMessageReaction({required int chatId, required int messageId, required MessageSender actorId, required int date, required List<
ReactionType> oldReactionTypes, required List<ReactionType> newReactionTypes, dynamic extra, int? clientId}) -
UpdateMessageReaction (updateMessageReaction) - child of Update
const
-
UpdateMessageReaction.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- actorId → MessageSender
-
Identifier of the user or chat that changed reactions
final
- chatId → int
-
Chat identifier
final
- clientId → int?
-
clientId client identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- date → int
-
Point in time (Unix timestamp) when the reactions were changed
final
- extra → dynamic
-
extra callback sign
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageId → int
-
Message identifier
final
-
newReactionTypes
→ List<
ReactionType> -
New list of chosen reactions
final
-
oldReactionTypes
→ List<
ReactionType> -
Old list of chosen reactions
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageId, MessageSender? actorId, int? date, List< ReactionType> ? oldReactionTypes, List<ReactionType> ? newReactionTypes, dynamic extra, int? clientId}) → UpdateMessageReaction -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type