UpdateMessageUnreadReactions constructor
const
UpdateMessageUnreadReactions({})
UpdateMessageUnreadReactions (updateMessageUnreadReactions) - child of Update
The list of unread reactions added to a message was changed.
chatId: Chat identifier.messageId: Message identifier.unreadReactions: The new list of unread reactions.unreadReactionCount: The new number of messages with unread reactions left in the chat.
Implementation
const UpdateMessageUnreadReactions({
required this.chatId,
required this.messageId,
required this.unreadReactions,
required this.unreadReactionCount,
this.extra,
this.clientId,
});