UpdateTermsOfService class final
UpdateTermsOfService (updateTermsOfService) - child of Update
New terms of service must be accepted by the user. If the terms of service are declined, then the deleteAccount method must be called with the reason "Decline ToS update".
- termsOfServiceId: Identifier of the terms of service.
- termsOfService: The new terms of service.
Constructors
- UpdateTermsOfService({required String termsOfServiceId, required TermsOfService termsOfService, dynamic extra, int? clientId})
-
UpdateTermsOfService (updateTermsOfService) - child of Update
const
-
UpdateTermsOfService.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
clientId client identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
extra callback sign
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- termsOfService → TermsOfService
-
The new terms of service
final
- termsOfServiceId → String
-
Identifier of the terms of service
final
Methods
-
copyWith(
{String? termsOfServiceId, TermsOfService? termsOfService, dynamic extra, int? clientId}) → UpdateTermsOfService -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type