WriteGeneratedFilePart class final
WriteGeneratedFilePart (writeGeneratedFilePart) - TDLib function
Writes a part of a generated file. This method is intended to be used only if the application has no direct access to TDLib's file system, because it is usually slower than a direct write to the destination file.
- generationId: The identifier of the generation process.
- offset: The offset from which to write the data to the file.
- data: The data to write.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- WriteGeneratedFilePart
Constructors
- WriteGeneratedFilePart({required int generationId, required int offset, required String data})
-
WriteGeneratedFilePart (writeGeneratedFilePart) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- data → String
-
The data to write
final
- generationId → int
-
The identifier of the generation process
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- offset → int
-
The offset from which to write the data to the file
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? generationId, int? offset, String? data}) → WriteGeneratedFilePart - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type